package preev

import (
	"bytes"
	"fmt"
	"io/ioutil"
	"net/http"
	"testing"
)

// mockHTTPTickersValid for mocking requests
type mockHTTPTickersValid struct{}

// Do is a mock http request
func (m *mockHTTPTickersValid) Do(req *http.Request) (*http.Response, error) {
	resp := new(http.Response)
	resp.StatusCode = http.StatusBadRequest

	// No req found
	if req == nil {
		return resp, fmt.Errorf("missing request")
	}

	// Valid
	if req.URL.String() == apiEndpoint+"/tickers" {
		resp.StatusCode = http.StatusOK
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`{"BSV:USD":{"id":"12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8","t":1593039540,"p":{"ppi":{"l":173.03,"v":813653},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":420032},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.97,"v":104642}},"tx":{"h":"e16b5f579834d5799e429bb56dbd559226027170a47706d2971e98830cbc7e37","t":1593039548}},"BSV:EUR":{"id":"184UFRtgg8BR2Uebt3BVBvqBLoj81ZwDK1","t":1585959060,"p":{"ppi":{"l":164.23,"v":182869},"bitvavo":{"l":164.23,"v":182869}},"tx":{"h":"0ffa02bba31943298aa99a7b66fa25b72ebb3f4d59c90d467b89132c6cdca658","t":1585994688}},"BSV:AUD":{"id":"1NsdpaqdWcFrzsaDEM55t7372tEmbrTsZx","t":1585796760,"p":{"ppi":{"l":275.99,"v":60854},"btcmarkets":{"l":275.99,"v":60854}},"tx":{"h":"ddc06373cb80c1094400063f58279eeff3e5b443c441f4bdc579c6f21a1b14c6","t":1585954226}}}`)))
	}

	// Valid (by id)
	if req.URL.String() == apiEndpoint+"/tickers/12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8" {
		resp.StatusCode = http.StatusOK
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`{"id":"12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8","t":1593039660,"p":{"ppi":{"l":173,"v":808950},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":415329},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.71,"v":104642}},"tx":{"h":"6c9789662c8c736d1e73db5ae5308b7e2c3c4064861face0c563dd6a86e3a3d5","t":1593039668}}`)))
	}

	// Invalid (by id) (even if it's a bad pair id, the API returns an ID anyway)
	if req.URL.String() == apiEndpoint+"/tickers/bad-pair-id" {
		resp.StatusCode = http.StatusOK
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`{"id":"bad-pair-id"}`)))
	}

	// Invalid (by id)
	if req.URL.String() == apiEndpoint+"/tickers/error" {
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(``)))
		return resp, fmt.Errorf(`unknown error`)
	}

	// Valid Historical (by id)
	if req.URL.String() == apiEndpoint+"/tickers/12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8/historical" {
		resp.StatusCode = http.StatusOK
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`[{"t":1592953980,"p":{"ppi":{"l":177.88,"v":726628},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":528243},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"b5937d93fcac13ccb5ab10661c8379e44adf22cb2b811aa6659d07bd7432acd1","t":1592953988}},{"t":1592954040,"p":{"ppi":{"l":177.88,"v":726628},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":528243},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"e97bc212e1ea9d234d74b27b4360499d5745f73934f05ad49db1849d1db80e33","t":1592954048}},{"t":1592954160,"p":{"ppi":{"l":177.88,"v":725475},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"b65f55beb30cdc279a6eaf559f4ef87b53ab7bfa8bcf89ac4c2fa385905a02dd","t":1592954168}},{"t":1592954220,"p":{"ppi":{"l":177.88,"v":725475},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"8fd25d6adfbd06e5fb3e63715d996c6fd5d2d7802263b0ee418bbb0ca74c5819","t":1592954228}},{"t":1592954280,"p":{"ppi":{"l":177.84,"v":725471},"bitfinex":{"l":178.06,"v":154055},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"406ebe7afdfbb368ce41d8fbc85ddeb4eb4543a59ec6f81db7d088b0bab40c0d","t":1592954288}},{"t":1592954340,"p":{"ppi":{"l":177.84,"v":725471},"bitfinex":{"l":178.06,"v":154055},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"f583a5fd2a1450c92f309a6efaaef43b2409b10f4ce79f20ab997c579a4671cf","t":1592954349}},{"t":1592954460,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"d1b6df4b058a2dc8eba340e446be98f79575967a5e83288fcc830517caa2fe0c","t":1592954468}},{"t":1592954520,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"c093f92db1ddb686077cd6b7c41385040b4f3248bd3cee640ca9344c45528edd","t":1592954579}},{"t":1592954580,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"09dd45cb6c1a9e250c89cdacfd9b1e8214954c5ab0a59bb0fc93065406d8e6a2","t":1592954588}},{"t":1592954640,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"a2a13b082effb134699875603c16e7d96fb04367477ce372a1e6c87642bf42fa","t":1592954648}},{"t":1592954760,"p":{"ppi":{"l":177.84,"v":723266},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39061}},"tx":{"h":"31652bf92e619bb57c0e91997cd8e8acc7c8e3fd5b1329a8e3f0500920b4696c","t":1592954768}},{"t":1592954820,"p":{"ppi":{"l":177.84,"v":723266},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39061}},"tx":{"h":"0b8854e1b1e46856933861bd9314fcbd615c4c251335b4505a57687c6e976793","t":1592954828}},{"t":1592954880,"p":{"ppi":{"l":177.84,"v":723436},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39231}},"tx":{"h":"afea091074a79fec89a7b5ca98f86f8f062a787dc5fd10c30643e0e34e1deb0d","t":1592954890}},{"t":1592954940,"p":{"ppi":{"l":177.73,"v":733181},"bitfinex":{"l":177.52,"v":161728},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39231}},"tx":{"h":"7e40a8b5e6d79dc9ab1e30d21fcea523cffd7c98d80e4da0e5322a1096fa825d","t":1592954948}},{"t":1592955060,"p":{"ppi":{"l":177.73,"v":733181},"bitfinex":{"l":177.52,"v":161728},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39231}},"tx":{"h":"0e2406abfd57845c1dda837cd23ebd02eefa18ebaef8c9add87096ad9d6c8fa4","t":1592955068}},{"t":1592955120,"p":{"ppi":{"l":177.71,"v":733358},"bitfinex":{"l":177.52,"v":161728},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.33,"v":39408}},"tx":{"h":"1ddfe95c1e10d0586558e4e809f9736665e5fbe409b22b1da4f09946d27fa099","t":1592955128}},{"t":1592955180,"p":{"ppi":{"l":177.75,"v":733743},"bitfinex":{"l":177.71,"v":161902},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.33,"v":39619}},"tx":{"h":"7be4e379f5dac56f440c32a99d6421ac3673393f8724a59938f688c4bc5ba244","t":1592955188}},{"t":1592955240,"p":{"ppi":{"l":177.77,"v":734065},"bitfinex":{"l":177.71,"v":162199},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"adeabaad79ae3392578d29f08146c915d1b658b27116f2ec8282b1721c29d29f","t":1592955248}},{"t":1592955360,"p":{"ppi":{"l":177.77,"v":733354},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"c0d8547afcc569c4aa625acc516fee033b51a674e092fd320fa1c361127d556e","t":1592955368}},{"t":1592955420,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"400b4a01c2dc45fd967bb769a5043ee9c2b2fa4bf37bd6a1691cf4b5e9d74eff","t":1592955428}},{"t":1592955480,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"e6358fbb820aa3261f94fc0ed9dcf58d157526a2b9ed56b4f342e2f5128d470d","t":1592955488}},{"t":1592955540,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"1c6ff3caad68f35e2ca91f8bf93b76b4d3aa3bc00e35601597490391f0e131b6","t":1592955549}},{"t":1592955660,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"3a72857bf36c5e3f59fb5d5aeb41e05677d50172d9333c237f6e058480423eea","t":1592955669}},{"t":1592955720,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"b3444fc2a35b31e60d2afef23f138d9b9dbe7a63fa9ae35da039fbbaa7174c3d","t":1592955729}},{"t":1592955780,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"01de6e491b7cd4800d9e256f8b3e92ef3fa9a770d6b7434d4586fe7d8deb1b69","t":1592955788}},{"t":1592955840,"p":{"ppi":{"l":177.78,"v":733710},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"305cefc4b5353177217650f7b9985f32a264849bd7588e1e9b6983d8b735c5c8","t":1592955848}},{"t":1592955960,"p":{"ppi":{"l":177.78,"v":733710},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"6293f09007d392b29b6fd35008838e10d492f5763af1f965f03cd3eef1090234","t":1592955968}},{"t":1592956020,"p":{"ppi":{"l":177.78,"v":733710},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"61ccb98a68468522056b51471252ea1ae6b80d5db438c4bbfdc7796de8a33d08","t":1592956028}},{"t":1592956080,"p":{"ppi":{"l":177.78,"v":732973},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":526514},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"fc7ffc839331400f580bf4a1d8cf852244c06397d587dac8f72d69489e875a7e","t":1592956089}},{"t":1592956140,"p":{"ppi":{"l":177.78,"v":732973},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":526514},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"e25889fa4c2297fb96842129b56de9d94506e88acfec487ea366c65bdd4e7ee4","t":1592956148}},{"t":1592956260,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"5c9d03789ba7e4e6eef3a78577b4ae55d8130d5d37619fa50e678fe6a2b76223","t":1592956268}},{"t":1592956320,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"43c736e41697d58e0cb7bf5594ab910f42bdf3c460831e73e008e625b4bed8b6","t":1592956379}},{"t":1592956380,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"6724f15b426270560f45f50a8be555648e2f0ac0201b4602ead9bbcc7f31cdaa","t":1592956388}},{"t":1592956440,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"9dd889913f98cddf0c8625af7ef876a50900dde866c9bb1886d0d8fa20c3d56a","t":1592956449}},{"t":1592956560,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"ff09adc3cda69510656695bb9421f3660031c1cc5c9b576d224d40f0ebb744a3","t":1592956568}},{"t":1592956620,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"f82e0b70f47bd9d7beddd27fe83563445260d11bce381d83b590f964de582f3c","t":1592956628}},{"t":1592956680,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"bc8be2d952e53c594dedab36daf107fb8da94546d0713211abeb688cc87231e5","t":1592956688}},{"t":1592956740,"p":{"ppi":{"l":177.97,"v":732818},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":178.08,"v":527388},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"647aa8f92b15fc5b4a295f19b8e5845fdbb98bd0f001517ad232f105840c63d3","t":1592956748}},{"t":1592956860,"p":{"ppi":{"l":178,"v":732809},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":178.08,"v":527388},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"1f5225a2c889cd36cbdfb111bcd9912add30ae696f82e350c3a091c358125b5f","t":1592956868}},{"t":1592956920,"p":{"ppi":{"l":178,"v":724930},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":178.08,"v":519509},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"dfedefba94e8eb2ed39be3bb7275c06570c44e1701c508d6e43a80f93e4dd280","t":1592956928}},{"t":1592956980,"p":{"ppi":{"l":178,"v":724930},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":178.08,"v":519509},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"b7148519f1e814224bb88bfd4bbfa0c4d2c769049666b942399889649c385574","t":1592956988}},{"t":1592957040,"p":{"ppi":{"l":178,"v":724930},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":178.08,"v":519509},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"f5eb7a01320e0a5a80968b1f4cfb59ab6ed096fc62efda4ed1d170f84c8d8095","t":1592957048}},{"t":1592957160,"p":{"ppi":{"l":178,"v":720961},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":517286},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"718c325de0337fa9296f5da0ac8f1c3a61606fb8f4eb40b8fdebb420d943f515","t":1592957169}},{"t":1592957220,"p":{"ppi":{"l":178,"v":720514},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":516839},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"bdd93608cf1eb8a4a7225a94998e2b2e3c71a809d5f56a9d648347f64d69b5a0","t":1592957228}},{"t":1592957280,"p":{"ppi":{"l":178,"v":718640},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":514965},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"d23de1772395e62ea429bf76848bef23675334c1365e14e156f6a2b9a5df2144","t":1592957288}},{"t":1592957340,"p":{"ppi":{"l":178,"v":718640},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":514965},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"bb518a84e12de562d97d7bf1a38d9c74a3e89b271029dcebde443394775de487","t":1592957349}},{"t":1592957460,"p":{"ppi":{"l":178,"v":718640},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":514965},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"c4c34503d92a6c23c8ac54396a23058603633ccbcb24bb4880996145525d10b0","t":1592957468}},{"t":1592957520,"p":{"ppi":{"l":178,"v":715934},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":512259},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"812f11ad89dd9f59703293a56b81d39ba8ebe6b69c2a0f76d8200e169512fd13","t":1592957528}},{"t":1592957580,"p":{"ppi":{"l":178,"v":715505},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":511830},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"0a3c2578ed232fe6d79625ea00776f1ea1542e68a63f27cf14776617bce6fa4d","t":1592957590}},{"t":1592957640,"p":{"ppi":{"l":178,"v":715505},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.08,"v":511830},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"4e0945477679a1a206de7faff3c8bea83a4f09127f3dafe12e5ad519bb42681d","t":1592957648}},{"t":1592957760,"p":{"ppi":{"l":177.99,"v":715834},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"6f518c63b60e08556ea11a10c4b1856fe970498fb9c8d257cbfae834ca1043be","t":1592957768}},{"t":1592957820,"p":{"ppi":{"l":177.99,"v":715834},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"25a22d63e68e349a32829a4d95a77f4d731da7fbb968d4a540f2858417ccd824","t":1592957829}},{"t":1592957880,"p":{"ppi":{"l":177.99,"v":715834},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"df11a2d865a101a27dd8aedeff128ccb769eb3cb3182c04f06d414ef82f72ac2","t":1592957889}},{"t":1592957940,"p":{"ppi":{"l":177.99,"v":715834},"bitfinex":{"l":177.69,"v":158819},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"1b6715293cc615bcc872f18cd9cda90188de41abf15e6b46f9d151d7324b7fef","t":1592957948}},{"t":1592958060,"p":{"ppi":{"l":178,"v":711713},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"fce22d24ab7e3e2199f39af01e9727cde5f1305d5c464443b583aa25e32839c1","t":1592958068}},{"t":1592958120,"p":{"ppi":{"l":178,"v":711713},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"5b794c8de5618259d3fa324b7dd6fafc5d54d4992e1e68b9590fb72dec2126bb","t":1592958180}},{"t":1592958180,"p":{"ppi":{"l":178,"v":711713},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"3784ded0f291a1608eb34ec50d3c03560709032385bb2cb7a1f8a341749bea49","t":1592958188}},{"t":1592958240,"p":{"ppi":{"l":178,"v":711756},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"34a9cc971cf598028d7dda9f5eae7889052f98c1e19e92428ea4c3974652f81d","t":1592958249}},{"t":1592958360,"p":{"ppi":{"l":178,"v":711756},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"c9dae8190a90d4894db3d4668e20d6deed902c674ffcb10a5064021e6ed89369","t":1592958369}},{"t":1592958420,"p":{"ppi":{"l":178,"v":711756},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":512159},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"dd32a59ce44eccb029475e0a2b50847f3e15fad1d883b8e1f0b9f8d0b253553b","t":1592958428}},{"t":1592958480,"p":{"ppi":{"l":178,"v":710942},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":511345},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"20877ba99079fb55d6959a08772e2b2a3088d74cafb68b0a5b0703df588c7811","t":1592958488}},{"t":1592958540,"p":{"ppi":{"l":178,"v":710942},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.07,"v":511345},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"41ce2e9424d983da2bbac8e037d04034c77a56b84604d0509250fb00d57d42ff","t":1592958548}},{"t":1592958660,"p":{"ppi":{"l":178.13,"v":712684},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.25,"v":513087},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"0a94c91e7fca83a34cac5fdf743f250430d0f4d1fd8cae854e1e3ec8bba496f0","t":1592958669}},{"t":1592958720,"p":{"ppi":{"l":178.13,"v":712684},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.25,"v":513087},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"037bce21d6a0cb6cdd17c8b3e7c6fd47195328ac5a0986e9b470a4a0684159a3","t":1592958729}},{"t":1592958780,"p":{"ppi":{"l":178.13,"v":713021},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.25,"v":513424},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"8c2c569e5491dd0e8c4eb96eb1dbc4617ab1f7a9f94dd5f4dffd4029591e90af","t":1592958789}},{"t":1592958840,"p":{"ppi":{"l":178.13,"v":713021},"bitfinex":{"l":177.69,"v":154698},"bittrex":{"l":178.25,"v":513424},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"ffbcef83c6a8e881953303098ad23200b49944399733cd7c7554bd0143662c8a","t":1592958848}},{"t":1592958960,"p":{"ppi":{"l":178.13,"v":712943},"bitfinex":{"l":177.69,"v":154484},"bittrex":{"l":178.25,"v":513560},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"250142bb7d4dd32f253bf468a81c622d3820e7867e964a3f9ad8775d32163815","t":1592958968}},{"t":1592959020,"p":{"ppi":{"l":178.19,"v":713779},"bitfinex":{"l":177.69,"v":154484},"bittrex":{"l":178.34,"v":514396},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"d760665dc03061fbde87de882dad2bc90e750e964ecad59d689ebac0d5af241e","t":1592959028}},{"t":1592959080,"p":{"ppi":{"l":178.19,"v":713779},"bitfinex":{"l":177.69,"v":154484},"bittrex":{"l":178.34,"v":514396},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"c1fbc5eb0a4ebd5b5c158417657d0b9f29f9cb3c466e85b6b3d416bebfdf2284","t":1592959088}},{"t":1592959140,"p":{"ppi":{"l":178.19,"v":713779},"bitfinex":{"l":177.69,"v":154484},"bittrex":{"l":178.34,"v":514396},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"19f187401b291f8bc45cb001818d84c4f0d45baa17e8d85a42a0381843bbcaf3","t":1592959148}},{"t":1592959260,"p":{"ppi":{"l":178.19,"v":713779},"bitfinex":{"l":177.69,"v":154484},"bittrex":{"l":178.34,"v":514396},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"39e3bb3a3cb678e9a2dcd688c76a7b347549c98e5d97df4370d6751d1304d9cf","t":1592959269}},{"t":1592959320,"p":{"ppi":{"l":178.34,"v":710199},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":510228},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"d3466d2eb576f8b3f1a6509d4999ce7e30a7a49899147b79d03d961bba08e449","t":1592959328}},{"t":1592959380,"p":{"ppi":{"l":178.34,"v":709377},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"ee128c1670d985b5e80eb85b3c9389f0cf8ebc12e5020c82de3be009d5cddc00","t":1592959388}},{"t":1592959440,"p":{"ppi":{"l":178.34,"v":709377},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"f01269f8a3aaba0741512303adce9c26d1ce0a6b162dae51f33fcada37651ab1","t":1592959448}},{"t":1592959560,"p":{"ppi":{"l":178.34,"v":709377},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"387ddec8cbcb0410caf3c876279c75bb73617e93d9d6ab3d7bd744f569ac677f","t":1592959568}},{"t":1592959620,"p":{"ppi":{"l":178.34,"v":709377},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"e401fe6c98d96c5d296b68d3ff65286c999555a1e6c71a798622089623b0762a","t":1592959629}},{"t":1592959680,"p":{"ppi":{"l":178.34,"v":709377},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"742359d5c51ebcf8fd44868a0d1ad4688c7ee43b0af91bbde39f86ed49f38d1c","t":1592959689}},{"t":1592959740,"p":{"ppi":{"l":178.34,"v":709377},"bitfinex":{"l":178.34,"v":155072},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"2166a77fc7849f4b44b2196466d208ba3830878641d6ddf44f14ca2135787915","t":1592959748}},{"t":1592959860,"p":{"ppi":{"l":178.34,"v":702383},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"0f5cc1ab7f055010be2afd2d8d188e78a2bb2b1033c334f72b0b82578a58f7a7","t":1592959869}},{"t":1592959920,"p":{"ppi":{"l":178.34,"v":702383},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"63abfd4a1fd1b54f7d8873c39c2470509426a26e2a0d5bfcc9ea0ccf59590437","t":1592959981}},{"t":1592959980,"p":{"ppi":{"l":178.34,"v":702383},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"e9e11ba0e90c42035af81862c6c3af2ee913560a7a8e419751bf378dd9fa1e53","t":1592959988}},{"t":1592960040,"p":{"ppi":{"l":178.34,"v":702383},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":509406},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"7d76cf230676e42fbe2ea7b36f990c14b8fb7dc09e65837d67a24a6318c3b15d","t":1592960048}},{"t":1592960160,"p":{"ppi":{"l":178.34,"v":699466},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506489},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"26d42083b172ab58b6d8cdf40586e82fdec99ac1988a09d34ed6a4a76c58a465","t":1592960168}},{"t":1592960220,"p":{"ppi":{"l":178.34,"v":699466},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506489},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"df4bb36a7f9eb982dff276317b230ea7eb8ba9180fb048fc125eb4ba75a6b36f","t":1592960228}},{"t":1592960280,"p":{"ppi":{"l":178.34,"v":699466},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506489},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"8ca3773beac3cf1699810b75dc1a7c3ac9aefcf10e633a4e97a9446bbe920930","t":1592960289}},{"t":1592960340,"p":{"ppi":{"l":178.34,"v":699466},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506489},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"7641b86c5ac17784ca4ae116549c4d42d1f85f208a3ba4338a8cebf03579b1d5","t":1592960348}},{"t":1592960460,"p":{"ppi":{"l":178.34,"v":699254},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"68561b4241086ce1a6d6f7353a4df89c393e05e18bb249fa5f1c4b92c472c14e","t":1592960469}},{"t":1592960520,"p":{"ppi":{"l":178.34,"v":699254},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"b8ae204b2200c93cf5529cd047b7d2f52673f6cec7d9d9f30d903bcdf75cdeaa","t":1592960528}},{"t":1592960580,"p":{"ppi":{"l":178.34,"v":699254},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"f4fb9c3c2be32b29472eeaaea6dd425d5bc9102e91214a3b4075b313402c9721","t":1592960588}},{"t":1592960640,"p":{"ppi":{"l":178.34,"v":699254},"bitfinex":{"l":178.34,"v":148078},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"9a23918e275d13a5e0e95b91088d00597ec6b03febc29b7558b2d94d77a70939","t":1592960648}},{"t":1592960760,"p":{"ppi":{"l":178.34,"v":699250},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"8c9f269fab11181e8f6643638a5bcb52a5aec7ca5e447c07916c61049d50e22f","t":1592960768}},{"t":1592960820,"p":{"ppi":{"l":178.34,"v":699250},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"005988ea2d4d4657292141f944705b3d888933002c10dbe8a46bd8a0729010c1","t":1592960827}},{"t":1592960880,"p":{"ppi":{"l":178.34,"v":699250},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"8c34b7470c232cbb0a0ac46e5f729518770c3d59845e7f62f5c3490e80c379bc","t":1592960888}},{"t":1592960940,"p":{"ppi":{"l":178.34,"v":699250},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.34,"v":506277},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"960a30ba8d75130e27b92611fc2edb2b32ec7d7bfa8a93194f2bfa742fd83bf9","t":1592960948}},{"t":1592961060,"p":{"ppi":{"l":178.34,"v":696077},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.34,"v":503104},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"70e3a3fe75c3622584fd3e658f9077a14faad016edf5c53c3bf29799d1342848","t":1592961068}},{"t":1592961120,"p":{"ppi":{"l":178.34,"v":696077},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.34,"v":503104},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"ad4e6e60bc96bd7ea793b12d872c470f013f87d658aaf68b790dd7cd3abccc16","t":1592961128}},{"t":1592961180,"p":{"ppi":{"l":178.35,"v":695996},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":503023},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"6202420943fbaa728515e62a2aec2a8039a894c1f2ae74196da076cb8a36c189","t":1592961188}},{"t":1592961240,"p":{"ppi":{"l":178.35,"v":695996},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":503023},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"fd710deac64b530d224a54ae11338b4da3599e2b15b894fe1148338ee58c8c60","t":1592961248}},{"t":1592961360,"p":{"ppi":{"l":178.35,"v":692456},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":499483},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"9fc1fdbadaa5314981a9ec764926a1383621e81e63c7a5ab3cf7d17db8000272","t":1592961368}},{"t":1592961420,"p":{"ppi":{"l":178.35,"v":692456},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":499483},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"b317773cbb08da68e3a788391b5e34c88065616b59664c67c3ef2e5de2c943ba","t":1592961428}},{"t":1592961480,"p":{"ppi":{"l":178.12,"v":696711},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503738},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"3e1d68fb90f7e8369d88f06959ab268da5268a6e1ee5bc0ceaaa44309030a5fb","t":1592961488}},{"t":1592961540,"p":{"ppi":{"l":178.12,"v":696711},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503738},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"3560176eefc171a580adf4ab30dabe3479dde83f1cbd09ca23868049df980839","t":1592961547}},{"t":1592961660,"p":{"ppi":{"l":178.12,"v":696614},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503641},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"6bb15e9eb68448da8ac8451a63f81a2fa3afbfb62583fb871b1208094fd4d10c","t":1592961668}},{"t":1592961720,"p":{"ppi":{"l":178.12,"v":696614},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503641},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"93b71659640bc53253ea181c07eeb1c8b33d96e9a8eebe0d1f087f89152291b8","t":1592961782}},{"t":1592961780,"p":{"ppi":{"l":178.12,"v":696614},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503641},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"4a3a0f81d6e00b16d15fbaf7a144f9a4e48f911d52cbc3a887f69f81ac78bcf4","t":1592961788}},{"t":1592961840,"p":{"ppi":{"l":178.12,"v":696614},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503641},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"aa251f00de852b12a6ee2776dbc3be5da66e04b42c3376dd0f83d030d7ff23f2","t":1592961849}},{"t":1592961960,"p":{"ppi":{"l":178.12,"v":696614},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":503641},"okcoin":{"l":178.15,"v":5264},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"937fe813864d2527a128519d4a6621f509393a06bffbd6addc0699aa67a70cf5","t":1592961968}},{"t":1592962020,"p":{"ppi":{"l":178.12,"v":689123},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":495703},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"c25b91b9b34ef0b663b0bd53897272392785972e6a9e9d12ecc3271f2deae6c2","t":1592962029}},{"t":1592962080,"p":{"ppi":{"l":178.13,"v":657243},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":463823},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.28,"v":39635}},"tx":{"h":"cace145a3e268589a6d0da50c0abcff05bb1b44116717ab0bb4a89b355d01e8d","t":1592962088}},{"t":1592962140,"p":{"ppi":{"l":178.12,"v":651958},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.04,"v":458538},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":39635}},"tx":{"h":"350b1b235425c614585c369b5f15a6d9a6f500e284a128da91bb393ed2bf54f6","t":1592962148}},{"t":1592962260,"p":{"ppi":{"l":178.34,"v":596685},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":403261},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":39639}},"tx":{"h":"b1c6aa5a81071bb7d3b1bbff16950432e7aa1b29f18c79907525bd698843e43c","t":1592962268}},{"t":1592962320,"p":{"ppi":{"l":178.34,"v":591805},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":400373},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"3a008be4ca5e7d152a20ab0c6d42dc2fd62c81f564a3bff2b034dbcb714cba6e","t":1592962328}},{"t":1592962380,"p":{"ppi":{"l":178.34,"v":587925},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":396493},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"066ace9b583460b98a121cd6a15949362fc91f22b8ccecf77363663285c8f981","t":1592962388}},{"t":1592962440,"p":{"ppi":{"l":178.34,"v":556324},"bitfinex":{"l":178.34,"v":148074},"bittrex":{"l":178.36,"v":364892},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"ceb6cddde2e9b009148fb7875bc28643b2cf38091603ee1fae81b8244e499b51","t":1592962448}},{"t":1592962560,"p":{"ppi":{"l":178.34,"v":541007},"bitfinex":{"l":178.34,"v":141326},"bittrex":{"l":178.36,"v":356323},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"5c966ae0cff3784c12ac1803d07309691d062e50b0edf45a4f0dc6f8782779ac","t":1592962568}},{"t":1592962620,"p":{"ppi":{"l":178.34,"v":539890},"bitfinex":{"l":178.34,"v":141326},"bittrex":{"l":178.36,"v":355206},"okcoin":{"l":178.64,"v":5711},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"8c46b8d8787f078ae8e1cd9a4cd931efc5b6a9eabfeb30d7d693912115fd7165","t":1592962628}},{"t":1592962680,"p":{"ppi":{"l":178.34,"v":539730},"bitfinex":{"l":178.34,"v":141326},"bittrex":{"l":178.36,"v":355206},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"73f40ef4066a9b152ba0785c8493e87d584fb383444875aa38b1eff4af82477f","t":1592962689}},{"t":1592962740,"p":{"ppi":{"l":178.34,"v":539730},"bitfinex":{"l":178.34,"v":141326},"bittrex":{"l":178.36,"v":355206},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"c12b6535478bfa86ccb3f7274743373bcb823fab90ce17627aa47c7a2bdc5392","t":1592962750}},{"t":1592962860,"p":{"ppi":{"l":178.49,"v":541554},"bitfinex":{"l":178.93,"v":143150},"bittrex":{"l":178.36,"v":355206},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"932066d5ec37d2b99fb4cb68909541a7a4fefeb25b8fa6038757590be0f5ed63","t":1592962870}},{"t":1592962920,"p":{"ppi":{"l":178.49,"v":541554},"bitfinex":{"l":178.93,"v":143150},"bittrex":{"l":178.36,"v":355206},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"28002ebfada2fb5561362d45c470df85786dc8e2b45042c90703433ab0feed36","t":1592962929}},{"t":1592962980,"p":{"ppi":{"l":178.49,"v":541509},"bitfinex":{"l":178.93,"v":143150},"bittrex":{"l":178.36,"v":355161},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"3c6d68789076b6664b4b10d6a05fbc248e99616b2d711edb8168a0c276f62ec2","t":1592962988}},{"t":1592963040,"p":{"ppi":{"l":178.64,"v":541916},"bitfinex":{"l":178.93,"v":143150},"bittrex":{"l":178.58,"v":355568},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"646bf2d3ce8a844114bc77fa9580833e7d5362b7387545b735f50ae975b72444","t":1592963048}},{"t":1592963160,"p":{"ppi":{"l":178.64,"v":541916},"bitfinex":{"l":178.93,"v":143150},"bittrex":{"l":178.58,"v":355568},"okcoin":{"l":178.64,"v":5551},"poloniex":{"l":178.07,"v":37647}},"tx":{"h":"9deaec5fa96233f7fd2f32e52a50d43c585f86f0037766ec8190220a8b26add4","t":1592963168}},{"t":1592963220,"p":{"ppi":{"l":179.09,"v":554550},"bitfinex":{"l":178.93,"v":143150},"bittrex":{"l":179.16,"v":367933},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":178.92,"v":37647}},"tx":{"h":"1db33a80136c73da1079a69da70d38c89530c43c81290fab53c33c0d20d6712a","t":1592963229}},{"t":1592963280,"p":{"ppi":{"l":180.01,"v":564025},"bitfinex":{"l":180.39,"v":144625},"bittrex":{"l":179.99,"v":375833},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":178.92,"v":37747}},"tx":{"h":"cf1ceab8daed85de096b3ef55febcccd28da3cc048fffce6675da433926785ac","t":1592963288}},{"t":1592963340,"p":{"ppi":{"l":180.81,"v":573118},"bitfinex":{"l":181.59,"v":147624},"bittrex":{"l":180.58,"v":381927},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37747}},"tx":{"h":"dfe2b647c00d006065ba85afcd71571367f66e93a58af2462288b2d7018abc47","t":1592963348}},{"t":1592963460,"p":{"ppi":{"l":180.76,"v":571253},"bitfinex":{"l":181.41,"v":144705},"bittrex":{"l":180.58,"v":382880},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"fc6e867d5e31cef7ab7acebe73a58b1ad9cb18215059915644fdcf528cd599b5","t":1592963468}},{"t":1592963520,"p":{"ppi":{"l":180.73,"v":580621},"bitfinex":{"l":181.23,"v":154073},"bittrex":{"l":180.58,"v":382880},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"e2469d9aab830f75c8677b99ad46798157cc3d5af2f9c93f19393e41beb3ff5e","t":1592963582}},{"t":1592963580,"p":{"ppi":{"l":180.67,"v":579368},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.58,"v":381448},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"61776bde4e2f8ff927980daa1b5c2d5f89465b9f6e7cf640f88e5ab330de74c2","t":1592963588}},{"t":1592963640,"p":{"ppi":{"l":180.67,"v":579368},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.58,"v":381448},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"dfd3e755fa30d39f8c2e0aa61bf0962375a4a9568576d2eaf9b0ea28f60fc52e","t":1592963649}},{"t":1592963760,"p":{"ppi":{"l":180.31,"v":579377},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":381457},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"44f848939a400f8321a598e5e238dc8792a985fd05c96dfaac8e4668a2617017","t":1592963768}},{"t":1592963820,"p":{"ppi":{"l":180.31,"v":579264},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":381344},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"b433def06e3ef5b454ba68df1b59f9ec68d158e632bcd127a434c12c645cf2d9","t":1592963828}},{"t":1592963880,"p":{"ppi":{"l":180.31,"v":579264},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":381344},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"1988fb79fa4ea8fb8620ce5261dc841aeccbc88b295e5bb8ff44d678d7d353ec","t":1592963888}},{"t":1592963940,"p":{"ppi":{"l":180.31,"v":577544},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":379624},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"4a22826c5ed3df95b5f4e2391b83bac7d745bea0b1f96127421cc301c62ea40b","t":1592963948}},{"t":1592964060,"p":{"ppi":{"l":180.31,"v":575918},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":377998},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"cb37321a094620d89cd6d32f9401957110be6a6c2e556805f9fae7f1c250d2e2","t":1592964068}},{"t":1592964120,"p":{"ppi":{"l":180.31,"v":575068},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":377148},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37848}},"tx":{"h":"5687dec422dd76addce3bad63b3d06700b718fcf82b5e475992dd9dbbc42f61f","t":1592964128}},{"t":1592964180,"p":{"ppi":{"l":180.31,"v":572714},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.04,"v":374973},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37669}},"tx":{"h":"6c8c198697b12fd65e5fa21c882fed7f029d0d68f26b808299f2ba9128ebbfec","t":1592964188}},{"t":1592964240,"p":{"ppi":{"l":180.53,"v":571498},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.37,"v":373757},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37669}},"tx":{"h":"5f8e40467ff68347e393be377d84ee7998aac78ff48ae857a3a2a861bae87183","t":1592964249}},{"t":1592964360,"p":{"ppi":{"l":180.53,"v":567034},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.37,"v":369293},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37669}},"tx":{"h":"a283b72250ad5e615f023331c97e1f8458041eb87b48e68355e4c3c1cdca7c9a","t":1592964368}},{"t":1592964420,"p":{"ppi":{"l":180.53,"v":565798},"bitfinex":{"l":181.01,"v":154252},"bittrex":{"l":180.37,"v":368057},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37669}},"tx":{"h":"600df52455be154b1a4198867868972b133f13dfc45bd7d5ab9732da13ccb364","t":1592964428}},{"t":1592964480,"p":{"ppi":{"l":180.37,"v":560908},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":363497},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37667}},"tx":{"h":"95075177567c52e17f0e5967c6ea7bf9fa6b4e20bcdd4951d0d270c422494b40","t":1592964488}},{"t":1592964540,"p":{"ppi":{"l":180.37,"v":560713},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":363302},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37667}},"tx":{"h":"9bd7a12163d4744fd0583ad0bae3ae9592027b7e7db88c539eb1e69d74b8e2c6","t":1592964548}},{"t":1592964660,"p":{"ppi":{"l":180.37,"v":558742},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":361331},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37667}},"tx":{"h":"56af5a7df71100e666444b93911f8dd9611d606e70f35ddefe1f51cdb3a42327","t":1592964668}},{"t":1592964720,"p":{"ppi":{"l":180.37,"v":555186},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":357775},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37667}},"tx":{"h":"a304de42d2ebdcc8820d1e28ccdd5b1633703c4a78aa4abd096026b69846fdbb","t":1592964728}},{"t":1592964780,"p":{"ppi":{"l":180.37,"v":554819},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":357408},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37667}},"tx":{"h":"2f4239e53769f68dece789cf8586e3a9cfeca0d4427b368026b0cd363032953d","t":1592964788}},{"t":1592964840,"p":{"ppi":{"l":180.37,"v":549202},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":351791},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37667}},"tx":{"h":"3a2fc73a6eb37321f50102c6e951c11041438c23d13b6d1644019e5926cbc20f","t":1592964847}},{"t":1592964960,"p":{"ppi":{"l":180.37,"v":547560},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":350249},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37567}},"tx":{"h":"742860bf869f2e2ed71ba955da75a365f5cb2f6c05b5d042de7ed7a977a373ed","t":1592964968}},{"t":1592965020,"p":{"ppi":{"l":180.37,"v":547560},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":350249},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37567}},"tx":{"h":"05da0ea99655a11096db3ed8c86fe525addefa3d162dd1e9ab42a38ee6d3ae9f","t":1592965028}},{"t":1592965080,"p":{"ppi":{"l":180.37,"v":540237},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":342926},"okcoin":{"l":179.31,"v":5820},"poloniex":{"l":180.36,"v":37567}},"tx":{"h":"ec20dd9cc6354048c72cf077304cc180483fe3329e61d4f8b11b7597700315fd","t":1592965088}},{"t":1592965140,"p":{"ppi":{"l":180.37,"v":539689},"bitfinex":{"l":180.42,"v":153924},"bittrex":{"l":180.37,"v":342616},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":37417}},"tx":{"h":"36aa4093c1bed004a8d7162c72d1d7934df4fd36638dd9c405d09b7e1d61ab38","t":1592965148}},{"t":1592965260,"p":{"ppi":{"l":180.51,"v":529918},"bitfinex":{"l":180.89,"v":150343},"bittrex":{"l":180.37,"v":337577},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36266}},"tx":{"h":"a3d256b7a3d65c178f589be232184e682b56863c1487d4421a90ae9fbba4e8bd","t":1592965268}},{"t":1592965320,"p":{"ppi":{"l":180.42,"v":529726},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":337550},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"b95e1eaabb3dcc9ebf810b1429072b4a9a4f9a4204b41fdb6913edd4c19373a6","t":1592965383}},{"t":1592965380,"p":{"ppi":{"l":180.42,"v":531530},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":339354},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"ddf2028b5edf69714afeeea15c82bede9107fecf2c3e164d82b320b238aa324b","t":1592965388}},{"t":1592965440,"p":{"ppi":{"l":180.42,"v":524359},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":332183},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"b1ac86284547285ccb35aef4003ae880c4bb3b495737b8e35faa20a7f768da2e","t":1592965451}},{"t":1592965560,"p":{"ppi":{"l":180.42,"v":520549},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":328373},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"5d2ddb473597c8052a1e418d7e8f766f64358392934b9e132221318427d540e9","t":1592965568}},{"t":1592965620,"p":{"ppi":{"l":180.42,"v":520549},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":328373},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"2c442f39ed2af67e2fe1aadfb04e0df687aded8dc8265caed255912d37066824","t":1592965629}},{"t":1592965680,"p":{"ppi":{"l":180.42,"v":520549},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":328373},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"fb73d65cbb3569ddfa9f68f30011904e7264a24bd2b6afb7802a4d8ada14ef69","t":1592965688}},{"t":1592965740,"p":{"ppi":{"l":180.42,"v":519678},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":327502},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"024ee20f15d000a04fb289fc47aecb6907948ad752046c1777c5fd0be59237d8","t":1592965748}},{"t":1592965860,"p":{"ppi":{"l":180.42,"v":511341},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":319165},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"1a9f24aada30c5a5d23db746c87910daacaa21799bee8e6f8a91b338b7442aa3","t":1592965869}},{"t":1592965920,"p":{"ppi":{"l":180.43,"v":510922},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":318746},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36262}},"tx":{"h":"767ad7c9cd72e114aa1f7aa2760c4c665557a5227affcb55d00499ac98a4889d","t":1592965928}},{"t":1592965980,"p":{"ppi":{"l":180.43,"v":510788},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":318746},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"dc198c15fe64c6556f52ace44e4cdb9d027bb6a37460ac0a4b16a6c60e09f228","t":1592965989}},{"t":1592966040,"p":{"ppi":{"l":180.43,"v":510788},"bitfinex":{"l":180.6,"v":150182},"bittrex":{"l":180.37,"v":318746},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"973db9b49a24baf99ed128cd14cadbface41840f325946c21a8e62f80ed1e7c8","t":1592966048}},{"t":1592966160,"p":{"ppi":{"l":180.42,"v":485400},"bitfinex":{"l":180.6,"v":124794},"bittrex":{"l":180.37,"v":318746},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"1c8ad486ea5d358497d7ec23abad7b1224eddcff8e3023724904bbb9f71df936","t":1592966168}},{"t":1592966220,"p":{"ppi":{"l":180.42,"v":485400},"bitfinex":{"l":180.6,"v":124794},"bittrex":{"l":180.37,"v":318746},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"946e8715c30708b07d332f9e9ab1abe34a5b0095579eb835c2d9b47f2901c6fb","t":1592966228}},{"t":1592966280,"p":{"ppi":{"l":180.42,"v":482931},"bitfinex":{"l":180.6,"v":124794},"bittrex":{"l":180.37,"v":316277},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"1b0f4715326e91a6176168cfd35c4171455ba31c9aafdee740c395883fb96dc2","t":1592966289}},{"t":1592966340,"p":{"ppi":{"l":180.42,"v":482336},"bitfinex":{"l":180.6,"v":124794},"bittrex":{"l":180.37,"v":315682},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"62581dba9de71f1d01ed275bacbb3202822089801ea352e329db0102f9d72801","t":1592966348}},{"t":1592966460,"p":{"ppi":{"l":180.42,"v":482336},"bitfinex":{"l":180.6,"v":124794},"bittrex":{"l":180.37,"v":315682},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"fca0d9833a7dd9dd8dfea5cd1429624185073d18b599a3941ce6e958e0afdfe3","t":1592966468}},{"t":1592966520,"p":{"ppi":{"l":180.42,"v":482336},"bitfinex":{"l":180.6,"v":124794},"bittrex":{"l":180.37,"v":315682},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"1c5814294798465829766e425f13c2962726d55eba7f54eef18746bedb23328c","t":1592966528}},{"t":1592966580,"p":{"ppi":{"l":180.43,"v":482613},"bitfinex":{"l":180.64,"v":125071},"bittrex":{"l":180.37,"v":315682},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"ec0039173658bc18ffa6cbdab513dc6e1619b4a34b150bd1c0df77ee8884ac5b","t":1592966588}},{"t":1592966640,"p":{"ppi":{"l":180.43,"v":480788},"bitfinex":{"l":180.64,"v":125071},"bittrex":{"l":180.37,"v":313857},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"37b3a8827482e1f6b0557bdf3b93b44cff7ca5aaac2c53318f497b416bb1742f","t":1592966648}},{"t":1592966760,"p":{"ppi":{"l":180.43,"v":480048},"bitfinex":{"l":180.66,"v":125335},"bittrex":{"l":180.37,"v":312853},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36128}},"tx":{"h":"26a59def16c00645fbaabff916483df811de6448dc67fb3ddecd3f79596abd87","t":1592966768}},{"t":1592966820,"p":{"ppi":{"l":180.44,"v":478717},"bitfinex":{"l":180.67,"v":125597},"bittrex":{"l":180.37,"v":311360},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36028}},"tx":{"h":"1747f01e94757d3ccb3736195f13a7c6a613dc8339ca7f0c9808008c7a182c96","t":1592966828}},{"t":1592966880,"p":{"ppi":{"l":180.44,"v":474862},"bitfinex":{"l":180.67,"v":125597},"bittrex":{"l":180.37,"v":307505},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36028}},"tx":{"h":"0187c219fdfb351c71cb4517f906044845bc61a4b3f4948422304372614bf241","t":1592966888}},{"t":1592966940,"p":{"ppi":{"l":180.45,"v":475140},"bitfinex":{"l":180.71,"v":125875},"bittrex":{"l":180.37,"v":307505},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36028}},"tx":{"h":"6b93d78cc5de9e7ec9241e5950180cae082b2b5b4b3a043c522c6379d2302d60","t":1592966955}},{"t":1592967060,"p":{"ppi":{"l":180.45,"v":472019},"bitfinex":{"l":180.74,"v":122754},"bittrex":{"l":180.37,"v":307505},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36028}},"tx":{"h":"3c51f1b4a6c24ee8fb4e9695c70c393e5f22b0c8c00e6280ac250fd9de015cd9","t":1592967068}},{"t":1592967120,"p":{"ppi":{"l":180.45,"v":472019},"bitfinex":{"l":180.74,"v":122754},"bittrex":{"l":180.37,"v":307505},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36028}},"tx":{"h":"ccd76e830939a2a4ab52ed324b263702e356c12385c85bc92168b28b2f5333c5","t":1592967184}},{"t":1592967180,"p":{"ppi":{"l":180.43,"v":472207},"bitfinex":{"l":180.65,"v":122942},"bittrex":{"l":180.37,"v":307505},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.36,"v":36028}},"tx":{"h":"54875090443ef39ece956c0b141c5ec09ca583cbc216ee691816e9dc74528a1f","t":1592967189}},{"t":1592967240,"p":{"ppi":{"l":180.48,"v":472330},"bitfinex":{"l":180.65,"v":122942},"bittrex":{"l":180.49,"v":307627},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":179.96,"v":36029}},"tx":{"h":"4f483316148446e14490b614171a997fdddc3bcb3bbd2ca1f46c722712169869","t":1592967248}},{"t":1592967360,"p":{"ppi":{"l":180.48,"v":472552},"bitfinex":{"l":180.67,"v":123206},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":179.96,"v":36029}},"tx":{"h":"3944f847f5c548856a3c78dd4d6ee82426837d50364b565da169c1d619db4769","t":1592967368}},{"t":1592967420,"p":{"ppi":{"l":180.52,"v":473614},"bitfinex":{"l":180.8,"v":124268},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":179.96,"v":36029}},"tx":{"h":"5f3635251098ec7a927aeb8cde20d0013694d1cd721f137af7ca4335b2481656","t":1592967428}},{"t":1592967480,"p":{"ppi":{"l":180.53,"v":473614},"bitfinex":{"l":180.8,"v":124268},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36029}},"tx":{"h":"701059365de889e64f5c381d0f02804d060b95262ab0230562ffd75758eae00e","t":1592967488}},{"t":1592967540,"p":{"ppi":{"l":180.5,"v":473775},"bitfinex":{"l":180.67,"v":124428},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"bfbc040bf16e96639de9d63abdf65d92713e114f1ad63b745e45c7be349873c3","t":1592967548}},{"t":1592967660,"p":{"ppi":{"l":180.51,"v":474060},"bitfinex":{"l":180.72,"v":124713},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"fa992a63a6457622e6d905f002fd872ebed6f71f7eed9eefbad3224828bd7ba2","t":1592967669}},{"t":1592967720,"p":{"ppi":{"l":180.54,"v":476627},"bitfinex":{"l":180.81,"v":127280},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"676c231553fb2f8cb3c8f03073a1d1c1499d2d08189c254b3d1d2a8d90b99266","t":1592967728}},{"t":1592967780,"p":{"ppi":{"l":180.4,"v":478922},"bitfinex":{"l":180.31,"v":129575},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"5fe21843d7d5beb2b07bf373dc8cd15035e160ce50c27cd4f06f98b9354f9295","t":1592967788}},{"t":1592967840,"p":{"ppi":{"l":180.4,"v":478922},"bitfinex":{"l":180.31,"v":129575},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"8d24225f626dc4ceb79dca24429089452649777fafb4e4dc6a0529c3f1927943","t":1592967849}},{"t":1592967960,"p":{"ppi":{"l":180.39,"v":475189},"bitfinex":{"l":180.27,"v":125842},"bittrex":{"l":180.49,"v":307585},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"85d546536f32ecae0054921173acd1bfdfd5e600bb8adf1facdadaae12cb1ed5","t":1592967968}},{"t":1592968020,"p":{"ppi":{"l":180.08,"v":476117},"bitfinex":{"l":180.18,"v":126029},"bittrex":{"l":180.04,"v":308326},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"448e7fbea0dfbb278976cdb3b899d0b220abaf31aab069bae6922889cfcb84a0","t":1592968027}},{"t":1592968080,"p":{"ppi":{"l":180.07,"v":476494},"bitfinex":{"l":180.18,"v":126029},"bittrex":{"l":180.03,"v":308703},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"23702d12200ee105ea5f597c4239870a4dc62d0a9bb5206fb7bb786bbe51a977","t":1592968088}},{"t":1592968140,"p":{"ppi":{"l":180.04,"v":477116},"bitfinex":{"l":180.09,"v":126216},"bittrex":{"l":180.01,"v":309138},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"99cec3e6b21b42a994c5b2bab4cdec58ca9b5c6e926df1007e223de23cc5ca40","t":1592968149}},{"t":1592968260,"p":{"ppi":{"l":180.02,"v":474425},"bitfinex":{"l":180.02,"v":126417},"bittrex":{"l":180.01,"v":306246},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"5f46ceef1d4271ab0c106110034a029a72f9d2db9fc8d84f684d922625f3a2dc","t":1592968268}},{"t":1592968320,"p":{"ppi":{"l":180.02,"v":468937},"bitfinex":{"l":180.02,"v":126417},"bittrex":{"l":180.01,"v":300758},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"aecf091ec67cc295f5cf6e3522c73dcc7021f14c4d5df231d6c953b9270d9d44","t":1592968328}},{"t":1592968380,"p":{"ppi":{"l":180.03,"v":469157},"bitfinex":{"l":180.06,"v":126637},"bittrex":{"l":180.01,"v":300758},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"9db5f79d7c88b08bafc743895619ac21221bc6ed22165057356ab3475b4bf045","t":1592968388}},{"t":1592968440,"p":{"ppi":{"l":180.03,"v":466974},"bitfinex":{"l":180.06,"v":126637},"bittrex":{"l":180.01,"v":298575},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"7e259599bcd010dc2822947f56e77ea0a28b5e4429fd2f728e7939443c0a724e","t":1592968448}},{"t":1592968560,"p":{"ppi":{"l":180.03,"v":464506},"bitfinex":{"l":180.06,"v":126637},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"688f78ecb527fab39e6d28c36cee043454856a9fa9483b5a25f28cd9af07cc52","t":1592968568}},{"t":1592968620,"p":{"ppi":{"l":180.03,"v":464506},"bitfinex":{"l":180.06,"v":126637},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"cfccfac27bbc05dd3b87119c8e446b1b05fe7c31e73a927b64d136ccef1fee94","t":1592968628}},{"t":1592968680,"p":{"ppi":{"l":180.03,"v":464506},"bitfinex":{"l":180.06,"v":126637},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"ed0daf50fa48019bc79a02634ebef5032bcc1028f6490785b72dc6ca5c3c0c70","t":1592968688}},{"t":1592968740,"p":{"ppi":{"l":180.03,"v":464506},"bitfinex":{"l":180.06,"v":126637},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"af0c3d064d9911e65680ed9f1edc756dc715b9bf935a73c73fd02aee9bf36a04","t":1592968748}},{"t":1592968860,"p":{"ppi":{"l":180.03,"v":462939},"bitfinex":{"l":180.06,"v":125070},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"5ffcdd14b3920c83e6c4ef1cbac171faf64e545849c29f80661b7ee77cd8c450","t":1592968868}},{"t":1592968920,"p":{"ppi":{"l":180.03,"v":462939},"bitfinex":{"l":180.06,"v":125070},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":36030}},"tx":{"h":"e6c4b9d6613256fec77a53a5a23bbbbbbb80b96c4c84d1e62a3a32e547ffe87a","t":1592968985}},{"t":1592968980,"p":{"ppi":{"l":180.03,"v":462318},"bitfinex":{"l":180.06,"v":125070},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"a17039f6951dcc2a2a61cb424df0df32b7ed858382be87cf532bc23ac6bff94d","t":1592968988}},{"t":1592969040,"p":{"ppi":{"l":180.03,"v":462318},"bitfinex":{"l":180.06,"v":125070},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"0569bb8ebe5e67e11012c7eafd0983295627dd3108f776c50237dd55c93668f8","t":1592969048}},{"t":1592969160,"p":{"ppi":{"l":180.03,"v":462318},"bitfinex":{"l":180.06,"v":125070},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"e2f656974aeff95cda94aec7cdbbf12fd72e5b8b59d62b999aa07cf3f851e2df","t":1592969168}},{"t":1592969220,"p":{"ppi":{"l":180.03,"v":462318},"bitfinex":{"l":180.06,"v":125070},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"3fc64a6039990863230be12a2a5947757a7a0dcb34e179b19eaef642a0572646","t":1592969228}},{"t":1592969280,"p":{"ppi":{"l":180.01,"v":462457},"bitfinex":{"l":180.01,"v":125209},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"077963f3016724d1cb0b431144d9e48fbf9162123d5b4ee6084ad269a16497ff","t":1592969288}},{"t":1592969340,"p":{"ppi":{"l":180.01,"v":462457},"bitfinex":{"l":180.01,"v":125209},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"767966d3bba9d58d892dbd91c5a4be401c0d8b2a68c446e461c5c57d4814a489","t":1592969348}},{"t":1592969460,"p":{"ppi":{"l":179.98,"v":463096},"bitfinex":{"l":179.88,"v":125848},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"5f18b012ab4d39d8f90f8eb3a5df3d4f308b4d2d5620ff89f07119ad5b07a75d","t":1592969468}},{"t":1592969520,"p":{"ppi":{"l":179.98,"v":463096},"bitfinex":{"l":179.88,"v":125848},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"f8909f57f206e6d1ef51f247ee443c208c31412977303e14bed63effbf4558b8","t":1592969528}},{"t":1592969580,"p":{"ppi":{"l":179.98,"v":463096},"bitfinex":{"l":179.88,"v":125848},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"eb2edf2008858508ac5cbd220dbc6d06f27d6349d6edb06176e9317880ea9d53","t":1592969589}},{"t":1592969640,"p":{"ppi":{"l":179.98,"v":463096},"bitfinex":{"l":179.88,"v":125848},"bittrex":{"l":180.01,"v":296107},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"579bce0eb6e8bd06d7a9403a54aa4759bc231e5032be2cc837db1eba10d29e67","t":1592969649}},{"t":1592969760,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"bd7ab272fc72fbcd4a7e92589835dfb7b8c208be3993650777ca3ab8f95c269a","t":1592969768}},{"t":1592969820,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"0a611c9e3dee7813f95eda60128068b89ed592ff8858ad2d8c462f00492185bc","t":1592969828}},{"t":1592969880,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"6073c893f5733dedd055ff883701a0defe76bd820b954ae2f714715265c13d37","t":1592969888}},{"t":1592969940,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"a063695c93242d2d6f90ec45442f2a1679070aa5221b23c7a53c58072f116f3b","t":1592969948}},{"t":1592970060,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"3486e4b7b84a9fd0fbc6e68b0698ac52a1d19fb170491dccc3cbc9ac3913bae9","t":1592970068}},{"t":1592970120,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"2a960441a6f9c27080bf6eb7eb026d56b6fa61c7ce1c28d93f539ad069ace16c","t":1592970128}},{"t":1592970180,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"aac861e7d97b265d40524bb577422aedd0c7e029e899ded929d8dbe0770f5a9d","t":1592970189}},{"t":1592970240,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"5be80d1c12937c174203f6430d8f66097fb0a958781b77670e87fb9af5c44d33","t":1592970249}},{"t":1592970360,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"f188d78e22f7f951154ddddd2f2b7b72e64bccf3e577068945bc0c4e52daaa9f","t":1592970368}},{"t":1592970420,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"8a6cc48d85b12cf8c25d42b6ee9cde41a6a9ad5b5438930aabe0d195d6e06d11","t":1592970428}},{"t":1592970480,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"3f3075bfeac509c7174bdd3060b292c66a175343e6ea1e038c993d919a5b9f71","t":1592970488}},{"t":1592970540,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"47fb33e9b85faac0d131eeebda2884e280580112f5336303e6aa058f416676d2","t":1592970548}},{"t":1592970600,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"91bdcad4ceb6defedcc1c33bc2d051e9bca42582e12a2a889e06eed794b20c50","t":1592970609}},{"t":1592970660,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"d1ceb706af7478abf8ff2663b7214f29dfca1bf5b3a8836ef0064e06eee4e512","t":1592970668}},{"t":1592970720,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"8bb9067e4f198f0b9d251a174a704418523d68505277b252675936386546b6da","t":1592970786}},{"t":1592970780,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"56a775c3cd53241a6619b92f606bb9021b402d055d2afebbdc7d2e0d872f5af7","t":1592970788}},{"t":1592970840,"p":{"ppi":{"l":179.98,"v":460480},"bitfinex":{"l":179.88,"v":124997},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"bb9ee5ff1083d66217c909af5aea4248916ee901a5bdd0fa0d965c3826e9ebff","t":1592970848}},{"t":1592970960,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"33da209209636a5b1de37c2e87a08abcf24474749fb5ba05de754336d9f853e5","t":1592970968}},{"t":1592971020,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"d538170d2401bbb4e71bcc778278ad23028a7ee52265bbf94c020c763670096c","t":1592971028}},{"t":1592971080,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"fba0ffb2ae0a8019c646cfc8c94e2448a0e35e41ad4b14d805ea0aa732a69fb3","t":1592971088}},{"t":1592971140,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"42407fc43c6ea3ad755e612ca7d4573b50a8147f2c5b1533991930f5c3c931e3","t":1592971149}},{"t":1592971260,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"4d666d794aa8c6179212baf8e455abdd54cf7f96906a8dc49ffecf248cd8d37a","t":1592971268}},{"t":1592971320,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"4fbea48e664cfbc62809bde1e802cc653d366aaa7626badda8520d12a86b3901","t":1592971328}},{"t":1592971380,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"013682cde5c000868f20497e4556e7a06a8071187f25a2f2ae79f3924c0e9802","t":1592971389}},{"t":1592971440,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"6f5e3de6773d1e8a7d493996778d5cb62881be9141ce8770d9adfca0517932d3","t":1592971448}},{"t":1592971560,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"81e6b996c2460dbf90713d0af703063ceb726415440c669b59f6b2185a1276af","t":1592971568}},{"t":1592971620,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"407832420c01545cdf15c0de1ba85b8f2f6565e51a6b46c71669286b7f38a31b","t":1592971628}},{"t":1592971680,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"a8fc5c871d4fc5c0078af2d13ae57bb8bf9f837d4f3457ea880ca2b71641bb29","t":1592971688}},{"t":1592971740,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"25119ebd72d8e39a8c98a352dd05478826ad29db80d760febfb4d5cc7ea63025","t":1592971749}},{"t":1592971860,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"4a6c48450ae14afc037f8391ec6f9b9e4c9b1375b97237e196b414617c1dc3cc","t":1592971869}},{"t":1592971920,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"14c318ad8d47e4f2af86a8d64a39678ce46dc98518dc0ef95e78377c741cee80","t":1592971928}},{"t":1592971980,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"54c1dd7c4867ee58f268552d253904c3c865b7c2607152b7efdd692d42204fb2","t":1592971988}},{"t":1592972040,"p":{"ppi":{"l":180.03,"v":460699},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":180.01,"v":294342},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"b6f7740bf1f60f9bd848cef0239785957fca6cc1393ae58946ff951e29838353","t":1592972048}},{"t":1592972160,"p":{"ppi":{"l":179.79,"v":460888},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.64,"v":294531},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"b32ac1c9e6027b6a161a5d835cad4324738edef1e14050f8b8fb3d6a784d679d","t":1592972168}},{"t":1592972220,"p":{"ppi":{"l":179.78,"v":461356},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.63,"v":294999},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"e20762c943b33e99b3ea8526f12b6288506aa7178bdecef6754c86441e4ad5a1","t":1592972228}},{"t":1592972280,"p":{"ppi":{"l":179.78,"v":462361},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.63,"v":296004},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"955dd26a5ca9b6a61d29ab081a9c5ba104054b82296fadaff1121ccd2bb9fbc1","t":1592972288}},{"t":1592972340,"p":{"ppi":{"l":179.78,"v":462361},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.63,"v":296004},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"39bb840280b1074a99de4cdb0de856446ffaa63033666ef9b22fd33fd1e19cfe","t":1592972348}},{"t":1592972460,"p":{"ppi":{"l":179.64,"v":463588},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.41,"v":297231},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"659ccd3e7d57f36b5bfd7140575ff6062a4e7a773072c4b7c1a03ece4251aad8","t":1592972468}},{"t":1592972520,"p":{"ppi":{"l":179.64,"v":463588},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.41,"v":297231},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"dd3cc9d4c3297a12378b544e9107ed8db3f2e15a4960fc317a7fbc08cdba1ddc","t":1592972586}},{"t":1592972580,"p":{"ppi":{"l":179.64,"v":463588},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.41,"v":297231},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"fbcac9575a704882f28705cb10d984e9346ce9852417336d51663d082d69b5e2","t":1592972588}},{"t":1592972640,"p":{"ppi":{"l":179.64,"v":463588},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.41,"v":297231},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"b50fe11ad9814fdc253d4062f541588c373ceff7465b8b00061fb43c66dbb76d","t":1592972647}},{"t":1592972760,"p":{"ppi":{"l":179.64,"v":463943},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.41,"v":297586},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"325e77d28735ebf03ede89cadaf288fab94998284edfcb0311594e0e129062c1","t":1592972768}},{"t":1592972820,"p":{"ppi":{"l":179.64,"v":461913},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.41,"v":295556},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"474bbee596c9ac6da50ea035bd6f70b1a79e477ab25419163e56c4495116c273","t":1592972828}},{"t":1592972880,"p":{"ppi":{"l":179.48,"v":462409},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.15,"v":296052},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":35409}},"tx":{"h":"4b19d2ddb15315875d8360f58782af5f4745930dfaa2c810aa16ba710525935d","t":1592972888}},{"t":1592972940,"p":{"ppi":{"l":179.48,"v":461784},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.15,"v":296052},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"2398f23beb66936d5a50db9c453f317660123a61af32362abe1d60ba9830521f","t":1592972948}},{"t":1592973060,"p":{"ppi":{"l":179.45,"v":461854},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"932a18eb70fa43856cd0f24c1a59b66bf5f0d4417edbdab4c3d1187db312e2f1","t":1592973068}},{"t":1592973120,"p":{"ppi":{"l":179.45,"v":461854},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"ded9b6a2e050f8f6beb5c6cc1de1952ac79fda08df219fbd7ec3551ead19855a","t":1592973129}},{"t":1592973180,"p":{"ppi":{"l":179.45,"v":461854},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"8c2b53ff8e4f306c7c107a23313fbd2c7c1d0d18a51ba2aa20df8840259ba39f","t":1592973188}},{"t":1592973240,"p":{"ppi":{"l":179.45,"v":461854},"bitfinex":{"l":180.06,"v":125216},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"203f8f227ab37c5433b2c3b509af1d6afb8a0f16adc703adaca9c1c47da17ff3","t":1592973248}},{"t":1592973360,"p":{"ppi":{"l":179.45,"v":461609},"bitfinex":{"l":180.06,"v":124971},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"4938b7b9d231ff5ee45d3edf2644dba207fc55e918798ab9ec9871116414a6c4","t":1592973375}},{"t":1592973420,"p":{"ppi":{"l":179.45,"v":461609},"bitfinex":{"l":180.06,"v":124971},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"91c8e159f532565dd07a8adc7d3d3516ca4885c2e3cc3d5e9ed259d30ef7ee38","t":1592973428}},{"t":1592973480,"p":{"ppi":{"l":179.28,"v":464048},"bitfinex":{"l":179.44,"v":127410},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"2363d44a6785aa4f19fefb6c40a142ca501037cc7756d37ed107269b9a2fa768","t":1592973487}},{"t":1592973540,"p":{"ppi":{"l":179.28,"v":464048},"bitfinex":{"l":179.44,"v":127410},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"04115726325a1f12ff2ce483914cecca1838ed54fa8690291705eec1ca55d83c","t":1592973548}},{"t":1592973660,"p":{"ppi":{"l":179.28,"v":464048},"bitfinex":{"l":179.44,"v":127410},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"9314b5c935b5df7d47b6b80d56db5a22f19513a2662ce5361d4cdd6abce43f9e","t":1592973669}},{"t":1592973720,"p":{"ppi":{"l":179.28,"v":464048},"bitfinex":{"l":179.44,"v":127410},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"be09e075e2f6c6560c34b55b92a97c59ff4b81b93a2db8846f322bdd65979d4d","t":1592973729}},{"t":1592973780,"p":{"ppi":{"l":179.28,"v":464048},"bitfinex":{"l":179.44,"v":127410},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"3d8b3542f570b903e70c29061f2c48f8a776cbdb11910117c468a468caf81a96","t":1592973788}},{"t":1592973840,"p":{"ppi":{"l":179.28,"v":464048},"bitfinex":{"l":179.44,"v":127410},"bittrex":{"l":179.11,"v":296122},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"c4bf781224329c236ea286620c7cb9a2cb6b1445cf5cdae943d832a4e26c240a","t":1592973848}},{"t":1592973960,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"e25a18df0e1b1f05abaa0c8eddf2e6abd94d07ec8cd2b74de32cef681883aac3","t":1592973968}},{"t":1592974020,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"357748355e6a38cb933192bdcc693cb721266a038c255eb226adb93f9f89c1fa","t":1592974028}},{"t":1592974080,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"e903dfaf3d6a00ce2ce270cac6f38abd70692a232e5f04eab090e76d2ffe114a","t":1592974088}},{"t":1592974140,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"b1409e6ffea5867b1fb1c4ba0c372c86682bcd64b905b068c97f79c1cd350553","t":1592974148}},{"t":1592974260,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"26c4dbc1f5b2f68e2bb7c5cfd0313881ca57ceb2bd9b75ddd9a6d3e8ffd464a1","t":1592974268}},{"t":1592974320,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"b6cc33bbce60c023610ac8e261307e53434b93b047d402306015193d29b33f35","t":1592974387}},{"t":1592974380,"p":{"ppi":{"l":179.73,"v":465201},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.58,"v":296883},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"815af770c4012552d737239ec28d64c4d393f92f1869f87ca37b82640c95242f","t":1592974395}},{"t":1592974440,"p":{"ppi":{"l":179.94,"v":467255},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.91,"v":298937},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"76e10b08b959eca0c59d2dca9c93755b3701f4aefe847e92308ac74157af2e7a","t":1592974449}},{"t":1592974560,"p":{"ppi":{"l":179.94,"v":467255},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.91,"v":298937},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":34784}},"tx":{"h":"fa0098e9276c4bc844c695ae4b696e8dbdb059444c9649059692a3da6f2bb6ca","t":1592974568}},{"t":1592974620,"p":{"ppi":{"l":179.93,"v":449794},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.91,"v":298229},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":18031}},"tx":{"h":"8fac3cbbbc40ad382463fb5ab18b3dc0fbf15b031fdd293a94eaeb2e53379ae8","t":1592974628}},{"t":1592974680,"p":{"ppi":{"l":179.93,"v":451324},"bitfinex":{"l":179.98,"v":127802},"bittrex":{"l":179.91,"v":300263},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17527}},"tx":{"h":"e261ec72794a54a10d041362e1a0f77f24173b77300b0051f0b7f94e75db0130","t":1592974688}},{"t":1592974740,"p":{"ppi":{"l":180.01,"v":451679},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":300263},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17401}},"tx":{"h":"ae3b52de8fc614f7a2e55c460b941ebfd50eb03de25d6df69e2e0189cb2e8038","t":1592974748}},{"t":1592974860,"p":{"ppi":{"l":180.01,"v":450109},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17401}},"tx":{"h":"05b4135b62ec398378523408976730ac53c5f7f5a99ff5dce2822d45f21f95e7","t":1592974868}},{"t":1592974920,"p":{"ppi":{"l":180.01,"v":450109},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17401}},"tx":{"h":"ff50950ec52afcbfe0089cd001456d6c57d61b115d8d33e895cc269e1a6cc79e","t":1592974928}},{"t":1592974980,"p":{"ppi":{"l":180.01,"v":450109},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17401}},"tx":{"h":"085cea58fd94fe704a4d8bdd098cfb1a0c0c7e03fef696ec2e96716deb2f05aa","t":1592974989}},{"t":1592975040,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"3a1ccb9a476dbd5bf63e837819f97e7e6482a47ff6ffbb80badd608c86e196bd","t":1592975048}},{"t":1592975160,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"984b4be9bfcd55217ade548f9d4c9f9d977f5bdebca5b607c72ffad41f86a177","t":1592975168}},{"t":1592975220,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"2c32322e07967114b610bcba34b5d45f8107c20047581e715e300daf5bff77f7","t":1592975229}},{"t":1592975280,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"b0b043fb6064127deefbf56b53426216ed838b59d0ac8b6fc5ffcf9ccfc42a8d","t":1592975288}},{"t":1592975340,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"edaaba8db6f811c3e47dfae0362f3818b6cb0892516a3b4091d5220f94e4960c","t":1592975348}},{"t":1592975460,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"95127083d881bc491ff8ae3aaafbfd0acc67332c8dc51b85c367e167530fd56b","t":1592975468}},{"t":1592975520,"p":{"ppi":{"l":180.01,"v":450086},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":179.91,"v":298693},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"ae5b89128ff5b6f15600ab162988e54904b64c38dfc3c003acc2dcd956e4868c","t":1592975529}},{"t":1592975580,"p":{"ppi":{"l":180.24,"v":453058},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":180.26,"v":301665},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"ffc51c405ee0fa9bf709e023b25af64dbe9e3bbb9b14ed4842ecf77729b53122","t":1592975587}},{"t":1592975640,"p":{"ppi":{"l":180.18,"v":453076},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":180.16,"v":301683},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"e875da75dcea485f40734cfb30a230bb87133c4c71bb74c9d728723af0121edb","t":1592975648}},{"t":1592975760,"p":{"ppi":{"l":180.18,"v":453076},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":180.16,"v":301683},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17378}},"tx":{"h":"29085afcdf3be287e18d7395287fa3811a23b8a2cf6307560f21ceabc4e06af0","t":1592975768}},{"t":1592975820,"p":{"ppi":{"l":180.18,"v":452988},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":180.16,"v":301683},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"c0d3e83049a8f429baa56297ddc80240d905c26d26d8f1840baf24f4789d3692","t":1592975829}},{"t":1592975880,"p":{"ppi":{"l":180.18,"v":452988},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":180.16,"v":301683},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"85f080443b3e8b55ac12b2c7ec72574444943a6b6297b40fe87ee0a2866ee566","t":1592975888}},{"t":1592975940,"p":{"ppi":{"l":180.11,"v":453688},"bitfinex":{"l":180.25,"v":128283},"bittrex":{"l":180.06,"v":302383},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"748ca0efb9152549400c485e3adf5ea8cb5986477cd062d10a7e89f5d834b60c","t":1592975948}},{"t":1592976060,"p":{"ppi":{"l":180.11,"v":451461},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":302383},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"3e32a3c6245357782775fc809b45c86aa6bffab4137aedfb5aa314664c0c6ba2","t":1592976068}},{"t":1592976120,"p":{"ppi":{"l":180.11,"v":451461},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":302383},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"dcc6acb6256c165553b7b531ad67b0a5c82dbf57af24f36acb56eaf7f4aaff83","t":1592976128}},{"t":1592976180,"p":{"ppi":{"l":180.11,"v":451461},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":302383},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"76a26da6fce1912cb0e920a9d00d362ed9ebd61eed27c64abed625061e30529a","t":1592976188}},{"t":1592976240,"p":{"ppi":{"l":180.11,"v":451461},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":302383},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"d3c82aaeec94d866bb946ef440ffc51ac0b2ff1d7dc7b34207dd79b2c9843a88","t":1592976249}},{"t":1592976360,"p":{"ppi":{"l":180.11,"v":453496},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":304418},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"30d23c2c3d4f05f2958628f5e4a080d48eb4fac363961038ab3ec16e10a886dd","t":1592976368}},{"t":1592976420,"p":{"ppi":{"l":180.11,"v":454408},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":305330},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17290}},"tx":{"h":"caddf3203970784ad85f261cf971f5d11c652d465121c22944edec8e13875df5","t":1592976428}},{"t":1592976480,"p":{"ppi":{"l":179.89,"v":454164},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":179.73,"v":305335},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17041}},"tx":{"h":"30a70199292526b59ae5caf2416d6d8cdc7868015cde476247427ef9f0a71acf","t":1592976488}},{"t":1592976540,"p":{"ppi":{"l":179.89,"v":454164},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":179.73,"v":305335},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17041}},"tx":{"h":"b201c48e53d8eaca6e545d24fef4e34027cffd06e5c26c1520c338d7a630136e","t":1592976549}},{"t":1592976660,"p":{"ppi":{"l":179.89,"v":454164},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":179.73,"v":305335},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":17041}},"tx":{"h":"72098aeab0b4bcfdeb3d602d439cb390c6038c1429378ba07c25cdd89f880310","t":1592976668}},{"t":1592976720,"p":{"ppi":{"l":179.89,"v":453913},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":179.73,"v":305335},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"ffb0ea5e230d5d3ff420d3f15699f3e6c0ff66884f5241c5d7413eb922c5484f","t":1592976729}},{"t":1592976780,"p":{"ppi":{"l":180.11,"v":453994},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"791eee04ee42e3a37100d3057e41b8bec8a0d59e2a55c976e212aec823f43c1a","t":1592976788}},{"t":1592976840,"p":{"ppi":{"l":180.11,"v":453994},"bitfinex":{"l":180.25,"v":126056},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5732},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"70dd58e944fdc932d304fd5148d21bb7b5c88774a9ff9f8054ea8e1f203a5ba0","t":1592976849}},{"t":1592976960,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"07c581db7995893579459de7aea0f9c05780efff0e659f53838b385700a594e7","t":1592976969}},{"t":1592977020,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"c5913d15fd901d51d227a8a4b33d4ad4fa7e89f5de03bacbfe5b3957006eb297","t":1592977029}},{"t":1592977080,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"5325f9e055cfecfdcadffa177c2d8f760fbd951c016f37668352f55d52af35d8","t":1592977087}},{"t":1592977140,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"5cde6f7b99401a9dc813230c4d030c2ac32b21c3eb1064105a0021b377a66128","t":1592977148}},{"t":1592977260,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"17cbc72daae08b273bfa007f048f925d5f23a710448e7a9cfd5cc3567b6b5c60","t":1592977268}},{"t":1592977320,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"3e6e2826795ff93aacbbc35b29bcc9cee0fd5efc31ce49d550407c52ef89930a","t":1592977328}},{"t":1592977380,"p":{"ppi":{"l":180.11,"v":453338},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305416},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"c14a4872ac85d5df5d26053c30bbb5392b97e228d6645e094054c2e9cee851b2","t":1592977388}},{"t":1592977440,"p":{"ppi":{"l":180.11,"v":453314},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305392},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"66af2c571216f7253156aea03c703c5715a5fc57cf9bd7c93de1ecc4b4e5cbd1","t":1592977448}},{"t":1592977560,"p":{"ppi":{"l":180.11,"v":453314},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305392},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"e8f090e51118397b73017e6c13c6bd3c125165fc348b7e41f468b9d0c0a547df","t":1592977568}},{"t":1592977620,"p":{"ppi":{"l":180.11,"v":453314},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305392},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"0fa071e9e574434a8e4c6cfc28452d224eaee329aaf4778a22af504c724353b6","t":1592977628}},{"t":1592977680,"p":{"ppi":{"l":180.11,"v":453314},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":180.06,"v":305392},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"3b2ed16763a5504c1f595c21d40cf8538d95ba82d18a619bd5dd747511464daf","t":1592977688}},{"t":1592977740,"p":{"ppi":{"l":179.94,"v":453535},"bitfinex":{"l":180.25,"v":125976},"bittrex":{"l":179.81,"v":305613},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16790}},"tx":{"h":"3411c6da0ebe6e76549b63de7652805b7f09efa3d658a892bf901137f0acc3f4","t":1592977747}},{"t":1592977860,"p":{"ppi":{"l":179.94,"v":453272},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":179.81,"v":305613},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16541}},"tx":{"h":"8927b8c0e252e80e0f89dc215abdba00d755bb09a90a86c9e182a7238ce7e16a","t":1592977868}},{"t":1592977920,"p":{"ppi":{"l":179.94,"v":453272},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":179.81,"v":305613},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16541}},"tx":{"h":"02a84e6a8eebcbc3fb18184b9d21d99cb018f03bde43f60780760dadf4887995","t":1592977928}},{"t":1592977980,"p":{"ppi":{"l":179.94,"v":453272},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":179.81,"v":305613},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16541}},"tx":{"h":"6eabac22811f829991897e875acab2b214b38f4a9db5e42f925308156d294620","t":1592977989}},{"t":1592978040,"p":{"ppi":{"l":179.94,"v":452956},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":179.81,"v":305297},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16541}},"tx":{"h":"ba498664582080a783f177c5c45430209358981b855671c6d875b35bd6d59252","t":1592978048}},{"t":1592978160,"p":{"ppi":{"l":180.07,"v":453856},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180,"v":306197},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16541}},"tx":{"h":"58a6a7dbd73422ba8f58d0c6344038b1b36518fb1f5d3def62032482b5a26df3","t":1592978168}},{"t":1592978220,"p":{"ppi":{"l":180.07,"v":453799},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180,"v":306197},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16484}},"tx":{"h":"1932be876ab3d9f37708b940db3f3fbe6cc90c6a532a49f3327e51de6c7cb135","t":1592978228}},{"t":1592978280,"p":{"ppi":{"l":180.07,"v":451410},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180,"v":303808},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16484}},"tx":{"h":"81c365a6cfe3449ee1ea3b09a98d957a068ae2ee4f0ea557c482a585aa5a1560","t":1592978289}},{"t":1592978340,"p":{"ppi":{"l":180.07,"v":451410},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180,"v":303808},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.18,"v":16484}},"tx":{"h":"abefa3d98984f3275e5482f79b82029ab634e245fb543d6bc8426127b3fff01a","t":1592978348}},{"t":1592978460,"p":{"ppi":{"l":180.3,"v":458381},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180.36,"v":310773},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.9,"v":16490}},"tx":{"h":"bd55e0a6e77f8cbccfb804bce2e8aba2dbeec19d7d4b3935b6a2c37720912902","t":1592978468}},{"t":1592978520,"p":{"ppi":{"l":180.3,"v":458281},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180.36,"v":310773},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.9,"v":16390}},"tx":{"h":"e639a5ee01d0521bd2b6059e3c378394e070e7ae70437f8ad358ff6ff45b6ecb","t":1592978528}},{"t":1592978580,"p":{"ppi":{"l":180.3,"v":456354},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180.36,"v":308846},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.9,"v":16390}},"tx":{"h":"b8abff6b458a130274913c91e7553e557dfe475d33577e84e9ff73c4c8df371a","t":1592978588}},{"t":1592978640,"p":{"ppi":{"l":180.3,"v":456354},"bitfinex":{"l":180.25,"v":125962},"bittrex":{"l":180.36,"v":308846},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.9,"v":16390}},"tx":{"h":"75b492c54805cf81a982bcaa77be2d79d3eee2642e1fced7d7c5bf8585184bce","t":1592978648}},{"t":1592978760,"p":{"ppi":{"l":180.48,"v":455800},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.36,"v":308846},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":16400}},"tx":{"h":"f1dc9d71f76af6eeef5d92b767014d0ff4a710ef03ebc77b10a498fdf2cb77dc","t":1592978769}},{"t":1592978820,"p":{"ppi":{"l":180.48,"v":455800},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.36,"v":308846},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":16400}},"tx":{"h":"edbea6099722bcb7aeb8f3688131403277592a823266eb5d1d16e51ad381236f","t":1592978828}},{"t":1592978880,"p":{"ppi":{"l":180.48,"v":462146},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.36,"v":308846},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":22746}},"tx":{"h":"8284d67e489ccf4c0489f5a2b1a982c93a7f350550ba32e472035f2e7518733c","t":1592978888}},{"t":1592978940,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"fdde1ed6aa407d3fb7c2c3f4c569a2e13d883b9f0fb918316ec724accf4af11b","t":1592978947}},{"t":1592979060,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c1e581f30475bc0c0b3b10bc12eb9ba544127cea98b5e6909c16727dd6e2133e","t":1592979068}},{"t":1592979120,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c456f45050ecbc7d40235e589332bd0c990b5eecebc8519d79fdc03d0cbea644","t":1592979128}},{"t":1592979180,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"93970fd93f8cbcfbd40b8dc8ebeae5a3d5ec81441413c25268249ed730d9cee4","t":1592979188}},{"t":1592979240,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c2f47ead2ec7911e7c289a944728f852b23259d9308e8a4b25c1ef1d6acedfe0","t":1592979248}},{"t":1592979360,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"b95ee415bcc880b82f3cd2ffe770678f1c5886b1a5e26a7e076381cf5c8cf563","t":1592979369}},{"t":1592979420,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"69343de7800a65b0b2e0dea558d0e77cac802e38ff3fa563bff253b51fc5fde4","t":1592979428}},{"t":1592979480,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"ee773d14fdfccdcb9a0a1424481c6fa57c7890da9f12d5e987796a805bc1342b","t":1592979488}},{"t":1592979540,"p":{"ppi":{"l":180.55,"v":470832},"bitfinex":{"l":180.83,"v":125398},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"20577d2d2d0086f7967eb0d3f076143a55d015881c6e1ecb3b1bb74130a0638e","t":1592979548}},{"t":1592979660,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"dded1036e9fb70e102678a3c8909d055a1717b35be543467e954cb4b6d265cab","t":1592979668}},{"t":1592979720,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"940dae838a5d7ceb1f3de7142a2acbe8c75a46aa35a7f41007a84cd1ed8b3673","t":1592979728}},{"t":1592979780,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"f1e4071e4a54cd16eaff71d70d0902657090b9a95a5970f7c7f6db76a7b153b3","t":1592979789}},{"t":1592979840,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"939faf362bd7e647f28e07a300411a81700d6187141ca45282543b29b4f5eba5","t":1592979848}},{"t":1592979960,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"4bd58e88180c1b04618721b941721ea32d1875f2519db91c33ee49c2ab235e02","t":1592979968}},{"t":1592980020,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"38240d2925fe2d1853ca1bdcf10dbe07a72edc8a0a623667841bf9aa3becb5bd","t":1592980028}},{"t":1592980080,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"3c789d3681f2d2b0d669966ce49f05e533814bb4c5c016252b91dba80e8be86b","t":1592980088}},{"t":1592980140,"p":{"ppi":{"l":180.59,"v":470194},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":311277},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"f586bff588d243cd01fcde5a28f322f933989628cf36cb3b97d6e48e5f9d5933","t":1592980148}},{"t":1592980260,"p":{"ppi":{"l":180.59,"v":469856},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"32f7359090067b20eb8ad22ede24372bcecbf8f7e10c6faffea1054661371284","t":1592980268}},{"t":1592980320,"p":{"ppi":{"l":180.59,"v":469856},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"719660508637b7cf7f8182cd9de906be62b0e831b1f7c770409dfe5f573c0b46","t":1592980328}},{"t":1592980380,"p":{"ppi":{"l":180.59,"v":469856},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"b2371ccbbea4b701812bf4e32f18bec7ceba502ad665e24e66e7df55cc1ee132","t":1592980389}},{"t":1592980440,"p":{"ppi":{"l":180.59,"v":469856},"bitfinex":{"l":180.98,"v":124760},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c1d8895916d50d8d4998b3734a46f527f75d863718bc88d361ef527294fa88e0","t":1592980448}},{"t":1592980560,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"3b807ecec14e33d383af541a4205c95694fa321405e47d32aa985fc26c0e8669","t":1592980569}},{"t":1592980620,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"b0aad20b6d4255aeea0f347fb014d41df4e7ee7546f066cdfd71fc02b7060f23","t":1592980628}},{"t":1592980680,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"e8da59e6e02151a58b60ceb1b5eb4dad478f3a9a80e3e5538f2eb5ceffcb940b","t":1592980688}},{"t":1592980740,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"959c2016cbe14144dfaa2ac7defe8690c1a35e0504c5f967487f4113aea9f427","t":1592980748}},{"t":1592980860,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"b2c2278ba1be7197cd4a7a1ab7b7ef150b107111d28fcf88722498f06fe0a8b0","t":1592980868}},{"t":1592980920,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"d95ee222967155384e65a72d44969058bde22ab39c9226eb17b87dc72ae7b433","t":1592980928}},{"t":1592980980,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"f511980b9c12873ba78b503539e8961371a4e2e97cd2b4851422318b4621ace3","t":1592980988}},{"t":1592981040,"p":{"ppi":{"l":180.58,"v":467762},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.47,"v":310939},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"15c723b7ba69d6ffc83c275c08e7e2b905452a0ba12644bffec879d306fc202d","t":1592981048}},{"t":1592981160,"p":{"ppi":{"l":180.41,"v":468259},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c945e6fd6ce0e54a67fcfefc642ca854963efc68d50189878eb1df7358fec6e0","t":1592981168}},{"t":1592981220,"p":{"ppi":{"l":180.41,"v":468259},"bitfinex":{"l":180.98,"v":122666},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"795659394b8e5ae0081c016870e69310eb83cbf9ac45a4a3bb88710958c54679","t":1592981228}},{"t":1592981280,"p":{"ppi":{"l":180.34,"v":468708},"bitfinex":{"l":180.7,"v":123115},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"dee2fdc1c8572244d3f435d9bc93762770586f77d96a31d0256418cf945ed21c","t":1592981288}},{"t":1592981340,"p":{"ppi":{"l":180.34,"v":468708},"bitfinex":{"l":180.7,"v":123115},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c4739032e32ae19e4f3ecc89f33087960c042f54adb5bbc356ed2f850fda4ca7","t":1592981348}},{"t":1592981460,"p":{"ppi":{"l":180.34,"v":468527},"bitfinex":{"l":180.7,"v":122934},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"fd75bd5838bbc1d381c04b99e72a39eac3ee15cba8b0d544ebbccf6214a610b3","t":1592981468}},{"t":1592981520,"p":{"ppi":{"l":180.34,"v":469085},"bitfinex":{"l":180.72,"v":123492},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"4a95ae55486c5d8fb19e46a87922bde9663a758550d0e5506006f816152045d9","t":1592981528}},{"t":1592981580,"p":{"ppi":{"l":180.34,"v":469085},"bitfinex":{"l":180.72,"v":123492},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"e00960164565a2ed533e48ce497d006c12bfcd474ad01401b7f0bf3ae2421090","t":1592981590}},{"t":1592981640,"p":{"ppi":{"l":180.34,"v":469085},"bitfinex":{"l":180.72,"v":123492},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"120c3671fa57203e51d2c3b9ccb8fef6dc0005716df9629b58384b5a26ddfdc2","t":1592981648}},{"t":1592981760,"p":{"ppi":{"l":180.34,"v":469085},"bitfinex":{"l":180.72,"v":123492},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"b8c0826cd668b2613605e06290242bd7d24b6f81c5ed62c6395e4266e30b04d2","t":1592981768}},{"t":1592981820,"p":{"ppi":{"l":180.34,"v":469085},"bitfinex":{"l":180.72,"v":123492},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"3ba24143a674e95bb12ac2cf68961f4a4e537abfdc0e7c3d48b64e140b863f8b","t":1592981828}},{"t":1592981880,"p":{"ppi":{"l":180.34,"v":469085},"bitfinex":{"l":180.72,"v":123492},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"950875c99492301b864ee629dd91ab31c56c54f68b4c54cb7960d43f1382e05f","t":1592981888}},{"t":1592981940,"p":{"ppi":{"l":180.35,"v":469441},"bitfinex":{"l":180.73,"v":123848},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"332dc6390b92f856139931097f644b4de179cddc5fbf6c989e34381c16a882a1","t":1592981948}},{"t":1592982060,"p":{"ppi":{"l":180.35,"v":469965},"bitfinex":{"l":180.73,"v":124372},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"0993482afed13facb8cc1661d61b2c647b65bae083aef3d9199c774d2b602994","t":1592982069}},{"t":1592982120,"p":{"ppi":{"l":180.35,"v":469965},"bitfinex":{"l":180.73,"v":124372},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"94d5b90803c212273ba4ed738ed95cf7e61e703657efc694ac0bcaf7f6ee4391","t":1592982129}},{"t":1592982180,"p":{"ppi":{"l":180.35,"v":469965},"bitfinex":{"l":180.73,"v":124372},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"f222fc243c04c7462f56dc11f5cc7b22ad2426460a5dd48344c56b523aed33bb","t":1592982188}},{"t":1592982240,"p":{"ppi":{"l":180.35,"v":469965},"bitfinex":{"l":180.73,"v":124372},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"a2614b430c823889d11731403624b220d17f902457296c48ac215da381a6491d","t":1592982248}},{"t":1592982360,"p":{"ppi":{"l":180.35,"v":469965},"bitfinex":{"l":180.73,"v":124372},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"ca69e63e22fdf966f9bcc38cc7207fc58d76cc65692e536d35f1cacf455c74cd","t":1592982368}},{"t":1592982420,"p":{"ppi":{"l":180.35,"v":470892},"bitfinex":{"l":180.73,"v":125299},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"852f10f89321e34be154bdac7cdce7d62687c37a03b98143b3fcc3dbc90e162c","t":1592982428}},{"t":1592982480,"p":{"ppi":{"l":180.34,"v":471053},"bitfinex":{"l":180.71,"v":125460},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"9cb5bddb9e94726f1c5db6a04d9d890146585020ce092573edf8bdb3413cb0ca","t":1592982488}},{"t":1592982540,"p":{"ppi":{"l":180.34,"v":471053},"bitfinex":{"l":180.71,"v":125460},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"50ff02f78b99f4e21e27841df2253e34e8db56ccd6bfd978f180eb1757cd661c","t":1592982549}},{"t":1592982660,"p":{"ppi":{"l":180.34,"v":471417},"bitfinex":{"l":180.71,"v":125824},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"978bbc30c5c1357c1a044b47122861ef69aa6af087000597565a3d00d85ed653","t":1592982668}},{"t":1592982720,"p":{"ppi":{"l":180.34,"v":472109},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"c897db2a48d5ea3e730f7191621439ca5c0825b0d89cb4945e8a0ae28181c61f","t":1592982728}},{"t":1592982780,"p":{"ppi":{"l":180.34,"v":472109},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"976de7d3ea163181f86c2ef35eb78686f92fe3d7c7f8549ca30c7e7e09ea573d","t":1592982788}},{"t":1592982840,"p":{"ppi":{"l":180.34,"v":472109},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":311436},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"4e25b075333bb6df491895404799338da18814508cf9d76b2991920956b73a23","t":1592982847}},{"t":1592982960,"p":{"ppi":{"l":180.34,"v":472905},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":312232},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"e57f05cefa7d93b4a492c779d4f7973733bc0831608f4d022629d7870db63619","t":1592982968}},{"t":1592983020,"p":{"ppi":{"l":180.34,"v":472905},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":312232},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"b4a90173bc32d787919045dd85a42925e459423792967a3caadc0011d1dda388","t":1592983028}},{"t":1592983080,"p":{"ppi":{"l":180.34,"v":472905},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":312232},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":180.37,"v":29001}},"tx":{"h":"413ab1ad7b20b7ceb4876d3b404c94743cda00492df75ffcbf5a6a243bae86fc","t":1592983088}},{"t":1592983140,"p":{"ppi":{"l":180.31,"v":473125},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":312232},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.82,"v":29221}},"tx":{"h":"feb98517f0a53a9afb4ab765d6681fc6ce1b94d7a2170e38e2010dfceffdfd8f","t":1592983148}},{"t":1592983260,"p":{"ppi":{"l":180.31,"v":471396},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":310503},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.82,"v":29221}},"tx":{"h":"2cdd81c961245e2579aba1d7ae9c8d532b8da2cfd78f9f6bee9032c74d52c620","t":1592983269}},{"t":1592983320,"p":{"ppi":{"l":180.31,"v":471396},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":180.21,"v":310503},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.82,"v":29221}},"tx":{"h":"c0109086373723b452d5f729b07c0229a755877cff659322a82d7fcf881f5e26","t":1592983329}},{"t":1592983380,"p":{"ppi":{"l":180.15,"v":472206},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":179.97,"v":311313},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.82,"v":29221}},"tx":{"h":"297f7879f2f3b368355b1313270a60e918cdd14435cd73f233bfb066c3757b3e","t":1592983391}},{"t":1592983440,"p":{"ppi":{"l":180.15,"v":472206},"bitfinex":{"l":180.7,"v":126516},"bittrex":{"l":179.97,"v":311313},"okcoin":{"l":179.31,"v":5156},"poloniex":{"l":179.82,"v":29221}},"tx":{"h":"a16eeaae86dc39820c7c92d4632a3192e3ec8b8ec990df77ca774e6edde65177","t":1592983463}},{"t":1592983560,"p":{"ppi":{"l":178,"v":494231},"bitfinex":{"l":177.7,"v":126480},"bittrex":{"l":178.2,"v":332802},"okcoin":{"l":177.82,"v":5728},"poloniex":{"l":177.05,"v":29221}},"tx":{"h":"87cf47fc189e7d30ce46f0370b2d4f7bfbecd8ea821c80825247b1ccc8e7829a","t":1592983569}},{"t":1592983620,"p":{"ppi":{"l":178.09,"v":499288},"bitfinex":{"l":177.7,"v":126480},"bittrex":{"l":178.34,"v":333922},"okcoin":{"l":177.82,"v":5728},"poloniex":{"l":177.05,"v":33158}},"tx":{"h":"19789d6d92ce09a3d808add16c59519cd058399d9bd5fbcec426e1d66828e02e","t":1592983629}},{"t":1592983680,"p":{"ppi":{"l":178.09,"v":500397},"bitfinex":{"l":177.7,"v":126480},"bittrex":{"l":178.34,"v":334485},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":33158}},"tx":{"h":"aa5f04a35ec690fb22b4cd6bdece655e4903e81d766bbeb7778ef18993aa9090","t":1592983688}},{"t":1592983740,"p":{"ppi":{"l":178.31,"v":503470},"bitfinex":{"l":178.58,"v":129340},"bittrex":{"l":178.34,"v":334698},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":33158}},"tx":{"h":"3152e8978117d9903e098da97fab22f7aa8bf6d5bc063bd2a6e893f7cc61c040","t":1592983748}},{"t":1592983860,"p":{"ppi":{"l":178.09,"v":508736},"bitfinex":{"l":178.58,"v":129340},"bittrex":{"l":178,"v":339964},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":33158}},"tx":{"h":"423e0a7498b95b694f182a65e0b043a0830a7f80e41c91cf4cd4f0ffcf89604e","t":1592983875}},{"t":1592983920,"p":{"ppi":{"l":178.09,"v":508114},"bitfinex":{"l":178.58,"v":129340},"bittrex":{"l":178,"v":339964},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"21e7776cc9e7510cdcc6c397ce165cbe50ba2d2b47abe465eb87fc5466529f0b","t":1592983935}},{"t":1592983980,"p":{"ppi":{"l":178.09,"v":508395},"bitfinex":{"l":178.58,"v":129340},"bittrex":{"l":178,"v":340245},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"2ae5d2abc6f6a5d3738c1a41f9ae4d510b5c7051407f2a6834bfd33feb62fa59","t":1592983991}},{"t":1592984040,"p":{"ppi":{"l":178.09,"v":508395},"bitfinex":{"l":178.58,"v":129340},"bittrex":{"l":178,"v":340245},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"cb0f205f34e510e8340f5d6fddd647eb553dfb771b93b067b3ee7d338c0f05b3","t":1592984048}},{"t":1592984160,"p":{"ppi":{"l":177.96,"v":508039},"bitfinex":{"l":178.09,"v":128984},"bittrex":{"l":178,"v":340245},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"580b915bdebede5f4f4bca78766e17b3fab4a2b37667db62c7eaf150290b0527","t":1592984169}},{"t":1592984220,"p":{"ppi":{"l":177.89,"v":510949},"bitfinex":{"l":178.09,"v":128984},"bittrex":{"l":177.89,"v":343155},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"2410b63ea057a2ae64064ec2d7da6f963f50c1fb06f0945650d176004866614c","t":1592984256}},{"t":1592984280,"p":{"ppi":{"l":177.54,"v":511676},"bitfinex":{"l":177.44,"v":128573},"bittrex":{"l":177.61,"v":344293},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"cb5458ee0b4f2e26c195e9789acf08af036e7ea6007f609b01220d19d0127ba4","t":1592984295}},{"t":1592984340,"p":{"ppi":{"l":177.58,"v":511811},"bitfinex":{"l":177.62,"v":128708},"bittrex":{"l":177.61,"v":344293},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"3e3db93afb1f6d798552309c6e3f91d109d6080b5e1310bafa83f7eaf59ab803","t":1592984348}},{"t":1592984460,"p":{"ppi":{"l":177.58,"v":511811},"bitfinex":{"l":177.62,"v":128708},"bittrex":{"l":177.61,"v":344293},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"8705378d45bca0e37972531fc6e6979888cc5cc9f5bdb427d7996bf6eac3e602","t":1592984468}},{"t":1592984520,"p":{"ppi":{"l":177.59,"v":511936},"bitfinex":{"l":177.67,"v":128833},"bittrex":{"l":177.61,"v":344293},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"eb05ca72dfd0d8f643029a143523d57fde18513c523d9fccc4cb1b38bc782d55","t":1592984528}},{"t":1592984580,"p":{"ppi":{"l":177.4,"v":513293},"bitfinex":{"l":177.67,"v":128833},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"17b3c910f7f3357aacef1907e548ce59c26a497bb6f1900ae1097a90cd60fe46","t":1592984589}},{"t":1592984640,"p":{"ppi":{"l":177.4,"v":513293},"bitfinex":{"l":177.67,"v":128833},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.05,"v":32536}},"tx":{"h":"ae5b537768a6b04659f094af73338acebac902d336bc22feb4e682b6e28b3030","t":1592984648}},{"t":1592984760,"p":{"ppi":{"l":177.42,"v":514173},"bitfinex":{"l":177.67,"v":128833},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"612a1545124d18a397940b3cc3940391f8249c8af25baf591925972b1f08142d","t":1592984768}},{"t":1592984820,"p":{"ppi":{"l":177.42,"v":514173},"bitfinex":{"l":177.67,"v":128833},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"03c8f2d9b65d0415cc622f29cc4653ff5fb5ace08ad5f62eac5a771640bf29a6","t":1592984835}},{"t":1592984880,"p":{"ppi":{"l":177.59,"v":514723},"bitfinex":{"l":178.36,"v":129383},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"c24c1c00008cae2120811b8bbf1085614cb1a4d193a87e082ab695eb00d1b553","t":1592984888}},{"t":1592984940,"p":{"ppi":{"l":177.59,"v":514723},"bitfinex":{"l":178.36,"v":129383},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"4ba65c64a993cfa4c64c3031de8295e09dcd883904462e02eaacca185aba18b5","t":1592984948}},{"t":1592985060,"p":{"ppi":{"l":177.59,"v":514714},"bitfinex":{"l":178.36,"v":129374},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"425c1f46e6be502966b276dfd759aeef57bad40ffbf99edace279a9ed2244b2e","t":1592985069}},{"t":1592985120,"p":{"ppi":{"l":177.5,"v":517094},"bitfinex":{"l":178,"v":131754},"bittrex":{"l":177.32,"v":345650},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"ca1e80841a74213a2909071bc0183af27364465fe233a1235358fa5fc33dd47d","t":1592985128}},{"t":1592985180,"p":{"ppi":{"l":177.64,"v":517456},"bitfinex":{"l":178,"v":131754},"bittrex":{"l":177.53,"v":346012},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"32ccff08874bb27a366bf11b9332081cf4b11cbeb84f6cddca66915726197b05","t":1592985192}},{"t":1592985240,"p":{"ppi":{"l":177.64,"v":517456},"bitfinex":{"l":178,"v":131754},"bittrex":{"l":177.53,"v":346012},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"05dd7768c2a0b946e20eb66b1479cd51a7bc3f57a6d3648df294dc26c45507bc","t":1592985248}},{"t":1592985360,"p":{"ppi":{"l":176.62,"v":529310},"bitfinex":{"l":176.57,"v":131110},"bittrex":{"l":176.55,"v":358510},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"a3ceeb640eaa7faf8a04b50016ffdc8a2b2f6f91d26b5f4ef09321d5edcca4d8","t":1592985368}},{"t":1592985420,"p":{"ppi":{"l":176.62,"v":529310},"bitfinex":{"l":176.57,"v":131110},"bittrex":{"l":176.55,"v":358510},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"5f101c9dc6f9734b0cb5ef8925f20b7b0754aee38bb586b37dcbd1e05d72f5f8","t":1592985435}},{"t":1592985480,"p":{"ppi":{"l":176.62,"v":529310},"bitfinex":{"l":176.57,"v":131110},"bittrex":{"l":176.55,"v":358510},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"69d3d19b92b57ee122b13bcb4b85efab76c81ffee4ae1c4cdc9568140de6c3f2","t":1592985488}},{"t":1592985540,"p":{"ppi":{"l":176.62,"v":529310},"bitfinex":{"l":176.57,"v":131110},"bittrex":{"l":176.55,"v":358510},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":177.31,"v":33416}},"tx":{"h":"684fc185b4a9c8fa7115836044a997d71ff852f9d5cfe3c98dd7b4d814337f84","t":1592985549}},{"t":1592985660,"p":{"ppi":{"l":176.53,"v":532304},"bitfinex":{"l":176.5,"v":131146},"bittrex":{"l":176.55,"v":361368},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"d66c455dd3ee23318bc64e32020c05c792fa38989d8d0f7437e44fc18c46e664","t":1592985682}},{"t":1592985720,"p":{"ppi":{"l":176.5,"v":535047},"bitfinex":{"l":176.41,"v":133889},"bittrex":{"l":176.55,"v":361368},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"ce83f182d6398ba14d4c170c14ac206c93747f30ae35ad59a85d4bebe46a179f","t":1592985728}},{"t":1592985780,"p":{"ppi":{"l":176.5,"v":535047},"bitfinex":{"l":176.41,"v":133889},"bittrex":{"l":176.55,"v":361368},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"e0fc57dc5e1e5bec1da283e0217efb22c8671083511299bb36a341f3d782ac44","t":1592985789}},{"t":1592985840,"p":{"ppi":{"l":176.5,"v":535047},"bitfinex":{"l":176.41,"v":133889},"bittrex":{"l":176.55,"v":361368},"okcoin":{"l":178.05,"v":6274},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"85710925ee9ee7dc70dba790b6e4a5369bb829646693c1d0b619748e5e9ecf4d","t":1592985856}},{"t":1592985960,"p":{"ppi":{"l":176.58,"v":546263},"bitfinex":{"l":177.14,"v":144352},"bittrex":{"l":176.4,"v":361544},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"9a3729ef26779659c87e9b85b99fba40a262f12fb0d7ae3099c628e02b24769f","t":1592985975}},{"t":1592986020,"p":{"ppi":{"l":176.58,"v":544944},"bitfinex":{"l":177.14,"v":144352},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"c6e6548b596974b09639c1056d49dd65c996d1eaeb9e2e23a58e0f506306d7f7","t":1592986028}},{"t":1592986080,"p":{"ppi":{"l":176.58,"v":544944},"bitfinex":{"l":177.14,"v":144352},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"277d486aa5b47a063751e446174b868f627845d9ea3b4e3d5984e1a6a424fef5","t":1592986088}},{"t":1592986140,"p":{"ppi":{"l":176.48,"v":546459},"bitfinex":{"l":176.77,"v":145867},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"4865264823612081c9e6ad288139778d2f44ca642d69ee6657c0b26e08c38358","t":1592986148}},{"t":1592986260,"p":{"ppi":{"l":176.57,"v":546965},"bitfinex":{"l":177.08,"v":146373},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"861b6fd3fca9c5fdb8ce81f8a9b2f78eb22aa8a4141ffb3bb3c072b2b8ad2561","t":1592986268}},{"t":1592986320,"p":{"ppi":{"l":176.57,"v":546965},"bitfinex":{"l":177.08,"v":146373},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"7bee8ec3421d2d2c5e5ee585a31031f6562621bd47ed310c25ac8c89ec72ae8c","t":1592986329}},{"t":1592986380,"p":{"ppi":{"l":176.59,"v":547316},"bitfinex":{"l":177.18,"v":146724},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"50d059f02ac8d792fbf1bafcc4be53083eba8bfd9ae542043ff4c71acf9b8770","t":1592986395}},{"t":1592986440,"p":{"ppi":{"l":176.6,"v":547343},"bitfinex":{"l":177.2,"v":146751},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"a9198ec8baa238b4dc9968aacb4ec0c7e9c0418e5e8514a7c8f049ccf3219266","t":1592986455}},{"t":1592986500,"p":{"ppi":{"l":176.64,"v":548516},"bitfinex":{"l":177.34,"v":147924},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"3f6f1454715167ca059b8c6942a5d05fb50f20cd6584b9c77125983912f6f671","t":1592986515}},{"t":1592986560,"p":{"ppi":{"l":176.64,"v":548516},"bitfinex":{"l":177.34,"v":147924},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"a3d7c35a51e1171e72b8890e712d08255bad93a2c2be76d3faeeec3c6437d194","t":1592986568}},{"t":1592986620,"p":{"ppi":{"l":176.63,"v":548732},"bitfinex":{"l":177.3,"v":148140},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"995d17003fa1af895a8f4ca6e4b35dcbca8687469246d91d15d5b18d8de99617","t":1592986636}},{"t":1592986680,"p":{"ppi":{"l":176.63,"v":548732},"bitfinex":{"l":177.3,"v":148140},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"e695a9d58fea24e6a5b92896cb663da28e0458ae6784e6fa627d34f4bd5b969e","t":1592986689}},{"t":1592986740,"p":{"ppi":{"l":176.57,"v":548557},"bitfinex":{"l":177.08,"v":147965},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"f944f92314f25cb80593ccb4e8c37b5c6f5f15cb028558a3f437349fdfb3ccaa","t":1592986755}},{"t":1592986860,"p":{"ppi":{"l":176.57,"v":548557},"bitfinex":{"l":177.08,"v":147965},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"62b667c32f48cfaf46c3c9463079f0b97a53d39bb2ec658195d03a620ea6a9ba","t":1592986868}},{"t":1592986920,"p":{"ppi":{"l":176.65,"v":548861},"bitfinex":{"l":177.39,"v":148269},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"97b5ff64172e8c7d3ab1a374162687eb0f6e519a2b950fdf8afcc6b9c10dc52f","t":1592986928}},{"t":1592986980,"p":{"ppi":{"l":176.61,"v":548735},"bitfinex":{"l":177.24,"v":148143},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"850f7b7651fb7f2381dc88028aec1efecd64413bc2706d5bad1be47caf85072d","t":1592986992}},{"t":1592987040,"p":{"ppi":{"l":176.61,"v":548780},"bitfinex":{"l":177.24,"v":148188},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"84badade8148325c79c428d0682b0cbbcccee943d81fa2a3ad9fbe789e344c09","t":1592987048}},{"t":1592987160,"p":{"ppi":{"l":176.6,"v":548855},"bitfinex":{"l":177.2,"v":148263},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"b24a46d1a0a2f3a9136aab759d91c4199f96eba41d2da11692a515cd6cf1f5b7","t":1592987188}},{"t":1592987220,"p":{"ppi":{"l":176.6,"v":548855},"bitfinex":{"l":177.2,"v":148263},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"fa3417a82aef8771d3f78411f8d27bbe18f8dbbb23c0bf13a7a4ccc1005b9ef5","t":1592987234}},{"t":1592987280,"p":{"ppi":{"l":176.56,"v":548879},"bitfinex":{"l":177.07,"v":148287},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"f0f48b9a888bcbace3d30610e71f171b05acfe21ea8b5151c1ac24c903e5140a","t":1592987306}},{"t":1592987340,"p":{"ppi":{"l":176.56,"v":548879},"bitfinex":{"l":177.07,"v":148287},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"9e4e977d1e21cc21db01fa9395b0fe7258a3f8bb411f48d1b9740cee25fc1538","t":1592987359}},{"t":1592987400,"p":{"ppi":{"l":176.57,"v":549155},"bitfinex":{"l":177.1,"v":148563},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"c0f6292d8baffae464773e2082bde9aa1a2775d8e66f65b5276dc7896288ad64","t":1592987594}},{"t":1592987460,"p":{"ppi":{"l":176.57,"v":549155},"bitfinex":{"l":177.1,"v":148563},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"82964761ce0ee7891e24d5206e3c091fdf1eb96629a0833c1a4a79b23d42d8c7","t":1592987688}},{"t":1592987520,"p":{"ppi":{"l":176.52,"v":549039},"bitfinex":{"l":176.91,"v":148447},"bittrex":{"l":176.4,"v":360225},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"808980b9615d45fa2d3f5dbc19d47b9211ee155349b3d787c6ffd4a6bf59fef2","t":1592987788}},{"t":1592987580,"p":{"ppi":{"l":176.52,"v":546401},"bitfinex":{"l":176.91,"v":148447},"bittrex":{"l":176.4,"v":357587},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"5a8ba618ce95ab3b63275d425b6d265f2428b1c616161706ff9120257a48176f","t":1592987870}},{"t":1592987640,"p":{"ppi":{"l":176.57,"v":546794},"bitfinex":{"l":177.08,"v":148840},"bittrex":{"l":176.4,"v":357587},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"b57ab00176bcd7f04d25b171a102a3d45d51afb1327263fc0aabf58273ba2994","t":1592987949}},{"t":1592987700,"p":{"ppi":{"l":176.57,"v":546225},"bitfinex":{"l":177.08,"v":148840},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"591a04d89355c5a5a7433d5c83e881e80ab52cc560a24582ae40a11a955fcdf9","t":1592987955}},{"t":1592987760,"p":{"ppi":{"l":176.62,"v":546626},"bitfinex":{"l":177.26,"v":149241},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"7f5db620bd30dc58fd7897c7b9e693236a72fc3226d749152eed78b96476e5e9","t":1592987968}},{"t":1592987820,"p":{"ppi":{"l":176.62,"v":546626},"bitfinex":{"l":177.26,"v":149241},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"2ce1d1e13707324ff72a9c27c5e9d002d83efc916bc821e7ea74970d0027128b","t":1592987985}},{"t":1592987880,"p":{"ppi":{"l":176.6,"v":546826},"bitfinex":{"l":177.2,"v":149441},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"032aaf65f22a69650b954480f15295e9f2060ee30b5aef9ff572b783b3a9db0d","t":1592988066}},{"t":1592988000,"p":{"ppi":{"l":176.54,"v":546882},"bitfinex":{"l":176.97,"v":149497},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"4ad71c2a1d4f6cac86079cdd57334003107c7dac8c64cce0624f61c91454909f","t":1592988064}},{"t":1592988060,"p":{"ppi":{"l":176.54,"v":546882},"bitfinex":{"l":176.97,"v":149497},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"9e5c6cd605a1ab467c46ec51d30d1f1df9a939abbb1544a6d86aea00969b8657","t":1592988164}},{"t":1592988120,"p":{"ppi":{"l":176.51,"v":547056},"bitfinex":{"l":176.88,"v":149671},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"0883d393995b9d46398a82bd46defd90effaca012bb9901b5da0ed9cb22e582b","t":1592988216}},{"t":1592988180,"p":{"ppi":{"l":176.51,"v":547056},"bitfinex":{"l":176.88,"v":149671},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"c4bdef95813c81183790dee1dff4450c7fc5664389932574c4dea0e5c66a4846","t":1592988267}},{"t":1592988360,"p":{"ppi":{"l":176.52,"v":547573},"bitfinex":{"l":176.9,"v":150188},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"d9121df7386bc8b7c5d6c8ba9bb7eaffb198775a8718bd08974850f20bdabc7d","t":1592988373}},{"t":1592988420,"p":{"ppi":{"l":176.52,"v":547927},"bitfinex":{"l":176.9,"v":150542},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"fd9d9a91a0d1710f7135d3658d5cbe7de01e7acd4e685e4a6a59cb2fe1d8275e","t":1592988436}},{"t":1592988480,"p":{"ppi":{"l":176.52,"v":547927},"bitfinex":{"l":176.9,"v":150542},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"4632d4066b7f92ef22a8c8c17e9c6e108f245fd556a14435e3b8a41e4f9c6f56","t":1592988497}},{"t":1592988600,"p":{"ppi":{"l":176.52,"v":547927},"bitfinex":{"l":176.9,"v":150542},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"43406c4b19a32a48cf22db4394f77bc9553ab9a8a620d6b25b31174fc9e74f39","t":1592988794}},{"t":1592988660,"p":{"ppi":{"l":176.53,"v":547592},"bitfinex":{"l":176.92,"v":150207},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"3e4b668fbdc5fc5b8b1ce3ef73f1492c619cb4453bd70f21f90a372eb059d5d6","t":1592988797}},{"t":1592988720,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"86424510bab8e1b8928b5fe82864cf2889a70ffe73f2e6e75b89758925a52850","t":1592988797}},{"t":1592988780,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"a23464d486686f5585bf8eec4b118bea7ad7bca524545188d18a9ff0388330f0","t":1592988919}},{"t":1592988840,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"473bee175d6b6eab261e455fe95688ee13cf0f28cea0bd1becb337093911edda","t":1592988924}},{"t":1592988900,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"5a77199cf4ef7b41b2a6577f2f4d159ab2bb355cfa60d946da16c90e9dff88e9","t":1592988961}},{"t":1592988960,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"8bbfdef536d7c4f2000383a32bcd8ccbf0411ec9630a9ce4ee7d6af322009402","t":1592988983}},{"t":1592989020,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"25f3c0a5e77ff596e75c7bbb0e843c56f9e84d4dbef61a4cd7a6ffbb6ff0d746","t":1592989036}},{"t":1592989080,"p":{"ppi":{"l":176.52,"v":547615},"bitfinex":{"l":176.91,"v":150230},"bittrex":{"l":176.4,"v":357018},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"e6b19a52c5ba8427d37f0e8e9f3bb431e54f774b9b3f85cd03497bcbf1be9bae","t":1592989100}},{"t":1592989140,"p":{"ppi":{"l":176.47,"v":566093},"bitfinex":{"l":176.88,"v":150454},"bittrex":{"l":176.34,"v":375272},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"09fae040e0d268eaa977ccf2f77187f4c07dd9f4c93069c0c0e0f8d335edbba6","t":1592989160}},{"t":1592989200,"p":{"ppi":{"l":176.47,"v":566093},"bitfinex":{"l":176.88,"v":150454},"bittrex":{"l":176.34,"v":375272},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"78ec6d7af06b996500446bbd5442b61b2815e09fe35ecdbf2776f078b5a52294","t":1592989222}},{"t":1592989260,"p":{"ppi":{"l":176.37,"v":566389},"bitfinex":{"l":176.88,"v":150454},"bittrex":{"l":176.18,"v":375568},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"9ee2fa353f1e5a259debe4cce57ec984a600e81c5d9e603e7a190d1ba0907059","t":1592989348}},{"t":1592989320,"p":{"ppi":{"l":176.33,"v":567994},"bitfinex":{"l":176.88,"v":150454},"bittrex":{"l":176.13,"v":377173},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"340843a54be9d3ef22e4f8a6e31891f67c7f183a6175bc6f6328fdf90ffea70f","t":1592989412}},{"t":1592989380,"p":{"ppi":{"l":176.19,"v":570985},"bitfinex":{"l":176.25,"v":153443},"bittrex":{"l":176.17,"v":377175},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"26eab56d5af858be5b11d574075e9ded78e950866643e27fb115f305c42bcd93","t":1592989420}},{"t":1592989440,"p":{"ppi":{"l":176.18,"v":572313},"bitfinex":{"l":176.25,"v":153443},"bittrex":{"l":176.15,"v":378503},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"f96940422cf2ffe9afee73f984220693748d4e5eac740460be5e6fc2034c472a","t":1592989479}},{"t":1592989500,"p":{"ppi":{"l":176.18,"v":572313},"bitfinex":{"l":176.25,"v":153443},"bittrex":{"l":176.15,"v":378503},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"b9338a9a866a41069128748b1a71d3c25c6af70bb73174cff7afab9dbf8a6a07","t":1592989583}},{"t":1592989560,"p":{"ppi":{"l":176.18,"v":571024},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.15,"v":378503},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"17170c63ca9c727a3d0af5ac8032c321bf218d2091c3e76e48f3acfe27fdeb52","t":1592989918}},{"t":1592989620,"p":{"ppi":{"l":176.18,"v":571024},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.15,"v":378503},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"1d2f6381c2afe1d00ee5f8425102e3e380b78425f3071fbdaca87dfddb376938","t":1592989892}},{"t":1592990100,"p":{"ppi":{"l":176.1,"v":570769},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.03,"v":378248},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"0465884efb84e68592be8775d6979ff2c7d8864f7f25f80f5307597e8422320f","t":1592990696}},{"t":1592990160,"p":{"ppi":{"l":176.1,"v":570769},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.03,"v":378248},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"66264199789dd155e58dd0b6212eb187ad88bc19b809a356f13fada99ddce733","t":1592990258}},{"t":1592990220,"p":{"ppi":{"l":176.1,"v":570769},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.03,"v":378248},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"7a04d44f1b85cb173a557b25c8745d72cc43a68484717d39d4f33d0c15e7f459","t":1592990297}},{"t":1592990280,"p":{"ppi":{"l":176.1,"v":570769},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.03,"v":378248},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.07,"v":33516}},"tx":{"h":"e413a5b3ba89ad581a5d073db2e1628b720eee94a0133239c8695ac2f8ea2218","t":1592990447}},{"t":1592990340,"p":{"ppi":{"l":176.11,"v":567549},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.03,"v":375027},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.24,"v":33517}},"tx":{"h":"4642a04e1eb45ff3ee45468331badb4a288975e4fb7bb10b7fc9966551e8a06b","t":1592990415}},{"t":1592990400,"p":{"ppi":{"l":176.11,"v":567403},"bitfinex":{"l":176.25,"v":152154},"bittrex":{"l":176.03,"v":375027},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.24,"v":33371}},"tx":{"h":"26f4ed7ce08ab6e5ebbdac550e1eebcda6dc7b678cbc0db78dbe98f982cd250e","t":1592990472}},{"t":1592990460,"p":{"ppi":{"l":176.11,"v":565668},"bitfinex":{"l":176.25,"v":150419},"bittrex":{"l":176.03,"v":375027},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.24,"v":33371}},"tx":{"h":"f04162104d32627344a1b511e101100d66156c5d0067381278b9c2e0b152f09f","t":1592990594}},{"t":1592990520,"p":{"ppi":{"l":175.93,"v":565658},"bitfinex":{"l":176,"v":150328},"bittrex":{"l":175.86,"v":375108},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.24,"v":33371}},"tx":{"h":"ad1fa0c9666245c779e8b339d10340b47816844269df38b2f9ca0541ee722e10","t":1592990601}},{"t":1592990580,"p":{"ppi":{"l":175.93,"v":565658},"bitfinex":{"l":176,"v":150328},"bittrex":{"l":175.86,"v":375108},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.24,"v":33371}},"tx":{"h":"3d2edcc82d3fbdbf8c92bbc164649fc1c5dc638643d6582b747889c58ae2fe92","t":1592990687}},{"t":1592990640,"p":{"ppi":{"l":175.9,"v":565658},"bitfinex":{"l":176,"v":150328},"bittrex":{"l":175.86,"v":375108},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.65,"v":33371}},"tx":{"h":"880692f60fd793e5025681501a85829d67543f1064ff4422c76f00082fd84776","t":1592990802}},{"t":1592990700,"p":{"ppi":{"l":175.86,"v":565545},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.86,"v":375108},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.65,"v":33372}},"tx":{"h":"f7d87fbfcc4c8eeacc237592b1952701fb2f63e50a53a57b47b4334c274900ab","t":1592990850}},{"t":1592990760,"p":{"ppi":{"l":175.86,"v":565545},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.86,"v":375108},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.65,"v":33372}},"tx":{"h":"35da979da289fb31726b6093dcb1a197abc9d7fbb39f596fe6bf25cb09339424","t":1592990821}},{"t":1592990820,"p":{"ppi":{"l":175.87,"v":565896},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.02,"v":33372}},"tx":{"h":"5b569f94f6f5f8bdd6a8fe9e0890206f8b38d44247f20fc1442fd1b6cf09b555","t":1592990906}},{"t":1592990880,"p":{"ppi":{"l":175.88,"v":565898},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.11,"v":33374}},"tx":{"h":"15b217bd727a63ea798f234db96acfac71f5a9f071a2d3b4e4c90821535787a8","t":1592991047}},{"t":1592990940,"p":{"ppi":{"l":175.88,"v":565898},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.11,"v":33374}},"tx":{"h":"1b12dff3cd5ca7293794ff01ef6f180a1a976350dfa8477cdd125063590480ef","t":1592991322}},{"t":1592991000,"p":{"ppi":{"l":175.87,"v":565898},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176,"v":33374}},"tx":{"h":"22a76cbb411fd5e47490e1d19142ee5a3b29aba8c44357039652d2b9c7ed28a6","t":1592991094}},{"t":1592991060,"p":{"ppi":{"l":175.87,"v":565899},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.97,"v":33375}},"tx":{"h":"3bb20874db9292036cff64fa45b0f676c09e9d8ab945827d9aa54308cfe0bf04","t":1592991266}},{"t":1592991120,"p":{"ppi":{"l":175.87,"v":565900},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.97,"v":33376}},"tx":{"h":"dab2585a44948360f8a2c908c5e9d67a2b1c6ac9b5f68f1bf48000b6e214b366","t":1592991332}},{"t":1592991180,"p":{"ppi":{"l":175.87,"v":565900},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.97,"v":33376}},"tx":{"h":"1eef8bf14814d4c932dc7c9c20c32c103123f4cc6f4705262056ab774c69cb42","t":1592991323}},{"t":1592991240,"p":{"ppi":{"l":175.88,"v":565901},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.85,"v":375459},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.17,"v":33377}},"tx":{"h":"3c69d7fef1310b917da2f60b6b283604ca93db2416316622970a55effa2f97d5","t":1592991332}},{"t":1592991300,"p":{"ppi":{"l":175.74,"v":592250},"bitfinex":{"l":175.86,"v":150214},"bittrex":{"l":175.65,"v":401807},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.08,"v":33378}},"tx":{"h":"0aaf82ba14e585a330572f2f569cde6084b49bff26024618eeaba4340d3e4e5e","t":1592991360}},{"t":1592991360,"p":{"ppi":{"l":175.79,"v":592639},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.65,"v":401807},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.08,"v":33378}},"tx":{"h":"14df6ff64647a6163a6f3056b522dd17c55a19f49ba69d23578a9cae8e978fe7","t":1592991408}},{"t":1592991420,"p":{"ppi":{"l":175.79,"v":592639},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.65,"v":401807},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.08,"v":33378}},"tx":{"h":"68a715dd5b7614861c7265b5ff5c23a84e52269896d3417d563e15f10f100a26","t":1592991493}},{"t":1592991480,"p":{"ppi":{"l":175.79,"v":591776},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.65,"v":400944},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.08,"v":33378}},"tx":{"h":"313afe3c8c629255320addb7d0d366bd3bb850b3d07ff76e315d92fd02b869d9","t":1592991530}},{"t":1592991540,"p":{"ppi":{"l":175.8,"v":591777},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.65,"v":400944},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.13,"v":33379}},"tx":{"h":"fdb5571310f808cee93a18cfd435a8fc15b068233bbe491b7bb53e1d9506eff3","t":1592991613}},{"t":1592991600,"p":{"ppi":{"l":175.93,"v":592488},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.85,"v":401654},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.13,"v":33380}},"tx":{"h":"8af1affb5cc41b73d5886bf684c411824a472263b01b5394300a294f959108c1","t":1592991688}},{"t":1592991660,"p":{"ppi":{"l":175.93,"v":592489},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.85,"v":401654},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33381}},"tx":{"h":"e800d279f8fe397cc878f19fc245221234f3ede132869d8302715653e368c430","t":1592991716}},{"t":1592991720,"p":{"ppi":{"l":175.75,"v":596932},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.59,"v":406097},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33381}},"tx":{"h":"181c0be9659b0200d9899d28f6b844e87d3b3a98b148a60090ab9134369e3eb2","t":1592991761}},{"t":1592991780,"p":{"ppi":{"l":175.75,"v":596932},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.59,"v":406097},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33381}},"tx":{"h":"54c639c769c3f055d7943235c9779828ae281278d7d615148e62bc8561c5a08c","t":1592991805}},{"t":1592991840,"p":{"ppi":{"l":175.72,"v":597130},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33381}},"tx":{"h":"ec20f1d5245de14d75b57081574d0188f1650c150e4cea3d7b496bcc3a31d160","t":1592991879}},{"t":1592991900,"p":{"ppi":{"l":175.72,"v":597130},"bitfinex":{"l":176.07,"v":150603},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33381}},"tx":{"h":"980bb16fef85cfb158c7fb64221a677b9cd982c1d221f29a3bb5222ee40eab8c","t":1592991927}},{"t":1592991960,"p":{"ppi":{"l":175.61,"v":604153},"bitfinex":{"l":175.65,"v":157626},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33381}},"tx":{"h":"80d134d13701f1005af5c23a2de102270604d613bc260555b1a325e097edd6ae","t":1592991990}},{"t":1592992020,"p":{"ppi":{"l":175.56,"v":612483},"bitfinex":{"l":175.47,"v":165955},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.98,"v":33382}},"tx":{"h":"d4ed49bd7fc8d935fe445aa68ce55832d6a68bb63e82b63a71f20fc35b84eec0","t":1592992046}},{"t":1592992080,"p":{"ppi":{"l":175.56,"v":612483},"bitfinex":{"l":175.47,"v":165955},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.98,"v":33382}},"tx":{"h":"4dfc27157968808b6f482aaec0ba867207b382e9b1663d3502daf452d67aa3a2","t":1592992102}},{"t":1592992140,"p":{"ppi":{"l":175.7,"v":613312},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.09,"v":33383}},"tx":{"h":"6d59d816bfadd00f59833a861f7af1c8f5a0151a1775e6e78b58adcbf963075d","t":1592992164}},{"t":1592992200,"p":{"ppi":{"l":175.7,"v":613312},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.09,"v":33383}},"tx":{"h":"3d69b756a74ec0c148822f902c22b967350b47ca92767760b637ada2f734f8ba","t":1592992208}},{"t":1592992260,"p":{"ppi":{"l":175.7,"v":613312},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.18,"v":33383}},"tx":{"h":"c9d43c7e02a4291aa4ce9665e7f6a595259d51ff96ca1921ae82868fc633e1e2","t":1592992275}},{"t":1592992320,"p":{"ppi":{"l":175.7,"v":613313},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.18,"v":33384}},"tx":{"h":"6bab42dc54da23e61e8a25aa9dd3d3c5c9bc98c04fd90f5871a3828a71ca70d1","t":1592992329}},{"t":1592992380,"p":{"ppi":{"l":175.7,"v":613313},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33384}},"tx":{"h":"05dfcaec996d28e0c28c2df3b48cfa6c7af0bcf757fd56edfa4e70b7fba7a31c","t":1592992395}},{"t":1592992440,"p":{"ppi":{"l":175.7,"v":613314},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"d8abd6cc17b588f6bb5d70ba727b1b06038fe6c1308312792be85643f7e3bed1","t":1592992448}},{"t":1592992560,"p":{"ppi":{"l":175.7,"v":613314},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"6851c2ce7a02efa9843e7e8a12ba732c8b007e6b865c188495d6e61daf541329","t":1592992568}},{"t":1592992620,"p":{"ppi":{"l":175.7,"v":613314},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"64973992b152bd5f96bfd751b393ada6afdc7b37a0a0677e67e1a50aef9cd605","t":1592992628}},{"t":1592992680,"p":{"ppi":{"l":175.7,"v":613314},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"9ea14250228836d2bf4ce744b1273ca4f1098e5a0ae44f760b84b63470ce0819","t":1592992689}},{"t":1592992740,"p":{"ppi":{"l":175.7,"v":613314},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.54,"v":406295},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"0adab02c93f12bbd27130316dc2c699081f5b4fd2f4741852ef6dc646f698ad6","t":1592992748}},{"t":1592992860,"p":{"ppi":{"l":175.92,"v":614521},"bitfinex":{"l":175.96,"v":166783},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"991166575e323bd6c48ad3b1a34bb97ae93adc293879e1350b7298bd7698a0d6","t":1592992876}},{"t":1592992920,"p":{"ppi":{"l":175.97,"v":615592},"bitfinex":{"l":176.16,"v":167854},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"3020233d92798aec93f68e1f9e45cc7aabce711ffa216120b259fc208a66e42a","t":1592992928}},{"t":1592992980,"p":{"ppi":{"l":175.97,"v":615592},"bitfinex":{"l":176.16,"v":167854},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"3bce66448c76d414ccb703a0038d41332175f2f88731af8126968d5e1d6eb837","t":1592992988}},{"t":1592993040,"p":{"ppi":{"l":175.97,"v":615592},"bitfinex":{"l":176.16,"v":167854},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33385}},"tx":{"h":"944e43490c1f433aced4d8b6eba3d5a6d12377e39f14b3f92e138e749febec57","t":1592993048}},{"t":1592993160,"p":{"ppi":{"l":175.95,"v":615250},"bitfinex":{"l":176.09,"v":167667},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"87a2421f5e6d3e00a9551c7f04d32790a23e35297546fe80ee11cc10961b1cca","t":1592993169}},{"t":1592993220,"p":{"ppi":{"l":175.95,"v":615250},"bitfinex":{"l":176.09,"v":167667},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"7ea3a6f3755605b97535f1f6dbc5d7ef4ed00c36166f3370790d18ef9b3266cf","t":1592993229}},{"t":1592993280,"p":{"ppi":{"l":175.95,"v":615250},"bitfinex":{"l":176.09,"v":167667},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"1802f49f22bfbcdca712846956518dc68b82c2db83fb7cf113122daa61b54280","t":1592993288}},{"t":1592993340,"p":{"ppi":{"l":175.95,"v":615250},"bitfinex":{"l":176.09,"v":167667},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"5c8d251f1aaeb4023ed122b45ca15763130b33482e03df7613cd39e24a8da5e8","t":1592993349}},{"t":1592993460,"p":{"ppi":{"l":175.88,"v":615888},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"9522d18d29283233900423622addd578cbb19062bbcba12d7dc4f47e28866d4c","t":1592993468}},{"t":1592993520,"p":{"ppi":{"l":175.88,"v":615888},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.87,"v":407502},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"2d163e15c462105f103f44f8047b6bcb6c4ff020a5c44c7b3baff01de5a33864","t":1592993528}},{"t":1592993580,"p":{"ppi":{"l":175.66,"v":616180},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.54,"v":407794},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.1,"v":33230}},"tx":{"h":"cc501bc450cf0803afffac55e26f2e449c78239d0950135e7e97abea54f63580","t":1592993588}},{"t":1592993640,"p":{"ppi":{"l":175.66,"v":616180},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.54,"v":407794},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.04,"v":33230}},"tx":{"h":"9e809c2f4b9b5051aa29824b0253ec2eb5a8287aa0c2ca3c7387e34043a395e3","t":1592993648}},{"t":1592993760,"p":{"ppi":{"l":175.65,"v":615035},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.54,"v":406647},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.91,"v":33232}},"tx":{"h":"6cac3821492db1e5e295f2ca457e7100cecccb339531c0abfd4b5d1ae79833d8","t":1592993769}},{"t":1592993820,"p":{"ppi":{"l":175.65,"v":615036},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.54,"v":406647},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.91,"v":33233}},"tx":{"h":"05f0fd76011efc9698462c0842b3961d9b6d97d48232bb6872ac6f89af2cdbcd","t":1592993828}},{"t":1592993880,"p":{"ppi":{"l":175.65,"v":611470},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.54,"v":406647},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.91,"v":29667}},"tx":{"h":"9e7fcf6619c26e336b856bb1dadd6c43afc2eee919a112c8d8115b9a265dc75e","t":1592993888}},{"t":1592993940,"p":{"ppi":{"l":175.65,"v":611470},"bitfinex":{"l":175.83,"v":168305},"bittrex":{"l":175.54,"v":406647},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":175.91,"v":29667}},"tx":{"h":"2e022514465ba31b3074eabc27de49a4d78fb8fd9a0df60385f2a84502e58378","t":1592993948}},{"t":1592994060,"p":{"ppi":{"l":175.9,"v":611758},"bitfinex":{"l":175.83,"v":167714},"bittrex":{"l":175.9,"v":407526},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.02,"v":29667}},"tx":{"h":"26cfa5426db0307d46099fcbbead304f35d830070d220a35d68796d4e4bad30a","t":1592994068}},{"t":1592994120,"p":{"ppi":{"l":175.9,"v":611759},"bitfinex":{"l":175.83,"v":167714},"bittrex":{"l":175.9,"v":407526},"okcoin":{"l":176.71,"v":6851},"poloniex":{"l":176.02,"v":29668}},"tx":{"h":"7585f041d3deb2759b4ca1a9d1a420d6bf25a8251bca95ca584f3e115d09532a","t":1592994128}},{"t":1592994180,"p":{"ppi":{"l":175.89,"v":609849},"bitfinex":{"l":175.83,"v":167714},"bittrex":{"l":175.9,"v":407526},"okcoin":{"l":176.71,"v":4941},"poloniex":{"l":176.02,"v":29668}},"tx":{"h":"d53e17aaeb5e3aa55c7a157bd25009b09d2c0c7504e8ae2367177600eb3f7704","t":1592994196}},{"t":1592994240,"p":{"ppi":{"l":175.89,"v":606118},"bitfinex":{"l":175.83,"v":167714},"bittrex":{"l":175.9,"v":403794},"okcoin":{"l":176.71,"v":4941},"poloniex":{"l":175.86,"v":29669}},"tx":{"h":"8ff2e1e7606609818546ff8795f04ba58db2d6a4859d23507a76349a70bb4679","t":1592994249}},{"t":1592994360,"p":{"ppi":{"l":175.87,"v":606711},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.9,"v":403794},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29669}},"tx":{"h":"558874a64e74fed86797514593ea5c9addcbb5472086fd3b1da9c91fe86707c6","t":1592994369}},{"t":1592994420,"p":{"ppi":{"l":175.87,"v":604227},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.9,"v":401310},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29669}},"tx":{"h":"bddd41af791d23fbf1a5b16c2e36116b6786d4dc77cb24716ebaa73b8f9becfa","t":1592994429}},{"t":1592994480,"p":{"ppi":{"l":175.87,"v":604227},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.9,"v":401310},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29669}},"tx":{"h":"6de28860cbaf326a90f7a3e08cf30a048f8e4e8859180a3b1e9c8147473775e5","t":1592994488}},{"t":1592994540,"p":{"ppi":{"l":175.89,"v":604398},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.93,"v":401486},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"06f46c2fdf807a7afb2876e2b712b198e2c1ea3d94ca3664950ce9567bfde031","t":1592994555}},{"t":1592994660,"p":{"ppi":{"l":175.67,"v":604749},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.6,"v":401837},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"08de59d43b4b10cc7898639e133df11f9c1393757f4fdc604bf24e90bd44a839","t":1592994668}},{"t":1592994720,"p":{"ppi":{"l":175.67,"v":604740},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.6,"v":401828},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"d31f2620047e70f6297ca4a89d251c460a192ce7a0e8ac2eff8f874f4058c4f7","t":1592994728}},{"t":1592994780,"p":{"ppi":{"l":175.67,"v":604740},"bitfinex":{"l":175.78,"v":168437},"bittrex":{"l":175.6,"v":401828},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"2ca082c70170619c3263aa1a1e18352e0fb11863f3668e2557c0ff86fe858fac","t":1592994789}},{"t":1592994840,"p":{"ppi":{"l":175.69,"v":605325},"bitfinex":{"l":175.84,"v":169022},"bittrex":{"l":175.6,"v":401828},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"a895a33031a2147d65e53476f8e2edb4e40d7d0979988b317a16c5fe2467ced5","t":1592994848}},{"t":1592994960,"p":{"ppi":{"l":175.65,"v":601752},"bitfinex":{"l":175.84,"v":165381},"bittrex":{"l":175.54,"v":401896},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"e676ee3fdc8d788a4d132985606050a34bf92bd1aa1989d501c843f6481db093","t":1592994968}},{"t":1592995020,"p":{"ppi":{"l":175.59,"v":602506},"bitfinex":{"l":175.84,"v":165381},"bittrex":{"l":175.46,"v":402650},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"51d884b3d6ad09ae176bcafe33a0217dd5ca58deed6ffeca770da9480773c7c5","t":1592995028}},{"t":1592995080,"p":{"ppi":{"l":175.34,"v":603922},"bitfinex":{"l":175.84,"v":165381},"bittrex":{"l":175.08,"v":404066},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":175.86,"v":29664}},"tx":{"h":"12c663cae09d79b4545b03e5ffde108d660e2940750b4b827cee065d09ff2b14","t":1592995088}},{"t":1592995140,"p":{"ppi":{"l":173.09,"v":616937},"bitfinex":{"l":173.21,"v":167228},"bittrex":{"l":173,"v":415234},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":173.16,"v":29664}},"tx":{"h":"6ce0e95b5b21d0930ef076f85213ab8471217cf4076c460fa9dbbf4ba38f69d2","t":1592995170}},{"t":1592995260,"p":{"ppi":{"l":173.33,"v":621148},"bitfinex":{"l":173.91,"v":171076},"bittrex":{"l":173,"v":415234},"okcoin":{"l":176.71,"v":4811},"poloniex":{"l":174.01,"v":30027}},"tx":{"h":"63b34f985d0cd05e1e33f6203036ccf9fb1e079f01419d7a5effbdcfaf2bb683","t":1592995275}},{"t":1592995320,"p":{"ppi":{"l":173.33,"v":620591},"bitfinex":{"l":173.91,"v":171076},"bittrex":{"l":173,"v":415234},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.01,"v":30028}},"tx":{"h":"d7874a70b5aa71e7dbd8a4aef80870223bf744b016d6213225212db32d4a8a32","t":1592995336}},{"t":1592995380,"p":{"ppi":{"l":173.98,"v":621971},"bitfinex":{"l":173.91,"v":171076},"bittrex":{"l":173.94,"v":416613},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.6,"v":30029}},"tx":{"h":"3b50e2227a6264c6c4808729f579e84108fb3ce3ce0104243c6dcdca8b1ae068","t":1592995389}},{"t":1592995440,"p":{"ppi":{"l":173.98,"v":621971},"bitfinex":{"l":173.91,"v":171076},"bittrex":{"l":173.94,"v":416613},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.6,"v":30029}},"tx":{"h":"730e262023213fc33dc03d9d687bd5b7ff2ae663b93d2152df34424f05e99b22","t":1592995456}},{"t":1592995560,"p":{"ppi":{"l":174.15,"v":628426},"bitfinex":{"l":174.49,"v":178016},"bittrex":{"l":173.94,"v":416126},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.59,"v":30031}},"tx":{"h":"094e34c838118c60c64427c95ac4ee1030011459d673193691ce54b95fcbb5fc","t":1592995569}},{"t":1592995620,"p":{"ppi":{"l":174.51,"v":630393},"bitfinex":{"l":174.49,"v":178016},"bittrex":{"l":174.48,"v":420255},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.66,"v":27869}},"tx":{"h":"55abe86eeb58ce332a261c33c515c671ceac266fe1bd1b7db04c40c4a6a451c8","t":1592995635}},{"t":1592995680,"p":{"ppi":{"l":174.51,"v":630393},"bitfinex":{"l":174.49,"v":178016},"bittrex":{"l":174.48,"v":420255},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.66,"v":27869}},"tx":{"h":"18118d624a97f3820a6f3c346cf18e71131e8ccfb610dadfe349499eb9b56f98","t":1592995689}},{"t":1592995740,"p":{"ppi":{"l":174.59,"v":630781},"bitfinex":{"l":174.49,"v":178016},"bittrex":{"l":174.61,"v":420641},"okcoin":{"l":176.71,"v":4253},"poloniex":{"l":174.66,"v":27871}},"tx":{"h":"f6151a1e98c96da9bb656f5673aa6210914910bc6b252891cf8f8f6e5ca91557","t":1592995749}},{"t":1592995860,"p":{"ppi":{"l":174.59,"v":629878},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.61,"v":420641},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.66,"v":27872}},"tx":{"h":"e41891067e066b3c9226f9999eeaa3e63ff9d26ff4c997ce2fc56120f01ef5b3","t":1592995868}},{"t":1592995920,"p":{"ppi":{"l":174.56,"v":629889},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.61,"v":420641},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":173.92,"v":27883}},"tx":{"h":"778a781911f5ae8f3d8b6b5aefbcb5514ac0181b49865c03cc03a45db007b07b","t":1592995928}},{"t":1592995980,"p":{"ppi":{"l":174.56,"v":629889},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.61,"v":420641},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":173.92,"v":27883}},"tx":{"h":"b3ace7c54b88e06a4bead8cfcb59a55b25321bfcf305de4be11d364c065e71d5","t":1592995996}},{"t":1592996040,"p":{"ppi":{"l":174.12,"v":631496},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":173.93,"v":422247},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"5bcfb32ad37a19943a2306f6388dd2c85145d2c0b143acfad1d8a3efbb728b26","t":1592996048}},{"t":1592996160,"p":{"ppi":{"l":174.12,"v":631496},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":173.93,"v":422247},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"fb3473e3b3b0245d3a017f690fa335a3b6c8c124b1f77351b60e7de99f85de50","t":1592996176}},{"t":1592996220,"p":{"ppi":{"l":174.12,"v":631496},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":173.93,"v":422247},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"c2845c2cc830ab84be0338a0871891101a0733317eceb61ed19d7eda11ecdffc","t":1592996236}},{"t":1592996280,"p":{"ppi":{"l":174.34,"v":631509},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.25,"v":422260},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"6a3aced9734da8f34cd617f553e1a0b5cb6e2345666542aa08d0069e641d7ea4","t":1592996289}},{"t":1592996340,"p":{"ppi":{"l":174.34,"v":631509},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.25,"v":422260},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"151f435b74fc1f86c6efcd47b5c6dad516c42349c133adc1e39d83626a8ccb11","t":1592996348}},{"t":1592996460,"p":{"ppi":{"l":174.34,"v":631509},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.25,"v":422260},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"ec09402d583639805584d18f89fcce5238e2f3abab6e2183dc42c2219589bd40","t":1592996475}},{"t":1592996520,"p":{"ppi":{"l":174.34,"v":631509},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.25,"v":422260},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"45f4fbb473a7432d8929259dd3b1749aae09c2a072d9dca0b848d8e63092b46f","t":1592996528}},{"t":1592996580,"p":{"ppi":{"l":174.34,"v":628321},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.25,"v":419072},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"95fdea41fda645718ca41e3830a338dd0cc52723bdb5885be7cfb1265d11d2ac","t":1592996589}},{"t":1592996640,"p":{"ppi":{"l":174.34,"v":628321},"bitfinex":{"l":174.49,"v":177268},"bittrex":{"l":174.25,"v":419072},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.32,"v":27884}},"tx":{"h":"6ee116059cdea3cffe2ce26874be5f9cf39c3ab8968e9ee9cff6e80aa52031b5","t":1592996649}},{"t":1592996760,"p":{"ppi":{"l":174.38,"v":603774},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.25,"v":392209},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.13,"v":27907}},"tx":{"h":"8e27b6255e1c92053217402cd78a93466d6d78e3c6692d52e3fec748e6eebd49","t":1592996768}},{"t":1592996820,"p":{"ppi":{"l":174.48,"v":603795},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.36,"v":392229},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.66,"v":27908}},"tx":{"h":"637bc5e868e1bfcc00e88cdb83f5f250ff0229eac0d51a97760c4669e9ea5324","t":1592996828}},{"t":1592996880,"p":{"ppi":{"l":174.48,"v":603796},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.36,"v":392229},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.64,"v":27909}},"tx":{"h":"bf84fb9ff6b2b9677a9b5e0bff2d69d7dbc8d8ae10d1649c317375a7bf8aae68","t":1592996889}},{"t":1592996940,"p":{"ppi":{"l":174.55,"v":608157},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.64,"v":27909}},"tx":{"h":"e5c0d06ebf9b1214ef357be7c485701a72f8b30cdc11b33fd11148d3af7287e8","t":1592996949}},{"t":1592997060,"p":{"ppi":{"l":174.55,"v":608157},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.64,"v":27909}},"tx":{"h":"e2090111bb04cb0814d9fab4b32c7e3b31fcac3a22efa968c1f777303b4ef884","t":1592997069}},{"t":1592997120,"p":{"ppi":{"l":174.55,"v":608157},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.64,"v":27909}},"tx":{"h":"c73e0b230d5b4fe0354e9522cb6b0742b7e34f0dd6a91328239a19a0376fe540","t":1592997128}},{"t":1592997180,"p":{"ppi":{"l":174.55,"v":608158},"bitfinex":{"l":174.65,"v":179561},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"637617030e6f4fe3d49933a0d34c2a1ff8c19ed2af3c12b311dab59ac0d03b0d","t":1592997188}},{"t":1592997240,"p":{"ppi":{"l":174.54,"v":609308},"bitfinex":{"l":174.62,"v":180711},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"7292c9f5ad3067885130b1ed78fbb873a95c1930ed881a7e6c4b2092f061a0a2","t":1592997249}},{"t":1592997360,"p":{"ppi":{"l":174.57,"v":613859},"bitfinex":{"l":174.7,"v":185262},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"7209e27f6813d6a49ffab7202cb33b7c97441ec6fd5878d9306e6fbe753d40f8","t":1592997368}},{"t":1592997420,"p":{"ppi":{"l":174.57,"v":613859},"bitfinex":{"l":174.7,"v":185262},"bittrex":{"l":174.48,"v":396590},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"bfebc041a6b6919fdd95e32cf49f118059bf189c57c45208fbb98f7fa9a70eac","t":1592997428}},{"t":1592997480,"p":{"ppi":{"l":174.67,"v":615567},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.53,"v":397890},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"3c58ee7d9c6b1f3e9337d8a64097567a5d7db8d75d316174343dbd7ebac51744","t":1592997488}},{"t":1592997540,"p":{"ppi":{"l":174.82,"v":616651},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":398974},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"d2615b02ff514d0fda4b6ab9355a8ac233ae7f7f1e94164fe3c9293e951138ee","t":1592997549}},{"t":1592997660,"p":{"ppi":{"l":174.82,"v":607739},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":390062},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"702a213106de4bf794dc14e39fc346c831b964aed41807d5f115cee5b1a0b62f","t":1592997675}},{"t":1592997720,"p":{"ppi":{"l":174.82,"v":599781},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":382104},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"ec14262b1fd017ec7154986dc23cd3b880389f33a4c58543ec229829e225cc34","t":1592997728}},{"t":1592997780,"p":{"ppi":{"l":174.82,"v":597817},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":380140},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"ab514b6eb0e4e189448b4ebbbf05d77cd6e766e414c47bae969fb4ab400ef81e","t":1592997797}},{"t":1592997840,"p":{"ppi":{"l":174.82,"v":597817},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":380140},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"a8b6a657366c22abe9997862694c2650e3cd3c5b98f4eda4e4e905a40074f960","t":1592997849}},{"t":1592997960,"p":{"ppi":{"l":174.82,"v":595060},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":377383},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"6e1888759c0f070426fa62c1563e506e4d0fe2251e80be39fd60fc7ffe4f153c","t":1592997968}},{"t":1592998020,"p":{"ppi":{"l":174.82,"v":595060},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":377383},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"1e8b022a3e1cd523edb71adb1df2257d18c15119711e4a747f074deda78c824a","t":1592998029}},{"t":1592998080,"p":{"ppi":{"l":174.82,"v":593975},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":376298},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"bdc8e134a882c19d6f7cb8238b16533677b6fc4819e9232f4e568901eb2baa39","t":1592998089}},{"t":1592998140,"p":{"ppi":{"l":174.82,"v":593975},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.77,"v":376298},"okcoin":{"l":176.71,"v":4097},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"d4b3cd3e8d4f918e06e840346ab888ec9f966337504d15211c593cd3cc81921b","t":1592998155}},{"t":1592998260,"p":{"ppi":{"l":174.56,"v":594482},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.35,"v":376976},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"c98f08eda3f0b18e4af6886bef965bfd9c4817bd185ea0faaff5c046918b3f45","t":1592998269}},{"t":1592998320,"p":{"ppi":{"l":174.48,"v":595199},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.23,"v":377693},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"bf839637858d098dc6c4849b64882fc7536e3f8ab5363ca0ced8b1a2f7c10cd3","t":1592998329}},{"t":1592998380,"p":{"ppi":{"l":174.48,"v":595199},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":174.23,"v":377693},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"96d2d6cc4a5b6b469fa05d77e4a8013d1f86284da4183ca72300b2b316c640ca","t":1592998389}},{"t":1592998440,"p":{"ppi":{"l":174.33,"v":595573},"bitfinex":{"l":174.92,"v":185670},"bittrex":{"l":173.99,"v":378067},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"516d9829f3fda1ee8007d441ad3aa33a328cb6f75f24c7ad0632329e216dd5ae","t":1592998448}},{"t":1592998560,"p":{"ppi":{"l":174.32,"v":591588},"bitfinex":{"l":174.92,"v":182743},"bittrex":{"l":173.99,"v":377009},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"63ccd382adaed32dda9a62f3c28366c2c858e2743bfd4c36f553a89165172f57","t":1592998568}},{"t":1592998620,"p":{"ppi":{"l":174.19,"v":591303},"bitfinex":{"l":174.48,"v":182458},"bittrex":{"l":173.99,"v":377009},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"f21aa3c13c08afd116b9069a4fd4d9f3bef661b17821c2af35ad5e230a0a73cb","t":1592998628}},{"t":1592998680,"p":{"ppi":{"l":174.19,"v":591303},"bitfinex":{"l":174.48,"v":182458},"bittrex":{"l":173.99,"v":377009},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"2d2ad8e6f64e4b8ece7a74e78b6530448facbecd3ce93baaf29374ab362de366","t":1592998689}},{"t":1592998740,"p":{"ppi":{"l":174.14,"v":592105},"bitfinex":{"l":174.48,"v":182458},"bittrex":{"l":173.91,"v":377811},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"117943b00da796b402fd04163f8b05478bcfa754a85c6f0846961f0580124471","t":1592998749}},{"t":1592998860,"p":{"ppi":{"l":173.73,"v":595161},"bitfinex":{"l":174.06,"v":183069},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"e586e40c30dc31a4ae62a2ba51c27c7836c525d676d595dac69e40acdebe6655","t":1592998869}},{"t":1592998920,"p":{"ppi":{"l":173.73,"v":595161},"bitfinex":{"l":174.06,"v":183069},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"ff072fb827ddc8d4a65985aae5c2dc3fe0ca2ececa916e70096fb225b4f4d3ac","t":1592998943}},{"t":1592998980,"p":{"ppi":{"l":173.73,"v":595161},"bitfinex":{"l":174.06,"v":183069},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"f3a12fa0a321dff9a76ad98255aa36684a51130e33f760b19f108c4d910883f0","t":1592998988}},{"t":1592999040,"p":{"ppi":{"l":173.72,"v":595144},"bitfinex":{"l":174.04,"v":183052},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.6,"v":27910}},"tx":{"h":"9a5a5f59f9434c4d26de30472435c627e8ab53f83f1c4397eac3fc8a1cd34076","t":1592999048}},{"t":1592999160,"p":{"ppi":{"l":173.7,"v":595144},"bitfinex":{"l":174.04,"v":183052},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.19,"v":27910}},"tx":{"h":"df5026ce60989ab9580b5ae43a27d939528633a1f491548d0ea096857cfcd012","t":1592999169}},{"t":1592999220,"p":{"ppi":{"l":173.71,"v":595145},"bitfinex":{"l":174.04,"v":183052},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.29,"v":27911}},"tx":{"h":"6b2ac956b56f490f9429f2bf6abd22e44cdeba07ce7c82c988bea2cc5bdd7c82","t":1592999228}},{"t":1592999280,"p":{"ppi":{"l":173.7,"v":595146},"bitfinex":{"l":174.04,"v":183052},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.14,"v":27912}},"tx":{"h":"ea6f9e5159d5df9ff739ce225595b91db67f2f16c4f73db1c06ed82d5310ac7f","t":1592999288}},{"t":1592999340,"p":{"ppi":{"l":173.7,"v":595147},"bitfinex":{"l":174.04,"v":183052},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.14,"v":27913}},"tx":{"h":"86a8de452000cadde6623aadfce56b9a43da479aa6f4200fdf8cc1cf3952ed3c","t":1592999349}},{"t":1592999460,"p":{"ppi":{"l":173.71,"v":594461},"bitfinex":{"l":174.04,"v":182365},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"ed5ada4f75667f9b4917807a5c7b1bf5e585ba314e6e50f94d90bc45ed19746b","t":1592999468}},{"t":1592999520,"p":{"ppi":{"l":173.71,"v":594461},"bitfinex":{"l":174.04,"v":182365},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"943007c09b5c9c84803fbec6515e6957a6e2eb610c8c092f881b3cc560575c89","t":1592999529}},{"t":1592999580,"p":{"ppi":{"l":173.71,"v":594461},"bitfinex":{"l":174.04,"v":182365},"bittrex":{"l":173.47,"v":380256},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"8efcc124d31d7b5b8a01fc6cfb7e0adaabe5b4f04c1ea80e64a277e986fa9236","t":1592999598}},{"t":1592999640,"p":{"ppi":{"l":173.97,"v":596992},"bitfinex":{"l":174.04,"v":182365},"bittrex":{"l":173.88,"v":382787},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"8eb0f0f07139f6335cb06b92dd0332950b3a205a592fadb299b4e89865bdc288","t":1592999648}},{"t":1592999760,"p":{"ppi":{"l":173.66,"v":602194},"bitfinex":{"l":174.04,"v":182365},"bittrex":{"l":173.4,"v":387989},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"cf3161d4d49c0cd23cf017dc6da057b4dc620d43fb7731caf7a1716bbcc16f00","t":1592999768}},{"t":1592999820,"p":{"ppi":{"l":173.66,"v":602194},"bitfinex":{"l":174.04,"v":182365},"bittrex":{"l":173.4,"v":387989},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"7cd19d738625108351d2e7aa8d8cccc7ba86f1458bab47fd2c6c2571fdb9ff41","t":1592999835}},{"t":1592999880,"p":{"ppi":{"l":173.72,"v":606863},"bitfinex":{"l":174.22,"v":187034},"bittrex":{"l":173.4,"v":387989},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"9c0a28dc71e5ebed521cb2973c3d9033f22e9e32b3f2206abb6c95f2ced7f118","t":1592999888}},{"t":1592999940,"p":{"ppi":{"l":173.59,"v":606596},"bitfinex":{"l":173.81,"v":186767},"bittrex":{"l":173.4,"v":387989},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.3,"v":27914}},"tx":{"h":"ae61453058ebc14cab5956cb4a06c856ab22f4c0d702f10075090bba08d45c59","t":1592999950}},{"t":1593000060,"p":{"ppi":{"l":173.48,"v":607472},"bitfinex":{"l":173.47,"v":187617},"bittrex":{"l":173.43,"v":388014},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":173.87,"v":27915}},"tx":{"h":"2702ad3277318c96f1362420a1aa85c72ff07ce9d87c4e3d945e4528837f4189","t":1593000069}},{"t":1593000120,"p":{"ppi":{"l":173.77,"v":610983},"bitfinex":{"l":174.13,"v":189950},"bittrex":{"l":173.55,"v":389192},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":173.87,"v":27915}},"tx":{"h":"2510e9ccfdd9e3c6a606bcb0cbbf878668ff45055adefcd3731f7ac1d4af9b98","t":1593000135}},{"t":1593000180,"p":{"ppi":{"l":173.81,"v":611322},"bitfinex":{"l":174.23,"v":190603},"bittrex":{"l":173.55,"v":388877},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.22,"v":27916}},"tx":{"h":"9c97588aea8a4099811e69e4c95848a55646fca9cd1c40ff96f4be9a39a2fd65","t":1593000196}},{"t":1593000240,"p":{"ppi":{"l":174.09,"v":612649},"bitfinex":{"l":174.23,"v":190603},"bittrex":{"l":173.98,"v":390203},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27917}},"tx":{"h":"705dd6ca0d8472f56cdbd24dcb3b34f95b3f6396a248b7f03803d53d52939589","t":1593000248}},{"t":1593000360,"p":{"ppi":{"l":174.09,"v":607305},"bitfinex":{"l":174.23,"v":185890},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"40b2931a0b4121ae94f3e5066432c604c3b499560442f088bed04cd90a424063","t":1593000368}},{"t":1593000420,"p":{"ppi":{"l":174.09,"v":607305},"bitfinex":{"l":174.23,"v":185890},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"4a24431b378f1b04d367eb394a4b445a7839548f0fe87a1f4dd25ed8692c97d3","t":1593000428}},{"t":1593000480,"p":{"ppi":{"l":174.09,"v":607305},"bitfinex":{"l":174.23,"v":185890},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"6b7f665cee40245fe92c331fad973663a8f897ae5ed297cfad268b7a109214a5","t":1593000489}},{"t":1593000540,"p":{"ppi":{"l":174.09,"v":607305},"bitfinex":{"l":174.23,"v":185890},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"f444be0cafc7f128c642daf7e95fd1d3ab4688a0f7a6b327db7601156141fe09","t":1593000549}},{"t":1593000660,"p":{"ppi":{"l":174.09,"v":607305},"bitfinex":{"l":174.23,"v":185890},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"26e82000d4319dc0856d0481ad5ca200f46ab5aca04f91609e236278d4ee9406","t":1593000668}},{"t":1593000720,"p":{"ppi":{"l":174.09,"v":607305},"bitfinex":{"l":174.23,"v":185890},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"c9bf14c06b31f8d5eaec03aa1301fbe4760960fc442c44919af524e2e3071f37","t":1593000728}},{"t":1593000780,"p":{"ppi":{"l":174.18,"v":608268},"bitfinex":{"l":174.53,"v":186853},"bittrex":{"l":173.98,"v":389571},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"451a47b384cdf3ca89cf669b2b4b251160b210d02af43eba0647880adafe610f","t":1593000788}},{"t":1593000840,"p":{"ppi":{"l":174.18,"v":607288},"bitfinex":{"l":174.53,"v":186853},"bittrex":{"l":173.98,"v":388591},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"afea836b7c6a2fec1781fdeed303e1cbd321531ca97f290231d9543c089fdfeb","t":1593000848}},{"t":1593000960,"p":{"ppi":{"l":174.21,"v":610923},"bitfinex":{"l":174.61,"v":190488},"bittrex":{"l":173.98,"v":388591},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"9526bbf89c9e281c525f8ec33d0a743f43cd8b258dcacd1c2ba14125bb23e50a","t":1593000968}},{"t":1593001020,"p":{"ppi":{"l":174.31,"v":618757},"bitfinex":{"l":174.74,"v":196829},"bittrex":{"l":174.07,"v":390084},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"bf2d2f53902ce99de7484ac212e1fcfdff668823791e4676762137be0d9a3295","t":1593001028}},{"t":1593001080,"p":{"ppi":{"l":174.39,"v":619840},"bitfinex":{"l":174.74,"v":197443},"bittrex":{"l":174.19,"v":390553},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"7905b55591ac7ee0131542497ebccd49356c14e559894e3dfcd172820dcc874b","t":1593001088}},{"t":1593001140,"p":{"ppi":{"l":174.39,"v":619840},"bitfinex":{"l":174.74,"v":197443},"bittrex":{"l":174.19,"v":390553},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"a7435db8c6f252faba7c47226b423070961439b501708a5c4f83e22ac9f4ca1c","t":1593001149}},{"t":1593001260,"p":{"ppi":{"l":174.38,"v":610569},"bitfinex":{"l":174.74,"v":188172},"bittrex":{"l":174.19,"v":390553},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"6578339a700158d17e747f3b234d739bad0a394124fc8da81712b0f3c24057cb","t":1593001268}},{"t":1593001320,"p":{"ppi":{"l":174.38,"v":610569},"bitfinex":{"l":174.74,"v":188172},"bittrex":{"l":174.19,"v":390553},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"7b5983f85d6bc0a779042b24e6a5ad86ab462a2c3761f2ada994ba9e7005192e","t":1593001329}},{"t":1593001380,"p":{"ppi":{"l":174.38,"v":610569},"bitfinex":{"l":174.74,"v":188172},"bittrex":{"l":174.19,"v":390553},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"41ff569ecc1ecddb68a3af19169bac05c878ab98af24051459da1675f9741e01","t":1593001399}},{"t":1593001440,"p":{"ppi":{"l":174.38,"v":610569},"bitfinex":{"l":174.74,"v":188172},"bittrex":{"l":174.19,"v":390553},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"5fe3eb65a76a4aa91d4392c43fd4ecb3dd80e6068b82380a006f9bac510ac7e3","t":1593001448}},{"t":1593001560,"p":{"ppi":{"l":174.38,"v":608263},"bitfinex":{"l":174.74,"v":188172},"bittrex":{"l":174.19,"v":388247},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"40dbf2b6f94c80d54ecf670bf121bdd91553f5e7607ee5fbf414fe770ce059b6","t":1593001568}},{"t":1593001620,"p":{"ppi":{"l":174.38,"v":607790},"bitfinex":{"l":174.74,"v":188172},"bittrex":{"l":174.19,"v":387774},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"84bb85f3634bed28533b48fb95cc139052c9eb039613659449fc07fc99d9952d","t":1593001628}},{"t":1593001680,"p":{"ppi":{"l":174.54,"v":613044},"bitfinex":{"l":175.24,"v":193584},"bittrex":{"l":174.19,"v":387616},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"b8c86d080ef26d4d7b3fb652cd3be164ab8d1d7efccac77d9a0fd1294508c03f","t":1593001688}},{"t":1593001740,"p":{"ppi":{"l":174.6,"v":616629},"bitfinex":{"l":175.4,"v":197356},"bittrex":{"l":174.19,"v":387429},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"ce10afe555415086a8b7fde5840efc2d32e8695b1c266e5fbd95a9497e2078b2","t":1593001748}},{"t":1593001860,"p":{"ppi":{"l":174.47,"v":616014},"bitfinex":{"l":175,"v":197686},"bittrex":{"l":174.19,"v":386484},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"fe889a967afa3439e0ed720b644736afa1a11dfabd5fcdba58aeb15f61241094","t":1593001869}},{"t":1593001920,"p":{"ppi":{"l":174.47,"v":615541},"bitfinex":{"l":175,"v":197686},"bittrex":{"l":174.19,"v":386011},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"428eec163ef7345ff63e0b648928980822ec1cf27fe38d0eacb652e41b7243d0","t":1593001928}},{"t":1593001980,"p":{"ppi":{"l":174.47,"v":615225},"bitfinex":{"l":175,"v":197686},"bittrex":{"l":174.19,"v":385695},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"666fd2663570eeb156cd152855366ad9db3092ae014cb525e36c6209467f781b","t":1593001988}},{"t":1593002040,"p":{"ppi":{"l":174.47,"v":614595},"bitfinex":{"l":175,"v":197686},"bittrex":{"l":174.19,"v":385065},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"06bdebb9da6c9ed63490b2b71a2691712c8b1ca3ef819eb9d5b7f5f7f097bc81","t":1593002048}},{"t":1593002160,"p":{"ppi":{"l":174.47,"v":605406},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":384818},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"e2593daf66f3c9f408de8a9b344138280c0de3d926a329d1828ef75475a13cea","t":1593002169}},{"t":1593002220,"p":{"ppi":{"l":174.47,"v":605406},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":384818},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"872da88fa60f99d252e72c315bde0592d2d35db335218a14688b6702f832faa9","t":1593002228}},{"t":1593002280,"p":{"ppi":{"l":174.47,"v":605406},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":384818},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"2b1f5cef84f10708266d0b6915e91add092e4d68da84d6212f818af4f7cc42cf","t":1593002288}},{"t":1593002340,"p":{"ppi":{"l":174.47,"v":605406},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":384818},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"5c5dce8beeb95c4e3f228a1f31c3dc3cef3261d814cea53e5fb7ce0e3e3e1398","t":1593002348}},{"t":1593002460,"p":{"ppi":{"l":174.47,"v":605397},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":384809},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"4b4871c4a39f3e995457f21649daf67863b70e66c6d9eafc45cc588b80dad66f","t":1593002469}},{"t":1593002520,"p":{"ppi":{"l":174.47,"v":605397},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":384809},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"c9aa3ac63303b47b6b9732bf259c2684c50506c9c28938673909e55fd1468717","t":1593002530}},{"t":1593002580,"p":{"ppi":{"l":174.47,"v":602730},"bitfinex":{"l":175,"v":188744},"bittrex":{"l":174.19,"v":382142},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"b477d6ca7afcd6af5dfe0e0d82bf8dc398ee2bce341a3847e9b54b56b42fec5a","t":1593002588}},{"t":1593002640,"p":{"ppi":{"l":174.42,"v":602615},"bitfinex":{"l":174.84,"v":188629},"bittrex":{"l":174.19,"v":382142},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"a907d5297497c19489abfabe1c3f62b237cfd3ece9fc89050fcb308f3832636e","t":1593002649}},{"t":1593002760,"p":{"ppi":{"l":174.42,"v":600655},"bitfinex":{"l":174.85,"v":189372},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":176.71,"v":3926},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"19b9b1ac1471bc8831223ea0b66bef562822b2358b351845d19ff99907e3c30f","t":1593002769}},{"t":1593002820,"p":{"ppi":{"l":174.41,"v":601367},"bitfinex":{"l":174.85,"v":189372},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.35,"v":27918}},"tx":{"h":"8c14b1e6c38594212cf23c4782421ef9a6c61f39fe29388344431236fefb785c","t":1593002828}},{"t":1593002880,"p":{"ppi":{"l":174.41,"v":601366},"bitfinex":{"l":174.85,"v":189372},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.35,"v":27917}},"tx":{"h":"08e06d376cb0e7826281692529d7845f2f5dfd52f78f90761449b3310baf9e6f","t":1593002888}},{"t":1593002940,"p":{"ppi":{"l":174.41,"v":601366},"bitfinex":{"l":174.85,"v":189372},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.35,"v":27917}},"tx":{"h":"12279f9cdd24bf393a8dbb3e62b22c7c6334a9e5b7697599b45a674bbfe5d506","t":1593002949}},{"t":1593003060,"p":{"ppi":{"l":174.41,"v":601342},"bitfinex":{"l":174.85,"v":189348},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.35,"v":27917}},"tx":{"h":"79343e92453ddd66f154fa96ee3b46e9d119c35316f2b1b444c676aa4d0fe921","t":1593003068}},{"t":1593003120,"p":{"ppi":{"l":174.41,"v":601342},"bitfinex":{"l":174.85,"v":189348},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.35,"v":27917}},"tx":{"h":"cc0693a47d2411488a8b02902d82838865504b38692e84f549c4fe534574b047","t":1593003128}},{"t":1593003180,"p":{"ppi":{"l":174.4,"v":602318},"bitfinex":{"l":174.8,"v":189880},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"1749a027ceb15673df1092eab9d1a4136a2c65c696ce0276d36a43d15b6049e9","t":1593003200}},{"t":1593003240,"p":{"ppi":{"l":174.43,"v":602440},"bitfinex":{"l":174.89,"v":190002},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"c04d3400f4a9fd6b8e7e806a0d31eacdd86489d3a610134bf4f319d88f13871b","t":1593003249}},{"t":1593003360,"p":{"ppi":{"l":174.43,"v":602440},"bitfinex":{"l":174.89,"v":190002},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"cc794dfce24746f0cbab3d5034336e7df3f844b04f6c635249a0b6f457bdb289","t":1593003369}},{"t":1593003420,"p":{"ppi":{"l":174.43,"v":602440},"bitfinex":{"l":174.89,"v":190002},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"156b8704a67ff9343d9d153bf72a2e7736fa5a8d925c08e3368f7ba90cd607b9","t":1593003429}},{"t":1593003480,"p":{"ppi":{"l":174.43,"v":602904},"bitfinex":{"l":174.89,"v":190466},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"62feac88ff94532d17a6a1c3e9e9c8686571e236940dbfa57acd3400bd7445f9","t":1593003495}},{"t":1593003540,"p":{"ppi":{"l":174.43,"v":602904},"bitfinex":{"l":174.89,"v":190466},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"2f34c0124a0a37c4ccadaeff662eaa1a30451bba983d53ffba82f89c6445ae39","t":1593003548}},{"t":1593003660,"p":{"ppi":{"l":174.43,"v":602904},"bitfinex":{"l":174.89,"v":190466},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"1d1dac8378979009bc8ba0f96c303431e2c2e9c55fa68f1c6e2780297709a7c7","t":1593003669}},{"t":1593003720,"p":{"ppi":{"l":174.43,"v":602904},"bitfinex":{"l":174.89,"v":190466},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"3f20c8fdab76793d32d474ac59f7645fb765952af8714d1885c5076074f76a6c","t":1593003728}},{"t":1593003780,"p":{"ppi":{"l":174.43,"v":602904},"bitfinex":{"l":174.89,"v":190466},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"b80185622dce17773e28401e19a3b77f8f27f6613c94e45bfccd71e0f09e6bed","t":1593003788}},{"t":1593003840,"p":{"ppi":{"l":174.43,"v":603275},"bitfinex":{"l":174.89,"v":190837},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"59d1b35569b85ebf421c552899f0861c564e3d28fb95de4038be9fa85ecd913f","t":1593003848}},{"t":1593003960,"p":{"ppi":{"l":174.43,"v":602836},"bitfinex":{"l":174.89,"v":190398},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"e8a68d48fc716018897afa3e86f0a0cd8245f876b5f16a5a9541a935087a58ed","t":1593003968}},{"t":1593004020,"p":{"ppi":{"l":174.43,"v":603302},"bitfinex":{"l":174.89,"v":190864},"bittrex":{"l":174.19,"v":379439},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.51,"v":28361}},"tx":{"h":"44b7f64a9ef1d61608930f137f5815ddff32544f722aea1ced81b46d5f6e7bea","t":1593004029}},{"t":1593004080,"p":{"ppi":{"l":174.6,"v":607601},"bitfinex":{"l":174.89,"v":193409},"bittrex":{"l":174.47,"v":381193},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.43,"v":28361}},"tx":{"h":"d5d83322ff75009598765dbff729885309d97f76f79432347a1f2e8c830c548e","t":1593004089}},{"t":1593004140,"p":{"ppi":{"l":174.66,"v":609248},"bitfinex":{"l":174.9,"v":194637},"bittrex":{"l":174.56,"v":381608},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.43,"v":28365}},"tx":{"h":"170df862d4a85ee3354c1f9abe9a19e3430967ccd553b6655d5063e0c93b2687","t":1593004148}},{"t":1593004260,"p":{"ppi":{"l":174.74,"v":610158},"bitfinex":{"l":174.9,"v":194637},"bittrex":{"l":174.68,"v":382518},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.43,"v":28365}},"tx":{"h":"ae274ee35464d54df9d4f6f9521f10055ac2c946305a596eeefaf5fa5b64992e","t":1593004268}},{"t":1593004320,"p":{"ppi":{"l":174.74,"v":609830},"bitfinex":{"l":174.9,"v":194637},"bittrex":{"l":174.68,"v":382190},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.43,"v":28365}},"tx":{"h":"1d875e9b47357f0860b9dbd1d5f4a3bdf7aa11fb2731dd6ad38ab31bc662be45","t":1593004335}},{"t":1593004380,"p":{"ppi":{"l":174.74,"v":609915},"bitfinex":{"l":174.9,"v":194637},"bittrex":{"l":174.68,"v":382275},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.43,"v":28365}},"tx":{"h":"2db70b29f2fd55f686e6110cf45b3600e5327bf41dca3fb315b661467655222a","t":1593004388}},{"t":1593004440,"p":{"ppi":{"l":174.74,"v":609915},"bitfinex":{"l":174.9,"v":194637},"bittrex":{"l":174.68,"v":382275},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.43,"v":28365}},"tx":{"h":"43204a2e764076237525c3ca41220e205a858d049f9be42bf9c4d57633ff299a","t":1593004448}},{"t":1593004560,"p":{"ppi":{"l":175.05,"v":615133},"bitfinex":{"l":175.5,"v":196195},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":28461}},"tx":{"h":"8742c4473a4bfdf252198a69bb451cbe3be8175bb3afca2505634b29b3629129","t":1593004568}},{"t":1593004620,"p":{"ppi":{"l":175.04,"v":616118},"bitfinex":{"l":175.46,"v":197180},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":28461}},"tx":{"h":"d1f5be6934a185b092ac0891b4444b18dc8109caa387d984b05ed92cfa0d3139","t":1593004628}},{"t":1593004680,"p":{"ppi":{"l":175.04,"v":616540},"bitfinex":{"l":175.46,"v":197602},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":28461}},"tx":{"h":"4eda5b3e705afa1a5d97794482b57821fba8767bb30750d570eadeccd9734856","t":1593004688}},{"t":1593004740,"p":{"ppi":{"l":175.01,"v":617980},"bitfinex":{"l":175.36,"v":199667},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27836}},"tx":{"h":"3019925b4043e720e864313a8afc3ba31c0c3ee1f10fbe5015406accc50826a2","t":1593004748}},{"t":1593004860,"p":{"ppi":{"l":175.01,"v":617713},"bitfinex":{"l":175.36,"v":199667},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27569}},"tx":{"h":"1c41b8b8e63885013548256083bc072e9f923a995c4fce1b143057718f554eef","t":1593004868}},{"t":1593004920,"p":{"ppi":{"l":175.01,"v":622503},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27569}},"tx":{"h":"dafbe403b1917d72553109cd7866f805b8a92d3c4bfbf9f209705a82320ff38c","t":1593004929}},{"t":1593004980,"p":{"ppi":{"l":175.01,"v":622503},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385839},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27569}},"tx":{"h":"9ad3c8e69ba36849411f2e45dd37c0c6d94766788e6193cf1eeb07110973eb8c","t":1593005000}},{"t":1593005040,"p":{"ppi":{"l":175.01,"v":622477},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385813},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27569}},"tx":{"h":"9d94f7ef1aa1be84d96cc378baa5fa93586f7a97fb2767762cfda11b26eebef3","t":1593005048}},{"t":1593005160,"p":{"ppi":{"l":175.01,"v":622477},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385813},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27569}},"tx":{"h":"4481672b9eaf2a446cfce24aaef12c1c42827cf39d29e0274e0e3899244c872a","t":1593005169}},{"t":1593005220,"p":{"ppi":{"l":175.01,"v":621997},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385813},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"892c3b1f24b9ecebdfeeb9840ce7a69f6bb81a4ead70edb16414e4fa55286b42","t":1593005228}},{"t":1593005280,"p":{"ppi":{"l":175.01,"v":621997},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385813},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"422fba9a7ac96bf3e4dfa877ffd2c48523ca96df5f957d234c02fc3f77fcdd42","t":1593005288}},{"t":1593005340,"p":{"ppi":{"l":175.01,"v":621997},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385813},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"5d249f398d8455be1fc6ae5fc733e2e1d745776aad7a83108b17176eefbfcb46","t":1593005348}},{"t":1593005460,"p":{"ppi":{"l":175.01,"v":621901},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"d0519c64a2c189433d32039aea675f842dc5885fd1465220feae34028637a1aa","t":1593005468}},{"t":1593005520,"p":{"ppi":{"l":175.01,"v":621901},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"a791476c0c769ee14e484bd4debaebb53c46a7dc10239478126b552d5bbe5984","t":1593005529}},{"t":1593005580,"p":{"ppi":{"l":175.01,"v":621901},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"a2e1282e22ee1f969a2d502d1b0fefdb74f8db3c781a0b37b89189d05096ab27","t":1593005596}},{"t":1593005640,"p":{"ppi":{"l":175.01,"v":621901},"bitfinex":{"l":175.36,"v":204457},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"45818510cbcd91d06f432919c2ef468751d49a110e93c3e26e9fc0658a54de0e","t":1593005648}},{"t":1593005760,"p":{"ppi":{"l":175.01,"v":620678},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"c095bb0d70a0db1cce319e42b4b59fef9d060aa17b079c0a377a3f47c1acf0d2","t":1593005768}},{"t":1593005820,"p":{"ppi":{"l":175.01,"v":620678},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"e2dfd7b48ccf801381d9a12841e8fd2b505cae4596bb9e38d39b6c805166be85","t":1593005829}},{"t":1593005880,"p":{"ppi":{"l":175.01,"v":620678},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"0a5e2e94bf56977583d07768cd89ba2bac32f1f483db95b3ba8dbd2d261cb96a","t":1593005888}},{"t":1593005940,"p":{"ppi":{"l":175.01,"v":620678},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"f671ff01d4eae84c08be412ec597500090e1d3d62ae17e6216adc0901000ab14","t":1593005948}},{"t":1593006060,"p":{"ppi":{"l":175.01,"v":620678},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385717},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"2a44a981be6d7ae9c1fb344d8c9b2061045990aba35db6552af5bc636c05c824","t":1593006068}},{"t":1593006120,"p":{"ppi":{"l":175.01,"v":620513},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385552},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"39cd7ebfe4edf030fc7c69eb4b7d034241f4fd6ef42d8207e485edb9fb6f637b","t":1593006128}},{"t":1593006180,"p":{"ppi":{"l":175.01,"v":620513},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385552},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"65c1406179564c322339d7860b473e874cead5491c31c0960de933bf2672c44c","t":1593006188}},{"t":1593006240,"p":{"ppi":{"l":175.01,"v":620513},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385552},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"ef7a2bbb86ec5cb03c7b42708640091a42519b36ab4fe150a1f71354ba596290","t":1593006248}},{"t":1593006360,"p":{"ppi":{"l":175.01,"v":620513},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":385552},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"729c06d0e9c7ab9d43b962e9a5df082ffe39b21c4dbccd96cba42842e850050e","t":1593006368}},{"t":1593006420,"p":{"ppi":{"l":175.01,"v":619266},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":384305},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"d77f79eed1475fb6379d5c895d761f98e0fc2a0733770b1c5854ec3427746588","t":1593006429}},{"t":1593006480,"p":{"ppi":{"l":175.01,"v":619266},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":384305},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"c6a2362fbc570cc2e24026fd8a8976fd34a8949ae9cb8141696d3fd7b19c7261","t":1593006488}},{"t":1593006540,"p":{"ppi":{"l":175.01,"v":619091},"bitfinex":{"l":175.36,"v":203234},"bittrex":{"l":174.85,"v":384130},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"55c2466bb3a69a3d2276bd269e101110ecdcaa0ec981e27271317013964edda8","t":1593006548}},{"t":1593006660,"p":{"ppi":{"l":175.01,"v":618908},"bitfinex":{"l":175.36,"v":203051},"bittrex":{"l":174.85,"v":384130},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"58d2f33186fad3b8fa8f153fb5cd1339c012a7b73074767bfd29637006d14408","t":1593006668}},{"t":1593006720,"p":{"ppi":{"l":174.88,"v":618999},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.85,"v":384130},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"22d7710addbb1d2435006697596db023e904c880d0dea449f124d092345a0d80","t":1593006728}},{"t":1593006780,"p":{"ppi":{"l":174.88,"v":618999},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.85,"v":384130},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"9759ead82cb691f2678cfc5d3dc9adabb659010f93719e25dcfea97c4773824d","t":1593006801}},{"t":1593006840,"p":{"ppi":{"l":174.88,"v":618999},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.85,"v":384130},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"9826e85238514519965700006d50c67130ba970cd49495f589a69d21d5204b0c","t":1593006855}},{"t":1593006960,"p":{"ppi":{"l":174.57,"v":621199},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.35,"v":386330},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"7952016f59e564fa1e498362bec29e40cf9f87ae926938cc98d4cb2f65c82c3e","t":1593006969}},{"t":1593007020,"p":{"ppi":{"l":174.57,"v":621199},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.35,"v":386330},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"676939a3f748b74f625f2bc82b65d18b069642b88a6a936444369982b254fd07","t":1593007028}},{"t":1593007080,"p":{"ppi":{"l":174.57,"v":621199},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.35,"v":386330},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"90473d8fcb4f1cd9c713307ee5c699c0c7fb60c0335778e5ca577a8ca24a4ac4","t":1593007096}},{"t":1593007140,"p":{"ppi":{"l":174.57,"v":621199},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":174.35,"v":386330},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.66,"v":27089}},"tx":{"h":"16322d35cbabac093e747955e4869513fbe2e6bae317fe88243ef6d7b159d4b6","t":1593007155}},{"t":1593007260,"p":{"ppi":{"l":174.29,"v":623049},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":173.93,"v":388179},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.17,"v":27090}},"tx":{"h":"dfa5057ba90f8136c110447844779168971a811d993ed6efc2429254e1b5b62d","t":1593007275}},{"t":1593007320,"p":{"ppi":{"l":174.29,"v":623049},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":173.93,"v":388179},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.17,"v":27090}},"tx":{"h":"2ac17a37d25a82fa2598a1b185c6479d88da683b084961affe57721d95d95491","t":1593007328}},{"t":1593007380,"p":{"ppi":{"l":174.29,"v":623049},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":173.93,"v":388179},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.17,"v":27090}},"tx":{"h":"923aa0cb8c82a9faa3a662441c7ecfdb1ec79288ee75889deb502efd20280078","t":1593007388}},{"t":1593007440,"p":{"ppi":{"l":174.29,"v":623050},"bitfinex":{"l":174.97,"v":203142},"bittrex":{"l":173.93,"v":388179},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.34,"v":27091}},"tx":{"h":"ae84b3d901477132f2f9fdd44319ec51834e74c7c352cc030a00859e2544d790","t":1593007448}},{"t":1593007560,"p":{"ppi":{"l":174.3,"v":609153},"bitfinex":{"l":174.97,"v":202323},"bittrex":{"l":173.93,"v":375100},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.26,"v":27092}},"tx":{"h":"f606790fb3749a7dd01ace796f1dffddba8f8502666ce8648657f35ad6027f41","t":1593007569}},{"t":1593007620,"p":{"ppi":{"l":174.3,"v":609053},"bitfinex":{"l":174.97,"v":202323},"bittrex":{"l":173.93,"v":375100},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.26,"v":26992}},"tx":{"h":"63d019d4823525b1ae1f46360391d581aca75a35bac97e95bb6b7bfa2256417f","t":1593007635}},{"t":1593007680,"p":{"ppi":{"l":174.3,"v":609053},"bitfinex":{"l":174.97,"v":202323},"bittrex":{"l":173.93,"v":375100},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.35,"v":26992}},"tx":{"h":"aa846bf1e500b781ef1fc214a636765a3f7b02a99ef3a8c5497042d5866cfd2b","t":1593007689}},{"t":1593007740,"p":{"ppi":{"l":174.31,"v":609051},"bitfinex":{"l":174.97,"v":202323},"bittrex":{"l":173.93,"v":375096},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.46,"v":26994}},"tx":{"h":"36e7669ab3402db11dc4b6c1e1f3d5ab0712b53af5a2634810fbc4d3c1c0087b","t":1593007748}},{"t":1593007860,"p":{"ppi":{"l":174.07,"v":608526},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":375096},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.32,"v":27199}},"tx":{"h":"691ff11bfaa17fc5f4d3909da0100cd716dcc481ef4619944627ff561885265c","t":1593007868}},{"t":1593007920,"p":{"ppi":{"l":174.07,"v":608526},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":375096},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.32,"v":27199}},"tx":{"h":"a8f5770704f92cee1289d4cb9ed5a289b6d8aa34088e33dbb1fe0b3fd1fe4e25","t":1593007928}},{"t":1593007980,"p":{"ppi":{"l":174.07,"v":608526},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":375096},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.32,"v":27199}},"tx":{"h":"2c263ff265b68fcdd2ed8048bb527f555b9794c047693ce9d40245abb168471a","t":1593007988}},{"t":1593008040,"p":{"ppi":{"l":174.08,"v":608527},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":375096},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27200}},"tx":{"h":"3f4925f9baeb245f0c10583b22676aeb2a88a625b9d4598690e70eedbc41d11e","t":1593008048}},{"t":1593008160,"p":{"ppi":{"l":174.08,"v":601580},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":368147},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"b75e70a056a0559fdedfeb67f583b9995108641c21696e248741dd3a9a9a69e0","t":1593008168}},{"t":1593008220,"p":{"ppi":{"l":174.08,"v":601580},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":368147},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"f3ebadb0685c7becd0e290a6bf5126ddbc3469dbb5c17e8a34873c618b38581e","t":1593008228}},{"t":1593008280,"p":{"ppi":{"l":174.08,"v":601580},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":368147},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"abab79f6f4de21ca5ea4c7b086e0289b488ce39990dab16f0a56b073071ddbe9","t":1593008288}},{"t":1593008340,"p":{"ppi":{"l":174.08,"v":601580},"bitfinex":{"l":174.29,"v":201593},"bittrex":{"l":173.93,"v":368147},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"e468c730316ea56857bfc955ef59cb7ff3ed0806c8dd15c11095b3638bdd1bd3","t":1593008348}},{"t":1593008460,"p":{"ppi":{"l":174.08,"v":600032},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.93,"v":368147},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"76e756c4035f2a6dd5c7db534a0632f3e5dca8fed16d7d351ee2363602b85a4c","t":1593008475}},{"t":1593008520,"p":{"ppi":{"l":173.8,"v":601593},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.47,"v":369708},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"7e606891f260b22eec2d9084b5614cc606c86895254d54ed12d6f0e093405daa","t":1593008528}},{"t":1593008580,"p":{"ppi":{"l":173.75,"v":601853},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.4,"v":369968},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"d1200feb7bff4e0ecc9fbdfe0be22ba6ca03c37af2f3edb370abda960e0fa227","t":1593008602}},{"t":1593008640,"p":{"ppi":{"l":173.75,"v":601853},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.4,"v":369968},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.42,"v":27202}},"tx":{"h":"182b8b9409dad46660eeb212f6413a103add4b22a257a706ba580c4cde6ee527","t":1593008648}},{"t":1593008760,"p":{"ppi":{"l":173.73,"v":601854},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.4,"v":369968},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.88,"v":27203}},"tx":{"h":"eb7689fc1136218975abc947756ba89a8cf2476c66a7219cec4da940b033d30e","t":1593008769}},{"t":1593008820,"p":{"ppi":{"l":173.73,"v":601855},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.4,"v":369968},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.87,"v":27204}},"tx":{"h":"f49a554c9db6ff8bc7228e7d4d56cc6b20d77e77b3cfa02dc238645aaeb76709","t":1593008828}},{"t":1593008880,"p":{"ppi":{"l":173.68,"v":602440},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.37,"v":370453},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.26,"v":27304}},"tx":{"h":"4f9f4ecb661223a52d41de3bfa49e1e2b78006c17c27eef63f1d31c2450cc3e8","t":1593008888}},{"t":1593008940,"p":{"ppi":{"l":173.48,"v":605235},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.04,"v":373248},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.26,"v":27304}},"tx":{"h":"e83fd0f9ec44e6adc1b9f4e495f5da34b7232dec74e27b04c794406a76db1a61","t":1593008949}},{"t":1593009060,"p":{"ppi":{"l":173.49,"v":603915},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.04,"v":371927},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.48,"v":27305}},"tx":{"h":"1234866ce6f477d5d8f25a9a8d603239e3a7d2a38c990b41d138de6fe8e396b7","t":1593009075}},{"t":1593009120,"p":{"ppi":{"l":173.51,"v":603916},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.04,"v":371927},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.91,"v":27306}},"tx":{"h":"1fcfd91fdc41581662f977450f7446bc948ff38c70045118e2ef9de79ddd4a85","t":1593009128}},{"t":1593009180,"p":{"ppi":{"l":173.5,"v":603916},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.04,"v":371927},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.84,"v":27306}},"tx":{"h":"5b870df055f12cf56fb23ad3ce7defe05c8c6b8b7b3921a230ff71e2608797a9","t":1593009195}},{"t":1593009240,"p":{"ppi":{"l":173.51,"v":603917},"bitfinex":{"l":174.29,"v":200045},"bittrex":{"l":173.04,"v":371927},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.92,"v":27307}},"tx":{"h":"03eb0ef07e103332b9265927a47027c95a54b481dba65ac217dfe9c3230fab3a","t":1593009249}},{"t":1593009360,"p":{"ppi":{"l":173.47,"v":603540},"bitfinex":{"l":174.29,"v":199477},"bittrex":{"l":173.04,"v":371927},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.05,"v":27498}},"tx":{"h":"c7c54240c3882b370e7c79abda34acf88f50a5c035d2d8aaca6449b2f1340a5a","t":1593009368}},{"t":1593009420,"p":{"ppi":{"l":173.47,"v":603540},"bitfinex":{"l":174.29,"v":199477},"bittrex":{"l":173.04,"v":371927},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.05,"v":27498}},"tx":{"h":"4e828b99c076bc72fc0ad73bfb64afdfb001eefbe5cbcb9c7be94f657e8d0c37","t":1593009429}},{"t":1593009480,"p":{"ppi":{"l":173.47,"v":602941},"bitfinex":{"l":174.29,"v":199477},"bittrex":{"l":173.04,"v":371328},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.05,"v":27498}},"tx":{"h":"eb67e910f22333273ce0a1881da243f3618da94d26df60302b94080c6dda96c9","t":1593009488}},{"t":1593009540,"p":{"ppi":{"l":173.05,"v":603326},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.93,"v":372740},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.05,"v":27498}},"tx":{"h":"1bfd1b09f7e1791837e6b4ad4499e916decbae36f1c17fed308e0db2b8df9bd8","t":1593009549}},{"t":1593009660,"p":{"ppi":{"l":172.83,"v":606263},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.05,"v":27498}},"tx":{"h":"966656a295df5cd52cdfd261baaf1b8b77e979fe9d5d43900b8d1bbeef4380ea","t":1593009675}},{"t":1593009720,"p":{"ppi":{"l":172.83,"v":606263},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.05,"v":27498}},"tx":{"h":"915175dd2e80240e2e1241d0d2c5cfeb3af7bf24f43d6632ab76c82a9d31033d","t":1593009736}},{"t":1593009780,"p":{"ppi":{"l":172.84,"v":606263},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.17,"v":27498}},"tx":{"h":"214167e119cfda769c35cbd85cd8b489d44ebe83359163bc925246ca85646dcb","t":1593009789}},{"t":1593009840,"p":{"ppi":{"l":172.85,"v":606264},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.31,"v":27499}},"tx":{"h":"8a8d5ba0f0f942b19b3713cc60b93a20b72adcf750a092a31007f3022824fa9c","t":1593009849}},{"t":1593009960,"p":{"ppi":{"l":172.83,"v":606266},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.95,"v":27501}},"tx":{"h":"9793f74521b56efe727796cd505e2332ccdef258702ee30cb3dbed1bbc8331e5","t":1593009975}},{"t":1593010020,"p":{"ppi":{"l":172.83,"v":606266},"bitfinex":{"l":173.24,"v":198450},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.95,"v":27501}},"tx":{"h":"a80690280491ce30c487adb1259d8f28a55cf0cc703761a32ea738fab07a9f49","t":1593010035}},{"t":1593010080,"p":{"ppi":{"l":172.73,"v":606440},"bitfinex":{"l":172.94,"v":198624},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.95,"v":27501}},"tx":{"h":"da9aaba7814e0065d8d237158d5f2d017b004eb49eb7ebd27231c7477c382d23","t":1593010088}},{"t":1593010140,"p":{"ppi":{"l":172.74,"v":606441},"bitfinex":{"l":172.94,"v":198624},"bittrex":{"l":172.58,"v":375677},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.12,"v":27502}},"tx":{"h":"07ed4feb8491368745da9ffedd6992ef050a41d0238aba0ef056ccc98cc47f87","t":1593010148}},{"t":1593010260,"p":{"ppi":{"l":173.18,"v":607950},"bitfinex":{"l":173.29,"v":199070},"bittrex":{"l":173.01,"v":376738},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":174.33,"v":27504}},"tx":{"h":"9035ef00512d2a8bd3c7c44b6f130bf5cf5db17f484bfc727929418b92f186e1","t":1593010269}},{"t":1593010320,"p":{"ppi":{"l":173.14,"v":607330},"bitfinex":{"l":173.29,"v":199070},"bittrex":{"l":173.01,"v":376117},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.64,"v":27505}},"tx":{"h":"273cafaaf0b943b9da1f14f82bf80404bcb0b604126096c2525b45ccc8c22a50","t":1593010335}},{"t":1593010380,"p":{"ppi":{"l":173.14,"v":607330},"bitfinex":{"l":173.29,"v":199070},"bittrex":{"l":173.01,"v":376117},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.64,"v":27505}},"tx":{"h":"4f4417e23bcd31898a3d5c9226ac9fe71365a079997fcc7707e0971cab8adb25","t":1593010403}},{"t":1593010440,"p":{"ppi":{"l":173.14,"v":607330},"bitfinex":{"l":173.29,"v":199070},"bittrex":{"l":173.01,"v":376117},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.64,"v":27505}},"tx":{"h":"20ac2a091cd84df2ceab3d5b7679d866cae252436b64ebceba2bc85807476148","t":1593010449}},{"t":1593010560,"p":{"ppi":{"l":173.08,"v":608268},"bitfinex":{"l":173.08,"v":200008},"bittrex":{"l":173.01,"v":376117},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.64,"v":27505}},"tx":{"h":"b933501bc7c07acb308d86924eaea8b0dee2361dc9d80be78e0c87431187e863","t":1593010568}},{"t":1593010620,"p":{"ppi":{"l":173.03,"v":608709},"bitfinex":{"l":173.01,"v":200448},"bittrex":{"l":173.01,"v":376117},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.13,"v":27506}},"tx":{"h":"7c677b8be7f4e4a37ed0034beb623b94957fe705dbebe53a1cc8bcdeac4c15e2","t":1593010629}},{"t":1593010680,"p":{"ppi":{"l":173.03,"v":608709},"bitfinex":{"l":173.01,"v":200448},"bittrex":{"l":173.01,"v":376117},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.13,"v":27506}},"tx":{"h":"57b2b61e70674f9286936d6875a9bac2d28488c6014e4bf91d9c32c5bd1fe6ee","t":1593010689}},{"t":1593010740,"p":{"ppi":{"l":172.9,"v":609763},"bitfinex":{"l":173.01,"v":200448},"bittrex":{"l":172.79,"v":377171},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.18,"v":27506}},"tx":{"h":"eb356d402967c99f89df921e3ee87d1ee28dd92a824c83d64bdb058634e880b3","t":1593010749}},{"t":1593010860,"p":{"ppi":{"l":172.52,"v":612530},"bitfinex":{"l":172.37,"v":200549},"bittrex":{"l":172.53,"v":379836},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":173.18,"v":27507}},"tx":{"h":"c4850d6c47a8b515394a85386502563d53b1137e8f27ac483f60d4a4ddcffffd","t":1593010868}},{"t":1593010920,"p":{"ppi":{"l":172.28,"v":608885},"bitfinex":{"l":171.8,"v":200358},"bittrex":{"l":172.53,"v":376382},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":171.88,"v":27507}},"tx":{"h":"ffa2ee91f79b76b070151538993b6522e4b9b8acfd467cd0a25b17a83948b8ab","t":1593010928}},{"t":1593010980,"p":{"ppi":{"l":172.39,"v":611189},"bitfinex":{"l":172.14,"v":202562},"bittrex":{"l":172.53,"v":376382},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":171.88,"v":27607}},"tx":{"h":"f5e92a7db3e4a7f1e057ab79b2478269d0cb68f54ea489767977de056e6d9b0d","t":1593010988}},{"t":1593011040,"p":{"ppi":{"l":172.15,"v":613363},"bitfinex":{"l":172.35,"v":204255},"bittrex":{"l":172,"v":376862},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.37,"v":27608}},"tx":{"h":"a8c9cd54976efe5f5bac653d97e0a8b022b6f408acb282fb7e96dd8bce7be9d4","t":1593011049}},{"t":1593011160,"p":{"ppi":{"l":172.32,"v":615176},"bitfinex":{"l":172.62,"v":205374},"bittrex":{"l":172.1,"v":377554},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.76,"v":27610}},"tx":{"h":"c2c5822d3e75ee4dbe52548b48c1f3399f23f5cd03e7639568aae1c32d63d984","t":1593011168}},{"t":1593011220,"p":{"ppi":{"l":172.32,"v":615167},"bitfinex":{"l":172.62,"v":205374},"bittrex":{"l":172.1,"v":377544},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.61,"v":27611}},"tx":{"h":"7654737e87a3a4d0e7bed655121fe26f1a4c0dbdc01582991ae50bc42ccdf982","t":1593011229}},{"t":1593011280,"p":{"ppi":{"l":172.32,"v":615169},"bitfinex":{"l":172.62,"v":205374},"bittrex":{"l":172.1,"v":377544},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.57,"v":27613}},"tx":{"h":"d9532f3da8aae619171a0e2daa7049c67e018f31bbe9c46b6969d4913710cf5b","t":1593011288}},{"t":1593011340,"p":{"ppi":{"l":172.36,"v":616595},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":172.1,"v":377544},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.71,"v":27712}},"tx":{"h":"94dae838dcfa67eac78a8f086e85b9f07c379e1d95572dc361c6ad1816558246","t":1593011349}},{"t":1593011460,"p":{"ppi":{"l":172.36,"v":615949},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":172.1,"v":376914},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.7,"v":27696}},"tx":{"h":"cc9859f50111154afcb82c115d5f8318d1edb8499005e2d2b474c291e2b3d1dc","t":1593011468}},{"t":1593011520,"p":{"ppi":{"l":172.36,"v":615949},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":172.1,"v":376914},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.7,"v":27696}},"tx":{"h":"f8a0684d8178fe867a7c8398fbf6e14d7ab544577c13290e71c6f3da8e97430f","t":1593011542}},{"t":1593011580,"p":{"ppi":{"l":172.2,"v":625621},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":171.85,"v":376248},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.43,"v":38034}},"tx":{"h":"e8d70aea58537b37c7c2a31e797a04cc6a8b81d8c427e9fd6e8e897fc295119d","t":1593011588}},{"t":1593011640,"p":{"ppi":{"l":172.2,"v":625621},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":171.85,"v":376248},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.43,"v":38034}},"tx":{"h":"3e54ff7f5f068db2e234284f4b25586012dd16733bcb1fefecf2d7c2d9a1b80e","t":1593011648}},{"t":1593011760,"p":{"ppi":{"l":172.2,"v":626509},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":171.85,"v":377136},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.43,"v":38034}},"tx":{"h":"0e4d31550b73f346c6cbe8b6294b70c6e844b0fdb08b99394dc36d93caaa0f18","t":1593011775}},{"t":1593011820,"p":{"ppi":{"l":172.2,"v":618999},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":171.85,"v":369626},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.43,"v":38034}},"tx":{"h":"d4895e5200a56549a9ac76e85bcd5f70809eb48484a1c95805323824bb0bbcb7","t":1593011842}},{"t":1593011880,"p":{"ppi":{"l":172.2,"v":618994},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":171.85,"v":369626},"okcoin":{"l":174.83,"v":4638},"poloniex":{"l":172.43,"v":38029}},"tx":{"h":"6a3cf4698f1bd7d869205c20b15e3ad75a239705cb2ca36063c22241753562ca","t":1593011888}},{"t":1593011940,"p":{"ppi":{"l":172.18,"v":619512},"bitfinex":{"l":172.73,"v":206701},"bittrex":{"l":171.85,"v":369626},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.43,"v":38029}},"tx":{"h":"11566cb23d1cf23f5bc3c0c2d42705e4cb6b358bba32185cde9a12cc8e16e189","t":1593011949}},{"t":1593012060,"p":{"ppi":{"l":172.17,"v":618598},"bitfinex":{"l":172.73,"v":205786},"bittrex":{"l":171.85,"v":369626},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.3,"v":38030}},"tx":{"h":"1e9046fcc785208422b14048d8051a3a24e026a0ae8a3e5b933168c3cbd2a206","t":1593012068}},{"t":1593012120,"p":{"ppi":{"l":172.17,"v":616539},"bitfinex":{"l":172.73,"v":205786},"bittrex":{"l":171.85,"v":367566},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.29,"v":38031}},"tx":{"h":"f957a88830c7a7ae16d6b43405b06d765e2e1c3440d25f881012c465f0e7441b","t":1593012128}},{"t":1593012180,"p":{"ppi":{"l":172.17,"v":616540},"bitfinex":{"l":172.73,"v":205786},"bittrex":{"l":171.85,"v":367566},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.29,"v":38032}},"tx":{"h":"0ab9015cdd78a6743bd28fdf7fc6589fae2f51059ad35789b6d7b64b3f27b26a","t":1593012203}},{"t":1593012240,"p":{"ppi":{"l":172.16,"v":618374},"bitfinex":{"l":172.73,"v":205786},"bittrex":{"l":171.83,"v":369400},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.29,"v":38032}},"tx":{"h":"bd3a11419d93219e7c8fdef0539bf8b4f396968ef3cfc26efa140c96f8a3ee3d","t":1593012248}},{"t":1593012360,"p":{"ppi":{"l":172.07,"v":618397},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":171.83,"v":369400},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.29,"v":38032}},"tx":{"h":"0fd31e9acd2ce1a80d817c1fab2748ade7ef6d03c566a28cb388514c1e286838","t":1593012368}},{"t":1593012420,"p":{"ppi":{"l":172.07,"v":616063},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":171.83,"v":367066},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.29,"v":38032}},"tx":{"h":"4f1767e6ea2d5c131a00f9d6368b0f564113fa161b2752020290ce4d25cf5217","t":1593012428}},{"t":1593012480,"p":{"ppi":{"l":172.08,"v":616064},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":171.83,"v":367066},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.49,"v":38033}},"tx":{"h":"48bd6dab4868655c09035dade5db97ff4a96b82657d099c206bfc5ab68121706","t":1593012488}},{"t":1593012540,"p":{"ppi":{"l":172.08,"v":616064},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":171.83,"v":367066},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.49,"v":38033}},"tx":{"h":"7558d666881f10161a5c1cec4cddc8b2b4f59f5b7d5562769a8d74ba63982836","t":1593012549}},{"t":1593012660,"p":{"ppi":{"l":172.23,"v":616897},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":172.08,"v":367899},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.49,"v":38033}},"tx":{"h":"6d70855be80672f8724bb1fe1a8bf19592997a093e16a3b8f94c71ae90602ded","t":1593012668}},{"t":1593012720,"p":{"ppi":{"l":172.25,"v":616898},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":172.08,"v":367899},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.76,"v":38034}},"tx":{"h":"fc1f13142bf3d8364e8f98145c4e2ab4e983518dc8e0f0df308945e41ce48d04","t":1593012728}},{"t":1593012780,"p":{"ppi":{"l":172.25,"v":616898},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":172.08,"v":367899},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.76,"v":38034}},"tx":{"h":"9828abf486ac8e5b615c0e9add15b5616b47e1ff3d34cf476751e7332ace7652","t":1593012788}},{"t":1593012840,"p":{"ppi":{"l":172.25,"v":616898},"bitfinex":{"l":172.46,"v":205809},"bittrex":{"l":172.08,"v":367899},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.76,"v":38034}},"tx":{"h":"947d3375973b0e414fcfc3218c0dad10cdc67a67c164a14e97972065f070e213","t":1593012848}},{"t":1593012960,"p":{"ppi":{"l":172.22,"v":616287},"bitfinex":{"l":172.46,"v":205098},"bittrex":{"l":172.08,"v":367899},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.32,"v":38134}},"tx":{"h":"9488cb2a2fa60c594a00ebfdb411aa1d512e8318a0b2cfa04e35d417d8220f7e","t":1593012969}},{"t":1593013020,"p":{"ppi":{"l":172.2,"v":614393},"bitfinex":{"l":172.46,"v":205098},"bittrex":{"l":172.04,"v":366005},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.32,"v":38134}},"tx":{"h":"184f2e7472fe54f09e7205d7a1239b8e8bd2841ffe59b7b84eec78e0c6318ebc","t":1593013028}},{"t":1593013080,"p":{"ppi":{"l":172.2,"v":614393},"bitfinex":{"l":172.46,"v":205098},"bittrex":{"l":172.04,"v":366005},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.32,"v":38134}},"tx":{"h":"db2da9de14cb6e628f74a815c2a4d5bfbba40cf4e6d7893f9d67ad5a33b5b512","t":1593013088}},{"t":1593013140,"p":{"ppi":{"l":172.2,"v":614393},"bitfinex":{"l":172.46,"v":205098},"bittrex":{"l":172.04,"v":366005},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.32,"v":38134}},"tx":{"h":"b334986881674afcf424c2f81894c3c9508026229343882c7d1ac9bf242efdd8","t":1593013148}},{"t":1593013260,"p":{"ppi":{"l":172.09,"v":615510},"bitfinex":{"l":172.46,"v":205098},"bittrex":{"l":171.86,"v":367122},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":172.32,"v":38134}},"tx":{"h":"1437b6a26eb8566be65f49c9a241a07f08035c2321d110f103e75ed8bed10daf","t":1593013268}},{"t":1593013320,"p":{"ppi":{"l":172.03,"v":615510},"bitfinex":{"l":172.46,"v":205098},"bittrex":{"l":171.86,"v":367122},"okcoin":{"l":171.74,"v":5156},"poloniex":{"l":171.44,"v":38134}},"tx":{"h":"5dd10d5ad4be1ed085383544b15df1bb2ec7435f23cf0007afbae66f3563e974","t":1593013328}},{"t":1593013380,"p":{"ppi":{"l":170.82,"v":622127},"bitfinex":{"l":171.18,"v":204370},"bittrex":{"l":170.54,"v":367292},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.44,"v":45141}},"tx":{"h":"9177631aa941b49134f7366abb595b2ba67055d810f652bac74cb4448cbdc14e","t":1593013388}},{"t":1593013440,"p":{"ppi":{"l":171.23,"v":622450},"bitfinex":{"l":171.18,"v":204370},"bittrex":{"l":171.14,"v":367615},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":172.21,"v":45141}},"tx":{"h":"611e9d8ce53396c67003e9b74e05841740abe6db0b49a9ab9d7165f4aaef3fe7","t":1593013448}},{"t":1593013500,"p":{"ppi":{"l":170.66,"v":622495},"bitfinex":{"l":170.88,"v":204115},"bittrex":{"l":170.42,"v":367913},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.58,"v":45143}},"tx":{"h":"f59d424c997c253374154af3c007530b946b244967928afd7c3d941fd62f402c","t":1593013509}},{"t":1593013560,"p":{"ppi":{"l":170.7,"v":623436},"bitfinex":{"l":170.98,"v":205056},"bittrex":{"l":170.42,"v":367913},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.65,"v":45143}},"tx":{"h":"a33208a1ded51a46a981b69d183a12b572fb42ad830a519ab246cc927420c1f7","t":1593013568}},{"t":1593013620,"p":{"ppi":{"l":170.7,"v":623607},"bitfinex":{"l":170.98,"v":205056},"bittrex":{"l":170.42,"v":367913},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.65,"v":45314}},"tx":{"h":"e94f8674c082e634635baded90ccbde67158cda85ab3466cdae3ec02e3afe330","t":1593013629}},{"t":1593013680,"p":{"ppi":{"l":170.58,"v":623726},"bitfinex":{"l":170.8,"v":205174},"bittrex":{"l":170.42,"v":367913},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":170.9,"v":45315}},"tx":{"h":"2ee82ba5236b41ae70788a19878763d7beecf97e36281d06b291e19ddbde2196","t":1593013688}},{"t":1593013740,"p":{"ppi":{"l":170.77,"v":633666},"bitfinex":{"l":171.29,"v":214943},"bittrex":{"l":170.42,"v":367913},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.16,"v":45486}},"tx":{"h":"ce5b7db08f378fde20d15b365f7264ed537802fa22382fa9f92c182aeb8c3f90","t":1593013748}},{"t":1593013860,"p":{"ppi":{"l":171.32,"v":635497},"bitfinex":{"l":171.45,"v":216051},"bittrex":{"l":171.2,"v":368635},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.79,"v":45487}},"tx":{"h":"352eec9dc4bb6e712ac29c8e9d7c96528384f39d813ec0363194193a6880e2b5","t":1593013868}},{"t":1593013920,"p":{"ppi":{"l":171.32,"v":635497},"bitfinex":{"l":171.45,"v":216051},"bittrex":{"l":171.2,"v":368635},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.79,"v":45487}},"tx":{"h":"79fa2167ee5a76f7c32c56c8500ee2b49f54899d75326e2906832a7c31add385","t":1593013929}},{"t":1593013980,"p":{"ppi":{"l":171.21,"v":636811},"bitfinex":{"l":171.45,"v":216051},"bittrex":{"l":171,"v":369949},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.79,"v":45487}},"tx":{"h":"58b7f71db0cff67e40a84dc5950dbd555b9243cafe187a25278ffb12249d11d9","t":1593014004}},{"t":1593014040,"p":{"ppi":{"l":170.8,"v":637014},"bitfinex":{"l":170.74,"v":215518},"bittrex":{"l":170.72,"v":370685},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.79,"v":45487}},"tx":{"h":"f5a9b4ed6f19d75dd258c92c7134924655b9e31b7a0e560bb5f96f266adc2af2","t":1593014048}},{"t":1593014160,"p":{"ppi":{"l":170.39,"v":636965},"bitfinex":{"l":170.54,"v":216134},"bittrex":{"l":170.28,"v":369920},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":170.5,"v":45587}},"tx":{"h":"82893e0b3587d3d66efd99da6cfd664471834126c894eedf14ab5df761ca6a08","t":1593014168}},{"t":1593014220,"p":{"ppi":{"l":170.43,"v":636966},"bitfinex":{"l":170.54,"v":216134},"bittrex":{"l":170.28,"v":369920},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.13,"v":45588}},"tx":{"h":"343344cbcc595eff522e9e61c0cd791fa3c641422729ccd0e8072dd2aa2db8fa","t":1593014228}},{"t":1593014280,"p":{"ppi":{"l":170.43,"v":636967},"bitfinex":{"l":170.54,"v":216134},"bittrex":{"l":170.28,"v":369920},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.03,"v":45589}},"tx":{"h":"d5c944c68d51e263cf9132c2fcba2665896069fc74013052fe472e54d1d68fda","t":1593014288}},{"t":1593014340,"p":{"ppi":{"l":170.44,"v":636967},"bitfinex":{"l":170.54,"v":216134},"bittrex":{"l":170.28,"v":369920},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":171.23,"v":45589}},"tx":{"h":"8149058b09f9d8b336ed77790c32120a3e776c8d7d5b40b79fb4e3dc1596ee8f","t":1593014348}},{"t":1593014460,"p":{"ppi":{"l":170.74,"v":637947},"bitfinex":{"l":170.58,"v":216359},"bittrex":{"l":170.83,"v":370674},"okcoin":{"l":170.8,"v":5324},"poloniex":{"l":170.81,"v":45590}},"tx":{"h":"701679e8b1746b5f399f04d13b8c2d42406ac6370dad7bb4730c913a9c69e504","t":1593014469}},{"t":1593014520,"p":{"ppi":{"l":170.95,"v":644166},"bitfinex":{"l":171.11,"v":217031},"bittrex":{"l":170.88,"v":374938},"okcoin":{"l":170.89,"v":6606},"poloniex":{"l":170.81,"v":45591}},"tx":{"h":"2d5c774cd24106f3fe8fc037e5cf76b13534b82ba975f92cc3a3eed60132fad7","t":1593014528}},{"t":1593014580,"p":{"ppi":{"l":171.18,"v":653785},"bitfinex":{"l":171.56,"v":226294},"bittrex":{"l":170.93,"v":375292},"okcoin":{"l":170.89,"v":6606},"poloniex":{"l":171.35,"v":45593}},"tx":{"h":"b2842c7daf6e74224d177820ee7b3f2f5f66bbe90bb1b6ac994c2e4e190080d0","t":1593014588}},{"t":1593014640,"p":{"ppi":{"l":171.18,"v":654360},"bitfinex":{"l":171.58,"v":226869},"bittrex":{"l":170.93,"v":375292},"okcoin":{"l":170.89,"v":6606},"poloniex":{"l":171.35,"v":45593}},"tx":{"h":"c3a1b3de3dd142cd258414d7889f485da16161efe6aed95fce9da86a2c4fb936","t":1593014648}},{"t":1593014760,"p":{"ppi":{"l":171.25,"v":654388},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":170.93,"v":375292},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.16,"v":45594}},"tx":{"h":"a655a869f0529897c96d92eacecc547f86ee844dc18876d201c7b8dd3638a469","t":1593014768}},{"t":1593014820,"p":{"ppi":{"l":171.21,"v":654389},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":170.93,"v":375292},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"b8e8db45344269d10f5e98dcac2dc8aec5d7ada9dc854fc8dbb6495f0857b5f6","t":1593014828}},{"t":1593014880,"p":{"ppi":{"l":171.21,"v":654389},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":170.93,"v":375292},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"854bcf7182f3d365ef454536a02982558eead626190d07be07887b7619aacba2","t":1593014889}},{"t":1593014940,"p":{"ppi":{"l":171.21,"v":653279},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":170.93,"v":374182},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"6ffc0697748399764ef77f37538ef11528dfd5682ea124b7b1addfa4ee28e78e","t":1593014948}},{"t":1593015060,"p":{"ppi":{"l":171.37,"v":653305},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":171.2,"v":374208},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"212e8771c56083f755ab92d9a84793dceafb6270acb017fdfb10b8460bac9c97","t":1593015068}},{"t":1593015120,"p":{"ppi":{"l":171.37,"v":653305},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":171.2,"v":374208},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"36effbe9abad4a81b66f43392562970246be2bb0bb97bc3a5dd07d17747dbf93","t":1593015128}},{"t":1593015180,"p":{"ppi":{"l":171.37,"v":653305},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":171.2,"v":374208},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"865a7b0e9a05b46cbeb055a0cbd490bb3f39e805f70d7b0989b49ae4266d29bc","t":1593015188}},{"t":1593015240,"p":{"ppi":{"l":171.37,"v":653305},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":171.2,"v":374208},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"d29b27dfa8bce50949f1da1935b00ecccceaebe2f737cab5834b87de1b75de29","t":1593015248}},{"t":1593015360,"p":{"ppi":{"l":171.37,"v":653305},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":171.2,"v":374208},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"c953a4677f0eae78b2bd938300a6f142e647c326b2e246f1e3a05d27932cd5ce","t":1593015368}},{"t":1593015420,"p":{"ppi":{"l":171.37,"v":653624},"bitfinex":{"l":171.58,"v":226038},"bittrex":{"l":171.2,"v":374527},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"e3d83d88b336522f6871bfa2c346fcca3b73dcdd05dbff7e7187d1b57d099eb8","t":1593015428}},{"t":1593015480,"p":{"ppi":{"l":171.45,"v":654877},"bitfinex":{"l":171.73,"v":226258},"bittrex":{"l":171.25,"v":375560},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"50d6859e90cc538bf06549fcf9be3239f373fd4b715a060acc411abd1ed51eee","t":1593015488}},{"t":1593015540,"p":{"ppi":{"l":171.37,"v":654606},"bitfinex":{"l":171.49,"v":225987},"bittrex":{"l":171.25,"v":375560},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"5e864bef8a90727d07b2d1ac942fd249a4a8b854964a247c74efa6f6f18da8ab","t":1593015550}},{"t":1593015660,"p":{"ppi":{"l":171.36,"v":652965},"bitfinex":{"l":171.49,"v":224346},"bittrex":{"l":171.25,"v":375560},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"b11b7c4e66d3ae4e76c85ab5599a0f58185456f71fa033ffa53f11f1c7f7d639","t":1593015668}},{"t":1593015720,"p":{"ppi":{"l":171.41,"v":653423},"bitfinex":{"l":171.49,"v":224346},"bittrex":{"l":171.33,"v":376018},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"f10ae594b9c37a5ce6f22c19a317cdc02be6ca6a7931bc02ce0ab064760f3184","t":1593015728}},{"t":1593015780,"p":{"ppi":{"l":171.53,"v":654243},"bitfinex":{"l":171.84,"v":225166},"bittrex":{"l":171.33,"v":376018},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.66,"v":45595}},"tx":{"h":"81242b8f81bb395e3ced2d91e45b6b609fafc5f6032f6b3a109ce9c27b0b01db","t":1593015805}},{"t":1593015840,"p":{"ppi":{"l":171.54,"v":654243},"bitfinex":{"l":171.84,"v":225166},"bittrex":{"l":171.33,"v":376018},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":45595}},"tx":{"h":"f88716f11bb28d0f4b100b09615135adc44f33be30ccd6529fa9613d13085ad5","t":1593015848}},{"t":1593015960,"p":{"ppi":{"l":171.52,"v":654495},"bitfinex":{"l":171.49,"v":225074},"bittrex":{"l":171.51,"v":376361},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":45596}},"tx":{"h":"84672f475d3cd0a166205b58cd0aa205d2441a0f4d243271b9ffbd177dc0ab7b","t":1593015968}},{"t":1593016020,"p":{"ppi":{"l":171.67,"v":655435},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.51,"v":376361},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":45596}},"tx":{"h":"b5796111ea0903b0a1e8eb169aa38b4f7d3dffe1b8764ca404c1556f65368ca3","t":1593016028}},{"t":1593016080,"p":{"ppi":{"l":171.67,"v":655435},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.51,"v":376361},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":45596}},"tx":{"h":"1a85c3eefab31db754edf246807704e9d8c5cba9224682ee0149d6c85e66240f","t":1593016088}},{"t":1593016140,"p":{"ppi":{"l":171.77,"v":656807},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":377733},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":45596}},"tx":{"h":"c91097004274facec66b45957f0c2b029d10a136a74b94360604a973b5e0694b","t":1593016148}},{"t":1593016260,"p":{"ppi":{"l":171.77,"v":654768},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":378491},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"8df7af2abab8461136c46475417e752ea11143f0f7f56770649aee947cec5b17","t":1593016268}},{"t":1593016320,"p":{"ppi":{"l":171.77,"v":654768},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":378491},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"d4f90f3c47fe16fe5fe244e7c7261eb0d23383b2e9c162c96753464a71259963","t":1593016328}},{"t":1593016380,"p":{"ppi":{"l":171.77,"v":654768},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":378491},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"98ba9189c714d9540c128e8fb468debd70980d1b6bb8dcc801ed511dec375819","t":1593016388}},{"t":1593016440,"p":{"ppi":{"l":171.77,"v":654768},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":378491},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"cb9a7a439a95d38cf93eabd1f0230d04d207975e858aeb7c1e589c157f46161e","t":1593016449}},{"t":1593016560,"p":{"ppi":{"l":171.77,"v":655202},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":378925},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"46e083a7d15f653e3c86cc2c2305cc4683ee9134e3c320771320f33fc231057e","t":1593016568}},{"t":1593016620,"p":{"ppi":{"l":171.77,"v":655182},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.68,"v":378905},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"9a68ecda00c7c5044447337d21f4f9394b6e514becdee8559c2c4b065765bd34","t":1593016636}},{"t":1593016680,"p":{"ppi":{"l":171.79,"v":656392},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.71,"v":380115},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"46ef2cc072cc36af99f6830e48f7dfccffc93d59ae9527209b9d4de504e57137","t":1593016688}},{"t":1593016740,"p":{"ppi":{"l":171.89,"v":655007},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":378730},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"76c34181b9e519b266dd1294bd19fbc457f3bf06e03bd9772693763a585b419b","t":1593016748}},{"t":1593016860,"p":{"ppi":{"l":171.89,"v":653832},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":377555},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"ab4f6512032cf2bf86dc623b4c08cd9f298e9c6084505d0aa917545627f0e779","t":1593016869}},{"t":1593016920,"p":{"ppi":{"l":171.89,"v":653832},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":377555},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42799}},"tx":{"h":"d58445bcb1e2a4682ae68d88dabec5770294121e659940591bc76a3a845dcbf2","t":1593016936}},{"t":1593016980,"p":{"ppi":{"l":171.89,"v":653782},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":377555},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42749}},"tx":{"h":"ba65b4cffd75cc886477a180db7b79944eb100eefb283fac7b9060b223439594","t":1593016988}},{"t":1593017040,"p":{"ppi":{"l":171.89,"v":653782},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":377555},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":171.78,"v":42749}},"tx":{"h":"ddbd6f19ecd3fe75d1e65de89ba3948543d30af51485731fb13bbe48f4c434d0","t":1593017048}},{"t":1593017160,"p":{"ppi":{"l":171.96,"v":654285},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":377555},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"4059dffc288a9026f9176e8c7e33e91250bcd726e80ab1599e5a610b1e1021f8","t":1593017168}},{"t":1593017220,"p":{"ppi":{"l":171.96,"v":653543},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":376813},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"714f8db3c803ffc983f757d9adee743eca5c80c6bb2b61ca03a80ea8d5a9a2b6","t":1593017228}},{"t":1593017280,"p":{"ppi":{"l":171.96,"v":653543},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":376813},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"97cac0d51d864baa8f131d233744d6687680b6b4808823b54166ed6b41bd8421","t":1593017288}},{"t":1593017340,"p":{"ppi":{"l":171.96,"v":653899},"bitfinex":{"l":171.93,"v":226014},"bittrex":{"l":171.88,"v":377169},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"933d93d231ec64ffd2ef6984c34052c13f2f7d92483cb4db43a896229fb016aa","t":1593017349}},{"t":1593017460,"p":{"ppi":{"l":172.05,"v":654384},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":377169},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"de6c34acfe0a9d6b4e5db1c8aa49248e16b4e8ea2372139d6af046bf3fb72238","t":1593017469}},{"t":1593017520,"p":{"ppi":{"l":172.05,"v":653997},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":376782},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"ecc0eb133a848a9d21fc627d607161bff84b28e98c26916437bae5452f9442c0","t":1593017536}},{"t":1593017580,"p":{"ppi":{"l":172.05,"v":653997},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":376782},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"6f39237a005bb01d8217740f512182457c5e025fb5417398d8409d733961b277","t":1593017606}},{"t":1593017640,"p":{"ppi":{"l":172.05,"v":653997},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":376782},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"4bf7bb8a5317488cf59226ff60f03bf6a898294db234809fc81dd61ca00ec2e6","t":1593017648}},{"t":1593017760,"p":{"ppi":{"l":172.05,"v":653997},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":376782},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"f2d3ecd1513ed85759e67cf3321aeb0ccd20ea4f542d9896d75cfb4ae6577e14","t":1593017768}},{"t":1593017820,"p":{"ppi":{"l":172.05,"v":653493},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":376278},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"377f921415020597079ac80148659e7fe1278150d0cccfc54c42b1c738126238","t":1593017828}},{"t":1593017880,"p":{"ppi":{"l":172.05,"v":653493},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":376278},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"73ceedb4ca6daa0db5a8a57890df185f7250bbe4ab60ae2b515875bea141586c","t":1593017888}},{"t":1593017940,"p":{"ppi":{"l":172.05,"v":651783},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":374568},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"a2123b344b690689b701e4438d7f5219c0b98b6ee15d97467c6905a1e72ee28e","t":1593017948}},{"t":1593018060,"p":{"ppi":{"l":172.05,"v":650614},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":373399},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"c3abedc895aadfaeb01baf67ddc1dea52b46f5fd11a0b09071724b6f85aeb87f","t":1593018068}},{"t":1593018120,"p":{"ppi":{"l":172.05,"v":648266},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":371051},"okcoin":{"l":171.57,"v":7464},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"87c7814ccb3905c8960b964de1cdbe44b356dd29e6cd168486cdf86440b5b23b","t":1593018131}},{"t":1593018180,"p":{"ppi":{"l":172.05,"v":645446},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":368332},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":43252}},"tx":{"h":"f4b7af50f1f245719bfd03e83ad3e6ddc9dfd8ddbd0c6511f977a1813e00d386","t":1593018188}},{"t":1593018240,"p":{"ppi":{"l":172.05,"v":645342},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.88,"v":368332},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":43148}},"tx":{"h":"5ddaa78d7c7f2e505fb37459a09720276ffe4b390dff85ed087b4381f0f351f4","t":1593018248}},{"t":1593018360,"p":{"ppi":{"l":172.01,"v":645024},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.81,"v":368462},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42700}},"tx":{"h":"b7307e35ca96d99ffeb9da781e4e6c0827fbe081ee9b909890c3be8199b57e60","t":1593018368}},{"t":1593018420,"p":{"ppi":{"l":172.01,"v":645024},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.81,"v":368462},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42700}},"tx":{"h":"bbb515a9c6001ffc32dd49c2d556e8b2887607b85d5e7a5d7c857e2e3122daa8","t":1593018428}},{"t":1593018480,"p":{"ppi":{"l":172.01,"v":645024},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.81,"v":368462},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42700}},"tx":{"h":"18d8d662c2a4345cdf75fc3b5279043779b78373baf017dd80a4156328e0c556","t":1593018488}},{"t":1593018540,"p":{"ppi":{"l":172.01,"v":645024},"bitfinex":{"l":172.2,"v":226499},"bittrex":{"l":171.81,"v":368462},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42700}},"tx":{"h":"b4bc1a4423e962370ddcf98df6fcb2e5b4370158f6e1ee7674dcb82b457d878c","t":1593018548}},{"t":1593018660,"p":{"ppi":{"l":172.08,"v":645717},"bitfinex":{"l":172.41,"v":227192},"bittrex":{"l":171.81,"v":368462},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42700}},"tx":{"h":"487b38de38a0aba00b74e0338766129991823c76507cfcbbd9837a27ba506dbd","t":1593018669}},{"t":1593018720,"p":{"ppi":{"l":172.16,"v":647011},"bitfinex":{"l":172.41,"v":227192},"bittrex":{"l":171.95,"v":369756},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42700}},"tx":{"h":"455f117d8162853c8d7012c341b1458fc67da4a2094f1bb242d01698d6ed5596","t":1593018728}},{"t":1593018780,"p":{"ppi":{"l":172.16,"v":646980},"bitfinex":{"l":172.41,"v":227192},"bittrex":{"l":171.95,"v":369756},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"ae3d56074046559598d27e917ed1366f5145e0705bb11fd5bd47e80cb1d2286d","t":1593018788}},{"t":1593018840,"p":{"ppi":{"l":172.16,"v":645545},"bitfinex":{"l":172.41,"v":227192},"bittrex":{"l":171.95,"v":368321},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"7080ff62e8d32376b721c452321a2d0989527b06bf5274c6f95a95fcb38962c9","t":1593018848}},{"t":1593018960,"p":{"ppi":{"l":172.16,"v":645144},"bitfinex":{"l":172.41,"v":227192},"bittrex":{"l":171.95,"v":367920},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"a0c01cdc426c677c44e681fb1e56acbb2a669cce60208891d8ad3ebb6d45de9f","t":1593018968}},{"t":1593019020,"p":{"ppi":{"l":172.61,"v":662837},"bitfinex":{"l":172.61,"v":228148},"bittrex":{"l":172.6,"v":384657},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"f55fa20e8906527a5f571dbde27dc1bdab87636fc959a0b3b5a70e7ea9e5453f","t":1593019027}},{"t":1593019080,"p":{"ppi":{"l":172.61,"v":662837},"bitfinex":{"l":172.61,"v":228148},"bittrex":{"l":172.6,"v":384657},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"d508fae883fb1cfda7d5605c2118ad6f015fdc2abb782ec07bceb8b29baae538","t":1593019088}},{"t":1593019140,"p":{"ppi":{"l":172.61,"v":652142},"bitfinex":{"l":172.61,"v":228148},"bittrex":{"l":172.6,"v":373962},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"0dfbce36c4c06d29b1fa56d893b624524924d25c13ed684499c5a2874523f5f9","t":1593019148}},{"t":1593019260,"p":{"ppi":{"l":172.64,"v":650049},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.6,"v":370896},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"a4b078b5ecaf5361109c0df9d25eb8a32b698502fc42d703244aa5f6040208b2","t":1593019268}},{"t":1593019320,"p":{"ppi":{"l":172.64,"v":649491},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.6,"v":370338},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"f8cbbc2a2df0c940903be889195e8636dd48574cc4b2a59e6f8aefb01420e5d4","t":1593019328}},{"t":1593019380,"p":{"ppi":{"l":172.4,"v":650352},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.17,"v":371199},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"93c91a809dd58002a6e26246bf16d5e653a31b47a7e907e2d2d2f203753067ab","t":1593019407}},{"t":1593019440,"p":{"ppi":{"l":172.4,"v":650352},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.17,"v":371199},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"f39b406661ab8a572277a6b67654c5d20fa106b9e88e3db3e6972e31d4810014","t":1593019448}},{"t":1593019560,"p":{"ppi":{"l":172.41,"v":651571},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":372418},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"0aa773a4680399bcb272462c7806e11517cef6a49767c63cb7b8c5670cb72194","t":1593019568}},{"t":1593019620,"p":{"ppi":{"l":172.41,"v":651571},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":372418},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"e53193b86a334631150d1e8a8fff09f32cf293003d106d3a381b470fe3d7560c","t":1593019636}},{"t":1593019680,"p":{"ppi":{"l":172.41,"v":651571},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":372418},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"e1db865496bc9b62703c48282f75e9f2d5e23f9affbde4de4e8e70c42bfdcd7e","t":1593019689}},{"t":1593019740,"p":{"ppi":{"l":172.41,"v":651571},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":372418},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"8816efbca73c7946af24dd847e78b634dd703c4c251a407ab4a733bf306ff81a","t":1593019755}},{"t":1593019860,"p":{"ppi":{"l":172.41,"v":651562},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":372409},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"a99c4fb200d83962b225af9ff7d0b900745324ffd2dea313c22c0698dad74c1c","t":1593019868}},{"t":1593019920,"p":{"ppi":{"l":172.41,"v":629236},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":350083},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42669}},"tx":{"h":"c9564b14db2c213ae8dad8e8922e26e82f131abd3c7d2d3e32ced602fe3963c7","t":1593019928}},{"t":1593019980,"p":{"ppi":{"l":172.41,"v":628686},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":350083},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42119}},"tx":{"h":"6d3a3ed5da17d9165a43a24535a7e3baaa929f9ab0deda4a6440b7a295a260cc","t":1593019988}},{"t":1593020040,"p":{"ppi":{"l":172.41,"v":628686},"bitfinex":{"l":172.71,"v":229121},"bittrex":{"l":172.19,"v":350083},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42119}},"tx":{"h":"72d8b5c8169dcd44a313d082f486f49cd994a65d2e1d0f56b57e5e7ade3a1f9e","t":1593020056}},{"t":1593020160,"p":{"ppi":{"l":172.41,"v":628613},"bitfinex":{"l":172.71,"v":229048},"bittrex":{"l":172.19,"v":350083},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42119}},"tx":{"h":"a66dd2de59974c4618b788c31e5273da12f134f1576753ac20ec4c8d64d97a10","t":1593020169}},{"t":1593020220,"p":{"ppi":{"l":172.41,"v":628613},"bitfinex":{"l":172.71,"v":229048},"bittrex":{"l":172.19,"v":350083},"okcoin":{"l":171.57,"v":7363},"poloniex":{"l":172.81,"v":42119}},"tx":{"h":"248c1c60a77d805c3db77f4270fe89dbd12c824ee67f2754afa542a4bd8a896f","t":1593020228}},{"t":1593020280,"p":{"ppi":{"l":172.42,"v":628456},"bitfinex":{"l":172.71,"v":229048},"bittrex":{"l":172.19,"v":349675},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"04cf9bcab631ab730fdbb7eb6908a658c32c96ad20b0f861c01a706779e4caae","t":1593020288}},{"t":1593020340,"p":{"ppi":{"l":172.42,"v":628369},"bitfinex":{"l":172.71,"v":229048},"bittrex":{"l":172.19,"v":349588},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"77258d2689d2c8069e0abf6f4f16abac8082fe355acc11a0fa1ae83d525ab673","t":1593020349}},{"t":1593020460,"p":{"ppi":{"l":172.42,"v":628369},"bitfinex":{"l":172.71,"v":229048},"bittrex":{"l":172.19,"v":349588},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"c5ff823ae96d34bbeb4b405ddb29e1c539ef2e9702a065d1e7ffa366d2a318d4","t":1593020468}},{"t":1593020520,"p":{"ppi":{"l":172.3,"v":627945},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":172.19,"v":349579},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"14867974dcc51c25a4a46d71a48c9ba6d00484a65c947e7f3cd84d54fca9f406","t":1593020528}},{"t":1593020580,"p":{"ppi":{"l":172.3,"v":627945},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":172.19,"v":349579},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"fcd982440719dfa295e38c6fbeb18db0f6dbdcc2bccac95424c3376b2e449388","t":1593020588}},{"t":1593020640,"p":{"ppi":{"l":172.3,"v":627945},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":172.19,"v":349579},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"4862836368664c834a0d2698b4af96d03ab114d2bd16de49ed77790ea791a518","t":1593020648}},{"t":1593020760,"p":{"ppi":{"l":172.3,"v":626707},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":172.19,"v":348341},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"01fc39d169b5d66d5f9a8648daa5424ceaada9d862600632c023cf190b358a22","t":1593020768}},{"t":1593020820,"p":{"ppi":{"l":172.3,"v":626707},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":172.19,"v":348341},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"74b80ad362c27535cf08c2d7e276ebfbd669e96d42a1da78d552395e3b1d97e4","t":1593020835}},{"t":1593020880,"p":{"ppi":{"l":172.16,"v":629286},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"ad8c9e267004c3d72dfffa87501721b43ba3697db0acb1d7c5cb4eeb74a99f2b","t":1593020888}},{"t":1593020940,"p":{"ppi":{"l":172.16,"v":629286},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.81,"v":41940}},"tx":{"h":"52683f5e3f125ef6797b22dc8cc334292f0f4b7071996a2ae2f9c186c281b03a","t":1593020948}},{"t":1593021060,"p":{"ppi":{"l":172.12,"v":629286},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41940}},"tx":{"h":"d0e7052a633c66671f80b1f53f486810b8fc6cd61ef9816db2d72e6dd9385a5b","t":1593021069}},{"t":1593021120,"p":{"ppi":{"l":172.12,"v":629287},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41941}},"tx":{"h":"23e661be0f838dfb833993b719cd510ce4aa2be7904f2c6a6bffc537449cbfeb","t":1593021128}},{"t":1593021180,"p":{"ppi":{"l":172.12,"v":629288},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41942}},"tx":{"h":"2e8b47a25950f112464cc2ab4133b611883b6d9244faa7be007aec7fa0919a5c","t":1593021207}},{"t":1593021240,"p":{"ppi":{"l":172.12,"v":629288},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41942}},"tx":{"h":"6997a4e8670c27f87eb61a27f78d03e0d1d48662a1874c42203c6b34f83a09bb","t":1593021248}},{"t":1593021360,"p":{"ppi":{"l":172.12,"v":629289},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350920},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41943}},"tx":{"h":"1f0ce7daa773308b4d80717f85afd5886cd3af3fcdf4bab96fe95dfee841b059","t":1593021369}},{"t":1593021420,"p":{"ppi":{"l":172.12,"v":629280},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350911},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41943}},"tx":{"h":"583dbae5d8bbb2d8ac32ad4696b89ffe9e13e53d27a538283c506cf8d82db6e0","t":1593021428}},{"t":1593021480,"p":{"ppi":{"l":172.12,"v":629280},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350911},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.16,"v":41943}},"tx":{"h":"748e32420e3fe851f15e8f80119e337eeb8e52f5e597dd80297410545ec38068","t":1593021489}},{"t":1593021540,"p":{"ppi":{"l":172.12,"v":629281},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350911},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.24,"v":41944}},"tx":{"h":"45110d26f6b29a33523605b102dcaa6c91cf80a96a6be7d871fa51d1ecf69565","t":1593021548}},{"t":1593021600,"p":{"ppi":{"l":172.12,"v":629281},"bitfinex":{"l":172.39,"v":228633},"bittrex":{"l":171.93,"v":350911},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41944}},"tx":{"h":"430eb08d2539b62aabe5781abe535488e2125a1bb5ded0ea04e21e0ca8dca1e3","t":1593021608}},{"t":1593021660,"p":{"ppi":{"l":172.11,"v":629416},"bitfinex":{"l":172.35,"v":228767},"bittrex":{"l":171.93,"v":350911},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41945}},"tx":{"h":"bff58c65dbfd195ee8899dd188014fca5c05ebac125628a3b03a266b8bdb0614","t":1593021668}},{"t":1593021720,"p":{"ppi":{"l":172.11,"v":629416},"bitfinex":{"l":172.35,"v":228767},"bittrex":{"l":171.93,"v":350911},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41945}},"tx":{"h":"00d8e94b11a917eea0e4564b03e359a46e28848edf14971fbff240da0ef75660","t":1593021736}},{"t":1593021780,"p":{"ppi":{"l":172.11,"v":626282},"bitfinex":{"l":172.35,"v":228767},"bittrex":{"l":171.93,"v":347777},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41945}},"tx":{"h":"5d81834eaf8c3aaf8c45505b77d4cba72277ba5f59406d1b7ce9ee6facb9270b","t":1593021789}},{"t":1593021840,"p":{"ppi":{"l":172.11,"v":623772},"bitfinex":{"l":172.35,"v":228767},"bittrex":{"l":171.93,"v":345267},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41945}},"tx":{"h":"93f23b324780d3f65ae21438acc280764a9a8cc0c765efbe88ac89cc6b8cf169","t":1593021848}},{"t":1593021960,"p":{"ppi":{"l":172.11,"v":620923},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":345267},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"95a43481b509083d710eadec77b790683ad6fe2d48a8749f19fb40dae4185b80","t":1593021968}},{"t":1593022020,"p":{"ppi":{"l":172.11,"v":620923},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":345267},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"07eea34d12afee4251bd1bed4ca20412d37e040c8cadd12259038a7355a7cd1a","t":1593022031}},{"t":1593022080,"p":{"ppi":{"l":172.11,"v":620923},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":345267},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"452198ee254930140bc68170bb683fc30e2b377b9d0afbaef98eb90ae963b4b0","t":1593022091}},{"t":1593022140,"p":{"ppi":{"l":172.11,"v":620511},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":344855},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"588c3df5438cddd50335e27beaec42c6b4d7c37d0994b8b29bed05189a1f696e","t":1593022148}},{"t":1593022260,"p":{"ppi":{"l":172.11,"v":620073},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":344417},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"3db1d0f2f0d1f7c308ff94dde13959035b41ce3cba8d52a455dcf01ffb42a35a","t":1593022269}},{"t":1593022320,"p":{"ppi":{"l":172.11,"v":619844},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"cac50d73a2a7634cc2b992844edc2bb09d883a55bfb1597daa56f86f9c8547fc","t":1593022328}},{"t":1593022380,"p":{"ppi":{"l":172.11,"v":619844},"bitfinex":{"l":172.35,"v":226018},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"952854aef4b2280373c4021c18191066a383df16bf13ed779eeed3eb60f44b7d","t":1593022388}},{"t":1593022440,"p":{"ppi":{"l":172.15,"v":621824},"bitfinex":{"l":172.45,"v":227998},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"6d86fefb23311b87653a451fde2d3d560044a7710d505000d29ab407777e6a3f","t":1593022449}},{"t":1593022560,"p":{"ppi":{"l":172.2,"v":624848},"bitfinex":{"l":172.59,"v":231022},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"b795ffca9fb08de6ae0461bfb3d26405b7ef6641fc37c4b92f509c00ec230a72","t":1593022569}},{"t":1593022620,"p":{"ppi":{"l":172.2,"v":625209},"bitfinex":{"l":172.59,"v":231383},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"bb3140b9a86a7e478e021224b5d8e1b3f1b1ababc4c49ffeafde04f913b9efca","t":1593022631}},{"t":1593022680,"p":{"ppi":{"l":172.2,"v":625209},"bitfinex":{"l":172.59,"v":231383},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"9f11e6aae4f202453585f7c3ca5d85a7932c5d1d1ccd457aaf23bebeabd5b3d2","t":1593022693}},{"t":1593022740,"p":{"ppi":{"l":172.2,"v":625209},"bitfinex":{"l":172.59,"v":231383},"bittrex":{"l":171.93,"v":344188},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"4d2a4c62b36cc64906c4b103f24153c2866fd808c858029e2c0e5c6c61fda5d2","t":1593022750}},{"t":1593022860,"p":{"ppi":{"l":172.35,"v":627333},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":347976},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"b2b4071b782e7de27baa97a45db7c36532c1279b938f1adb17a9aac69bd31c45","t":1593022870}},{"t":1593022920,"p":{"ppi":{"l":172.35,"v":627333},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":347976},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"95afb0d908ccb00eb7140f8d09b37e81380fccf85ed9583fe298f993a7c6eb17","t":1593022928}},{"t":1593022980,"p":{"ppi":{"l":172.35,"v":634450},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":355093},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"5d4ed25ada38abd61b376c34dc4c5ceae3f6dc07acb15af8bf3a8906abafdadd","t":1593023012}},{"t":1593023040,"p":{"ppi":{"l":172.35,"v":634906},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":355549},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"1aeb6500ffeca84416aac02ae6123c80f685383a24c8e80123db8fc097a48949","t":1593023050}},{"t":1593023160,"p":{"ppi":{"l":172.35,"v":635404},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":356047},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"4196bf293b621e678a343834d735e11c7f6872dd9d6544a3204cede4b440760c","t":1593023168}},{"t":1593023220,"p":{"ppi":{"l":172.35,"v":635404},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":356047},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":41845}},"tx":{"h":"6182edb1dd742cec1e3619f4e07642f7e46b6aa534d23fd75461df6d73cc6497","t":1593023233}},{"t":1593023280,"p":{"ppi":{"l":172.35,"v":635883},"bitfinex":{"l":172.59,"v":229719},"bittrex":{"l":172.2,"v":356047},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"e617d9b6c5fbac70c7f312705e3ac95a6742b4e68b47a938cac978732a3e63a7","t":1593023290}},{"t":1593023340,"p":{"ppi":{"l":172.24,"v":641559},"bitfinex":{"l":172.3,"v":231401},"bittrex":{"l":172.2,"v":360041},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"d07ef7459678be8389a07278504e8212afa0c93ecd62e6753d42acfd54595c6d","t":1593023348}},{"t":1593023460,"p":{"ppi":{"l":172.22,"v":641853},"bitfinex":{"l":172.25,"v":231695},"bittrex":{"l":172.2,"v":360041},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"68fdbd9745d4ad0a4b1c039a06e8d33fa1f8a82459a87f064c6c7ebcd86df2de","t":1593023471}},{"t":1593023520,"p":{"ppi":{"l":172.22,"v":641853},"bitfinex":{"l":172.25,"v":231695},"bittrex":{"l":172.2,"v":360041},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"16ea7913da651505f7f4ac749f6c446df0a7974b4383ba3c09d19a98da2eee98","t":1593023528}},{"t":1593023580,"p":{"ppi":{"l":172.22,"v":641853},"bitfinex":{"l":172.25,"v":231695},"bittrex":{"l":172.2,"v":360041},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"e531425da9005565fad734f90e9400017c6d6db229f50e32e1e9fd9ba1a82c35","t":1593023589}},{"t":1593023640,"p":{"ppi":{"l":172.28,"v":642333},"bitfinex":{"l":172.25,"v":231695},"bittrex":{"l":172.3,"v":360521},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"e57ca8435ce4b5dd8fa36ac4d20cb3d0ab2e4ec641fc89021e08d0abe3caa6ae","t":1593023652}},{"t":1593023760,"p":{"ppi":{"l":172.28,"v":640496},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360521},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"4de8aed8a58880cf035e227aeaea9b8204e3d0b4fcf8b095738014ff75ad7ea1","t":1593023770}},{"t":1593023820,"p":{"ppi":{"l":172.28,"v":640496},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360521},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"792bbd9b74a3d15b98d2d2647819e3f1ffbc37604b8bb2044f7dc9358c308b50","t":1593023831}},{"t":1593023880,"p":{"ppi":{"l":172.28,"v":640496},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360521},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"e0cfe78367ebecbf1c059ccb36ecef74ed8211b0048b6821fa2a7a0805471328","t":1593023888}},{"t":1593023940,"p":{"ppi":{"l":172.28,"v":640455},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"cebcba12b8df2100e7e90ed7ff2f9126471f724119ed3fe91a38972d6714267d","t":1593023948}},{"t":1593024060,"p":{"ppi":{"l":172.28,"v":640455},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"e85e70db43d691668a2364472af92dedbd0e27a0a25f80e26a167fcfc8635c02","t":1593024067}},{"t":1593024120,"p":{"ppi":{"l":172.28,"v":640455},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"580b70ac61cf7414c97a6ca3242a487538cd8aabb5518bab19f0cee83d34069d","t":1593024128}},{"t":1593024180,"p":{"ppi":{"l":172.28,"v":640455},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"e1bb1ff76675fcc9c6b39c71bc9a4826555f3dd9c02c043c7d2207b7848bf00e","t":1593024191}},{"t":1593024240,"p":{"ppi":{"l":172.28,"v":640455},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"dd70e3023d63df34df472877cd695b2b6df026153a20c624a08a94cd5610411c","t":1593024250}},{"t":1593024360,"p":{"ppi":{"l":172.28,"v":640455},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":42324}},"tx":{"h":"573c944f352e7c2abcff6d4fef505cb4441fce73818e44da6cd1d16c7b3e49dc","t":1593024368}},{"t":1593024420,"p":{"ppi":{"l":172.28,"v":638775},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40644}},"tx":{"h":"d6656712ea702e7b903e327e5286df8188aa0aa7a1654fbd703f4c8bc6790651","t":1593024428}},{"t":1593024480,"p":{"ppi":{"l":172.28,"v":638775},"bitfinex":{"l":172.25,"v":229858},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40644}},"tx":{"h":"e07c816dce55bbcc681de1ed26c41d90a73cfd73b69395d34b66b1fff97394f7","t":1593024490}},{"t":1593024540,"p":{"ppi":{"l":172.31,"v":639446},"bitfinex":{"l":172.33,"v":230529},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40644}},"tx":{"h":"9af008219cbcf34aae427c7e81f77bcb1b6a87ee1e48174ca50a74da5c262c7b","t":1593024548}},{"t":1593024660,"p":{"ppi":{"l":172.31,"v":638750},"bitfinex":{"l":172.33,"v":229981},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"8d36c2dc0945d348c39fa892939a98410276f5e4b3db4338e2b2d9d973b3c14d","t":1593024670}},{"t":1593024720,"p":{"ppi":{"l":172.31,"v":638750},"bitfinex":{"l":172.33,"v":229981},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"0e54122af068358db6b9d2aef64842b4c11aa5d8ed142fbe5a60985e537b197b","t":1593024729}},{"t":1593024780,"p":{"ppi":{"l":172.31,"v":638750},"bitfinex":{"l":172.33,"v":229981},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"cb23ff67e9f7616135a51f05b58d4856c68575cda87fd7b4f0abb41c8ad45195","t":1593024810}},{"t":1593024840,"p":{"ppi":{"l":172.31,"v":638777},"bitfinex":{"l":172.35,"v":230008},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"bd9583ef3c156e0b9fc97d85e5f782bf755bb9bf9209accdc7a937f249825d93","t":1593024848}},{"t":1593024960,"p":{"ppi":{"l":172.33,"v":639652},"bitfinex":{"l":172.4,"v":230883},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"697a92e19c33ece0fb141c3a59f076f512f836197264e8dc3f3e7322dc26d93a","t":1593024969}},{"t":1593025020,"p":{"ppi":{"l":172.34,"v":640054},"bitfinex":{"l":172.43,"v":231285},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"a7bba7dc840d5a96f3de7422075c23870a46c011db14e60fe4ac3d034b622304","t":1593025028}},{"t":1593025080,"p":{"ppi":{"l":172.34,"v":640054},"bitfinex":{"l":172.43,"v":231285},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"d34768770eb7ce5ad3c76030b05fba9b40614cfe660f5e979122f44ef58cc6d8","t":1593025094}},{"t":1593025140,"p":{"ppi":{"l":172.34,"v":640054},"bitfinex":{"l":172.43,"v":231285},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"0f47cc6b3d89fab3fbfcfe3b29276413714c6aba4b047814ddcff8fa1ea9f4a4","t":1593025149}},{"t":1593025260,"p":{"ppi":{"l":172.34,"v":640915},"bitfinex":{"l":172.43,"v":232146},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"f000f1ec1fd0e77bc7911d3bc36f838df1a5987001b63746e45cc6e2a377e535","t":1593025271}},{"t":1593025320,"p":{"ppi":{"l":172.34,"v":641314},"bitfinex":{"l":172.43,"v":232545},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40496}},"tx":{"h":"bfff637c18da9ea8e26a6c7a3659d159fb3c46bf36c9349400c2d7bc886d973a","t":1593025333}},{"t":1593025380,"p":{"ppi":{"l":172.34,"v":641309},"bitfinex":{"l":172.43,"v":232545},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"d875acb84fb41cac33de5ee7c73cb40c4dd8769ed327d115a0085fb849621adb","t":1593025392}},{"t":1593025440,"p":{"ppi":{"l":172.34,"v":641309},"bitfinex":{"l":172.43,"v":232545},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"083effeb70dc5704de9360f2a4978900fcdb31431f3fe5f8a7cb6585fae6f0cb","t":1593025456}},{"t":1593025560,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"7537cfa8b0d64db14a35da536d7eb82950b4e5f6f4807701a21cf09167875967","t":1593025572}},{"t":1593025620,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"f69fc140d175b71ec5538062f60ac51b993be2defb771299fe56b00bc2c629db","t":1593025634}},{"t":1593025680,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"b9846cb7dcf6e717cad59e61bda7c3a5c5b96524afd884a5f7918eca7607c6c9","t":1593025695}},{"t":1593025740,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"e43b0f536ad06a5f9fb8ca27a9106786ef993c4bb2e4003700bfaa7a2a35081b","t":1593025750}},{"t":1593025860,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"11e37ec76ae08da7a73a8519eafc9a050dd83445e3ad56fc101678bc54c5dcee","t":1593025870}},{"t":1593025920,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"fbde231ffa77b3acfb4fc43e6525c1e146f4d54548925024845173f7c14df0ad","t":1593025930}},{"t":1593025980,"p":{"ppi":{"l":172.34,"v":641287},"bitfinex":{"l":172.43,"v":232523},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"7768ab0818f7345d3a5ad5090b278ced9e5acc18fe46d33fb0d64c55e92694e4","t":1593025988}},{"t":1593026040,"p":{"ppi":{"l":172.32,"v":641559},"bitfinex":{"l":172.36,"v":232795},"bittrex":{"l":172.3,"v":360480},"okcoin":{"l":172.14,"v":7793},"poloniex":{"l":172.28,"v":40491}},"tx":{"h":"ca6c26e9d5c81ff6d651b5853cd3c072a2e4f5149575d26997de9a008f44d4d8","t":1593026052}},{"t":1593026160,"p":{"ppi":{"l":173.21,"v":654982},"bitfinex":{"l":173.75,"v":236765},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.09,"v":8345},"poloniex":{"l":172.51,"v":40554}},"tx":{"h":"6b3641ae225f88ef4f8b6cf2ff252cbeb2d924cada3688dee081b5524971df32","t":1593026174}},{"t":1593026220,"p":{"ppi":{"l":173.14,"v":654710},"bitfinex":{"l":173.55,"v":236493},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.09,"v":8345},"poloniex":{"l":172.51,"v":40554}},"tx":{"h":"3fc4a9ad88a2e70187a9612c203985a77e1cda18639e681ea8cfd17199fa1008","t":1593026231}},{"t":1593026280,"p":{"ppi":{"l":173.15,"v":655333},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":172.51,"v":40554}},"tx":{"h":"ad67f6572823d8a553998fee4a5dc52257aa3a10545c55a867f4d9c5245a51c6","t":1593026298}},{"t":1593026340,"p":{"ppi":{"l":173.15,"v":655333},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":172.51,"v":40554}},"tx":{"h":"07a2cd3eafdcd529a5f9025d9dc6647fa77b22386ae79540971e78726d8d9638","t":1593026350}},{"t":1593026460,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"8809c15cbf289a4f752da0fc085c470c1fc0f855f1e4378ccebed0146309a1d1","t":1593026474}},{"t":1593026520,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"64e972df00133e564ca30b5bd8fd11d7e657a44bbf48f111818414f7570969d6","t":1593026534}},{"t":1593026580,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"149ea6476a4a4f2aab010e04048f560adaf09ed93734ecc804aeab2070e69c7c","t":1593026611}},{"t":1593026640,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"b53c56c3034bd14e8a1677f7cbfbcbfdd459115ee46209cefa5a79800f2084a0","t":1593026650}},{"t":1593026760,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"07539350a0461a136d3c3bdbdc3b52b5d366cc748362a795af293e775e71403b","t":1593026768}},{"t":1593026820,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"a981bb7ac0699493ea7eafe9eca1f8b76a5a54fd913b8d55eabd34cbeddd4b71","t":1593026829}},{"t":1593026880,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"51ac1441156950922781005679b4436bcb8723128c0734e4431a29341cae0ec3","t":1593026890}},{"t":1593026940,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"a0c3be4117944b89c5bc258cc5479a288fb86101238fffd5374440a3347445f1","t":1593026951}},{"t":1593027060,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"cb7e0f369e7088ad0a9cfa5d3f4f3cb10e462b0e0bfa0115c47185be2674a4bb","t":1593027069}},{"t":1593027120,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"0cdd5bf89dd4a9d953f0e8a562ab19755498be5be88909207470d9e99b130bfd","t":1593027131}},{"t":1593027180,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"377a5f4769b05a95a754a8eb7fff61bc118a21adc7dd1bcbeb826a35c6da1e47","t":1593027188}},{"t":1593027240,"p":{"ppi":{"l":173.19,"v":655433},"bitfinex":{"l":173.55,"v":236855},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"a1d1cb9382f412e5b360bf4b16bfaeb934bcaabcf00f0dcf84e6970e6a0458da","t":1593027249}},{"t":1593027360,"p":{"ppi":{"l":173.19,"v":648545},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"5ec2145a48258e9cf6a777887e1c5d420a163e5a90d2aa5775739ba30790f58e","t":1593027369}},{"t":1593027420,"p":{"ppi":{"l":173.19,"v":648545},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"b2538b3469de8c868021ed30603ea28e2241f04cd2113071ca5a29f742b5f580","t":1593027428}},{"t":1593027480,"p":{"ppi":{"l":173.19,"v":648545},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":369318},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"bdf0a1c3ad3b0e95ade381db0cd3803a5e1e6fe6e22e75f34eb331ab4b3e41b6","t":1593027488}},{"t":1593027540,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"bc8ce0b34dd71d99f6e5d6ecb5ed5cd34b6cf69d6089c7e824aecab88b95305b","t":1593027549}},{"t":1593027660,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"3c5b1c01b307f67e966bcc89407e7454d419b1c22a607ed74fdde14c0f6649d1","t":1593027668}},{"t":1593027720,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"360fa1fbea913d7bb92e9f8c0c35dd09fe140dd17cc489ec5f81e9e5b7d93f48","t":1593027728}},{"t":1593027780,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"8751b8219452005f050a7445144c0e7f4460ec76dcc8e57d60b7720b2cc20029","t":1593027788}},{"t":1593027840,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"16c900780d4c3d2f960d636af5b6bd58866da0b00a837eccbff96b6cac981f9b","t":1593027848}},{"t":1593027960,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"1a36305413883722752caf8beabc49818f36dae04140a1a4ce81a797d297f8cb","t":1593027968}},{"t":1593028020,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"3dc53f846b36ff4596d5c93020c5d0ce5b85d09cf389960590dec5d16a62f7cc","t":1593028029}},{"t":1593028080,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"7ba102d2dad3eb0dfd1464c05f9e58e86762cd06058f0ff41a31595ca761c71b","t":1593028088}},{"t":1593028140,"p":{"ppi":{"l":173.19,"v":647190},"bitfinex":{"l":173.55,"v":229967},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"8cfdfd09f60f6c13141fbbf67d33997ec5cac66b96489bdc1d378f518f8ab636","t":1593028148}},{"t":1593028260,"p":{"ppi":{"l":173.19,"v":644546},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"21e48b6503ec00e3c30794963f64deab33bd38fe148b4d5edbc83de250e6c1a1","t":1593028269}},{"t":1593028320,"p":{"ppi":{"l":173.19,"v":644546},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.95,"v":367963},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"6db9c896558fbdb7f2196b40db373becf822ce1acc9146a0d8864146dcb73aba","t":1593028328}},{"t":1593028380,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"b3c359f8388c22b51dc25c1714e9f3c261e49d38ebdcd523a56285d7552efad8","t":1593028410}},{"t":1593028440,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"e51ea182aa46902f1ae4f905eb91c0237fa337baa44a3927ebad03b2b47c55d3","t":1593028450}},{"t":1593028560,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"c2785dfd4c306b5b82538b0e097e441131e5cb7db9f2a80f148472e201a4b153","t":1593028569}},{"t":1593028620,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"856735967fd523ddf7785becbcc10d15bc0f6da7ca8d7a7a3e1d56c29de5ac59","t":1593028629}},{"t":1593028680,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"b6754b53ea96ef61394b0e2a9a11fef3f595dcae8c367c07b2540ab55e26b521","t":1593028689}},{"t":1593028740,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"5f47d96b0e35828b6cbb1755f3ba555297f82ecb4da4151f0d61780c149aec54","t":1593028748}},{"t":1593028860,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"e572c7ba6d8a5c20337c2ec12f913f2d6625b246e68c1622e2f2c338dba4d3b9","t":1593028868}},{"t":1593028920,"p":{"ppi":{"l":173.04,"v":648494},"bitfinex":{"l":173.55,"v":227323},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"652b30eb0bae6aafa9bf37e21fd5b689ecdbbd03c74c8ae911109089a02e19ea","t":1593028928}},{"t":1593028980,"p":{"ppi":{"l":172.99,"v":648938},"bitfinex":{"l":173.4,"v":227767},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"9f6f0a9174d9445e9d35acb5cd516cb5b01d023fcb7a4feb1427696b92c94d34","t":1593028988}},{"t":1593029040,"p":{"ppi":{"l":172.99,"v":648938},"bitfinex":{"l":173.4,"v":227767},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"b9f1373aa2e139792cd56448bd4f5eccc8f1bbf6c358abdfdf782fdf05ef59d9","t":1593029048}},{"t":1593029160,"p":{"ppi":{"l":172.99,"v":648770},"bitfinex":{"l":173.4,"v":227599},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"6f4c69851bb2fe9ac0591d1f0974a3551ca7f952d70ec6dc87f217af3c5ddebf","t":1593029169}},{"t":1593029220,"p":{"ppi":{"l":172.99,"v":648770},"bitfinex":{"l":173.4,"v":227599},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8606},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"34936d442b4e8ccd017032d609f879e31a22ffa97e50a3d66012e83e3a414fd1","t":1593029228}},{"t":1593029280,"p":{"ppi":{"l":172.99,"v":648419},"bitfinex":{"l":173.4,"v":227599},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"312ee3daa286c72923594e53c940906da32a5e7c2a961ddb19fb5a8a36aacf4a","t":1593029289}},{"t":1593029340,"p":{"ppi":{"l":172.99,"v":648419},"bitfinex":{"l":173.4,"v":227599},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"77a87724b75d1f01166710dfeb4fe074e3d71115bbfa3cd24fd16b01caf884a3","t":1593029348}},{"t":1593029460,"p":{"ppi":{"l":173,"v":650570},"bitfinex":{"l":173.42,"v":229750},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"2574c41608fe02325f5dd64a5394b5d55aac9fff22198a3b3b98486afcb2a037","t":1593029468}},{"t":1593029520,"p":{"ppi":{"l":173,"v":650570},"bitfinex":{"l":173.42,"v":229750},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"9f38b3b4b9cb0885044b3b3d42a527bd2f58f0f30d67f2e409c1a727052f8639","t":1593029528}},{"t":1593029580,"p":{"ppi":{"l":173,"v":650570},"bitfinex":{"l":173.42,"v":229750},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"a2caa970738d4bd3273a23ccc63dde5143674ba51da932d68a25bcaae0c66dd4","t":1593029588}},{"t":1593029640,"p":{"ppi":{"l":173,"v":650570},"bitfinex":{"l":173.42,"v":229750},"bittrex":{"l":172.7,"v":371911},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"3838fcbb23ac7c359220b21f640993e76158948dbd3c34d83d62e042c6cd771f","t":1593029648}},{"t":1593029760,"p":{"ppi":{"l":173.39,"v":651352},"bitfinex":{"l":173.65,"v":230417},"bittrex":{"l":173.24,"v":372026},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"6d7d929003e2506a8535e2896dbeaa7bf1c11d4f0bbf3ffa5a555c9629bd1435","t":1593029768}},{"t":1593029820,"p":{"ppi":{"l":173.39,"v":651352},"bitfinex":{"l":173.65,"v":230417},"bittrex":{"l":173.24,"v":372026},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"80277b848a38a6086f1331b07e4bfb4bea376bfb68688c964dab76bb425962fd","t":1593029829}},{"t":1593029880,"p":{"ppi":{"l":173.39,"v":651352},"bitfinex":{"l":173.65,"v":230417},"bittrex":{"l":173.24,"v":372026},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"5c63a9ffcb648e54065bbab3fc68e63f71ca8fd12810fcffb0c50d69a3281df8","t":1593029888}},{"t":1593029940,"p":{"ppi":{"l":173.35,"v":658147},"bitfinex":{"l":173.54,"v":237212},"bittrex":{"l":173.24,"v":372026},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"bbe1a4694a659663739cc2896fd1f305c079906d23d29162b03bc8e4f8517d14","t":1593029948}},{"t":1593030060,"p":{"ppi":{"l":173.36,"v":658720},"bitfinex":{"l":173.54,"v":237212},"bittrex":{"l":173.26,"v":372599},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"c5804118fa588db4e3c600045160d1ac10cba5ad5f1ec66b0d4146b9796a5a08","t":1593030068}},{"t":1593030120,"p":{"ppi":{"l":173.36,"v":658205},"bitfinex":{"l":173.54,"v":237212},"bittrex":{"l":173.26,"v":372084},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"0b322bf0f69920b25c12e3bff3b672ec15c1778402acffa15b5cce80b8025e28","t":1593030128}},{"t":1593030180,"p":{"ppi":{"l":173.43,"v":659073},"bitfinex":{"l":173.54,"v":237212},"bittrex":{"l":173.38,"v":372952},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"6639f971b943857d0a1aaa794474db1442529e856bbf7bbe436596206b1b277a","t":1593030211}},{"t":1593030240,"p":{"ppi":{"l":173.58,"v":664239},"bitfinex":{"l":173.54,"v":237212},"bittrex":{"l":173.65,"v":378118},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"31009a8f141bd2abe8f772ac00cc1e9869142300e436d7c4bb28de7ff5552d6d","t":1593030248}},{"t":1593030360,"p":{"ppi":{"l":173.65,"v":666271},"bitfinex":{"l":173.54,"v":237212},"bittrex":{"l":173.77,"v":380150},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"fcc5ea35a4e7de1657e11a3d530fc57800082cccf8eae60cc276e1142389158f","t":1593030369}},{"t":1593030420,"p":{"ppi":{"l":173.93,"v":673370},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.03,"v":386241},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"d8f6151430e43d8d2fca20f9bdde7224b4d0e2fa1af94155d156992cd01900de","t":1593030428}},{"t":1593030480,"p":{"ppi":{"l":173.95,"v":678748},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.07,"v":391619},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"07ff3f838a08972d1582c948526a633427aa9b5aa49e5ed440031600c986a2fd","t":1593030488}},{"t":1593030540,"p":{"ppi":{"l":173.95,"v":678748},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.07,"v":391619},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"89f627e266b1abf9dd3677ac693f299f9fcc62cacdfd5c034b3430cd2d31c33e","t":1593030549}},{"t":1593030660,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"2c48532b7dd6a852b464d212e2c0552716143dbd49920d56d9be0b784bf45f43","t":1593030668}},{"t":1593030720,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"8350ac9b5fc53b617ae7caa7e0298217355b131130451d6ddc39ee8ff4ee9e0d","t":1593030728}},{"t":1593030780,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"afd9d446ce271178f2dd4be38cdc0ade20e6a42695411649d8f3f224f26a42e5","t":1593030789}},{"t":1593030840,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"030b3576a6835d7840c7f6450fab84f39d0ac24d37be3031549b423ffee450d2","t":1593030848}},{"t":1593030960,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"2cd2476cdc5c72c06fbdfdc1374aed808a1f6bb5cc17b28e97125e2c3604d221","t":1593030968}},{"t":1593031020,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"e0c04818636fcc4695f9efc520ba366a163519c4918b059fbc989238c1fd1cdf","t":1593031030}},{"t":1593031080,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"0ccae3f7d3f47bad7a281ed7727a177c153ecd798d33fb9a2dd317287ef8054c","t":1593031088}},{"t":1593031140,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"8e276188720b0b3412477c0d6f6eeb104ea58d103e2e0e0b17215908ba4efd05","t":1593031148}},{"t":1593031260,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"798b7232591a02801d1b76709f7f55c746454d2010066897a17b134ac65ab40c","t":1593031269}},{"t":1593031320,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"184a1b492e74369180bb8add6fbe11e6b5584aa1a62c711134426624ba14f32a","t":1593031328}},{"t":1593031380,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"19c7c3fd79f1e670e796660b935feef8683d882c555875264c3f1720007d790d","t":1593031389}},{"t":1593031440,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"0710d8d33697f0ca28a2ac692d7c73e160db824b4ad70250361513204b9eb691","t":1593031448}},{"t":1593031560,"p":{"ppi":{"l":173.94,"v":683453},"bitfinex":{"l":173.89,"v":238220},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"75ba6f656ee2833f155cbc61fdb38c90fb154955d4908891fb9260919ff8939b","t":1593031575}},{"t":1593031620,"p":{"ppi":{"l":173.82,"v":683465},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"7c4c3ce201db8050b05333ab884e86688a11fa295a5edbb6f61d6f4faf677c02","t":1593031628}},{"t":1593031680,"p":{"ppi":{"l":173.82,"v":683465},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"5d753c7c63c1435371b43831f4961ac14d408e6c6b3e33c1064cc6be8ad46da1","t":1593031689}},{"t":1593031740,"p":{"ppi":{"l":173.82,"v":683465},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":174.05,"v":396324},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"b7f31761eb1c925da2b48211082f39d91623fc70b9c8378c9f54e34757d6f0b1","t":1593031749}},{"t":1593031860,"p":{"ppi":{"l":173.61,"v":683480},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.69,"v":396339},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"81c55b6398e97d5ee06f49d05b9e1dd4cd3c73d91679c9fb49cd5e9caa1ad8e2","t":1593031869}},{"t":1593031920,"p":{"ppi":{"l":173.46,"v":684574},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"9ce012581a53fd66acda118717fea8525ab708517bf03328315fbd8bbc39df1e","t":1593031929}},{"t":1593031980,"p":{"ppi":{"l":173.46,"v":684574},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"c6b4d4c500205f621682a50335980b61c0f17b4e49793cc456adbe670e525f1f","t":1593032013}},{"t":1593032040,"p":{"ppi":{"l":173.46,"v":684574},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.26,"v":40654}},"tx":{"h":"068bd8c06d3986dcf815652290202d43dda159ab033789d062580d0b646559fb","t":1593032049}},{"t":1593032160,"p":{"ppi":{"l":173.48,"v":684575},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.49,"v":40655}},"tx":{"h":"16fb4782f69cd28e16d68d3c84211971e95ac5145f1dd83e99251272d58c5641","t":1593032169}},{"t":1593032220,"p":{"ppi":{"l":173.48,"v":684575},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.49,"v":40655}},"tx":{"h":"ce0a5f7cc227115554b229a8b19987621edd422cf33ad42149798634e513f2a0","t":1593032229}},{"t":1593032280,"p":{"ppi":{"l":173.48,"v":684576},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.49,"v":40656}},"tx":{"h":"1097980176e67ea5b30e252fc5a54b23896e5801e29867e6ea82f0257dd96dd2","t":1593032289}},{"t":1593032340,"p":{"ppi":{"l":173.48,"v":684576},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.44,"v":397433},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.49,"v":40656}},"tx":{"h":"96d7f93ecd820e37fcb208f9022fda81a9795d99a989eaed6481993eb6e007de","t":1593032348}},{"t":1593032460,"p":{"ppi":{"l":173.34,"v":685212},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.23,"v":398068},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.22,"v":40657}},"tx":{"h":"03aa551782f1ba5567bd967df696f6d86f7182519ef27984e59e62048c25f144","t":1593032468}},{"t":1593032520,"p":{"ppi":{"l":173.34,"v":684735},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.23,"v":397591},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.22,"v":40657}},"tx":{"h":"0723c9e7f304d139639d83a0e0209059574b776852d95c98399c6fc53c5f2b57","t":1593032528}},{"t":1593032580,"p":{"ppi":{"l":173.35,"v":684737},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.23,"v":397591},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40659}},"tx":{"h":"3b72a452cd49c8d377d69edb54997d9c1400660b162d2c86f90afb70f0eeb631","t":1593032588}},{"t":1593032640,"p":{"ppi":{"l":173.35,"v":684737},"bitfinex":{"l":173.53,"v":238232},"bittrex":{"l":173.23,"v":397591},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40659}},"tx":{"h":"7ae11312dfd58a3a6f49e826069113d51fc980a203bb810e42c065e31161e4cc","t":1593032648}},{"t":1593032760,"p":{"ppi":{"l":173.35,"v":682927},"bitfinex":{"l":173.53,"v":237808},"bittrex":{"l":173.23,"v":396205},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40659}},"tx":{"h":"6a483756cca670108809a62b688ca962de5bb71205c9dfa2784b632f4841cabb","t":1593032768}},{"t":1593032820,"p":{"ppi":{"l":173.35,"v":682928},"bitfinex":{"l":173.53,"v":237808},"bittrex":{"l":173.23,"v":396205},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40660}},"tx":{"h":"b51b3c5170b4b08f4790e31a9575cbbd39ddb05ad4791986209442aca3088d1b","t":1593032828}},{"t":1593032880,"p":{"ppi":{"l":173.35,"v":682929},"bitfinex":{"l":173.53,"v":237808},"bittrex":{"l":173.23,"v":396205},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40661}},"tx":{"h":"a35c8cf38ee355453543efc6d8c1d160e8f6a6c3e8177b025ed8159aa927302e","t":1593032888}},{"t":1593032940,"p":{"ppi":{"l":173.37,"v":683759},"bitfinex":{"l":173.57,"v":238637},"bittrex":{"l":173.23,"v":396205},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40662}},"tx":{"h":"d4b79a5aa2e4f5468cda8da6a9dce8a63f0961e2358a37475c740b4bb6e725f9","t":1593032948}},{"t":1593033060,"p":{"ppi":{"l":173.36,"v":684136},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":173.23,"v":396205},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40662}},"tx":{"h":"4b7461a5649cf33e2257cbcb5d375aebac4af69db1421571ebdda278488f2ca3","t":1593033069}},{"t":1593033120,"p":{"ppi":{"l":173.36,"v":684137},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":173.23,"v":396205},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"fa0a1d68cbd214f06aef2165a6da416077efc49e82a1ff6da7432ee30701fb15","t":1593033128}},{"t":1593033180,"p":{"ppi":{"l":173.38,"v":684970},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":173.26,"v":397038},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"60e3c218b92e6227cbae452e3b8b6cd8b675fe0cfa38ade0db15a3c83a6cc695","t":1593033188}},{"t":1593033240,"p":{"ppi":{"l":173.33,"v":690021},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":173.17,"v":402089},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"a2a1bff9e8c14ded2d87fd9e0f47c1c46ccc8884cbeb1c5baa939385fcab78a7","t":1593033249}},{"t":1593033360,"p":{"ppi":{"l":173.17,"v":693165},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405233},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"f00993f0b612ce71a56c77c1a2ac03c48140e6d8e3b70e0a09872a2f7c6b2910","t":1593033368}},{"t":1593033420,"p":{"ppi":{"l":173.17,"v":693165},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405233},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"8c8753f0025af245cec68f236fab19e38d62df1774e682f591a1209355c153dc","t":1593033428}},{"t":1593033480,"p":{"ppi":{"l":173.17,"v":693504},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405572},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"2e69cc8b838c2eb2547cf0fff74f0f0102de1cc4089da7ffe273bbb1554d0f55","t":1593033489}},{"t":1593033540,"p":{"ppi":{"l":173.17,"v":693504},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405572},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"72e8e41872668ea4ee4a5e69321a02e7938ea22d827d960192d21181dad7dbca","t":1593033549}},{"t":1593033660,"p":{"ppi":{"l":173.17,"v":693504},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405572},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"62bd55c94d6aede6efb9283ebf770ba1a7b5fb0aea8fc77088a3b462ca463907","t":1593033675}},{"t":1593033720,"p":{"ppi":{"l":173.17,"v":693504},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405572},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40663}},"tx":{"h":"e6f5169c3d044d92c83c007259874a795e4b30593f9c0aab839fc03d6075e8f3","t":1593033728}},{"t":1593033780,"p":{"ppi":{"l":173.17,"v":693505},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405572},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.36,"v":40664}},"tx":{"h":"95918730580c735f79bad1e78b42f6fa09ea1b5a17ddda9f8cc14681f6f92563","t":1593033813}},{"t":1593033840,"p":{"ppi":{"l":173.17,"v":693505},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.91,"v":405572},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.36,"v":40664}},"tx":{"h":"f308e4f1451696e4c8913eee91e5c6876cbbb06c0cfa15e37716f9f0c80b76fb","t":1593033849}},{"t":1593033960,"p":{"ppi":{"l":173.01,"v":694631},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.65,"v":406698},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.36,"v":40664}},"tx":{"h":"284c12dc3f0d024a02f7601b0ca7d84326d65f71f7f32c71544a52e1d971a89b","t":1593033968}},{"t":1593034020,"p":{"ppi":{"l":173.01,"v":694631},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.65,"v":406698},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.36,"v":40664}},"tx":{"h":"ef7f6d9fb992749900d1cad42d008dbd5a5f48db7316f1d8024c57e3f2d04a48","t":1593034029}},{"t":1593034080,"p":{"ppi":{"l":173.01,"v":694631},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.65,"v":406698},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.36,"v":40664}},"tx":{"h":"43c4d476350331f208caae72d5974f4fbd899fae59061885d246e4bbc2ba9c15","t":1593034089}},{"t":1593034140,"p":{"ppi":{"l":173.01,"v":694631},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.65,"v":406698},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.36,"v":40664}},"tx":{"h":"7169917f2ea0b22bcf1ab947ffc1e52aa945f62ff7427f1bde598853e73e809a","t":1593034148}},{"t":1593034260,"p":{"ppi":{"l":173.02,"v":694632},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.65,"v":406698},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40665}},"tx":{"h":"257dfef8183e972306883003bfdd2a359512b987efe980d425fea43c83930425","t":1593034268}},{"t":1593034320,"p":{"ppi":{"l":173.09,"v":694676},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40666}},"tx":{"h":"feabdeb4b86b3d954935ad17f69584d30f3da0dfc7653f6b5a19a9d48a21c921","t":1593034328}},{"t":1593034380,"p":{"ppi":{"l":173.09,"v":694676},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40666}},"tx":{"h":"379eb959e7048c8fd515ebb4f18992dd86f4fe57acd5352913d3727f846fc3ac","t":1593034388}},{"t":1593034440,"p":{"ppi":{"l":173.09,"v":694676},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40666}},"tx":{"h":"66c10759a8b7ea32844958705ac2726606bda2e3847731ce827f504b925b5f87","t":1593034448}},{"t":1593034560,"p":{"ppi":{"l":173.09,"v":694676},"bitfinex":{"l":173.56,"v":239014},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40666}},"tx":{"h":"c943e11b279dc012595227a1096fc81e5ac6b4173e3358e8570cbab1274fcb90","t":1593034568}},{"t":1593034620,"p":{"ppi":{"l":173.08,"v":696010},"bitfinex":{"l":173.52,"v":240348},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40666}},"tx":{"h":"fe4c8db19d2d8dea2b35b06c997e64398fcb2b2a9ecc0ab02507300b7c765db5","t":1593034628}},{"t":1593034680,"p":{"ppi":{"l":173.05,"v":696246},"bitfinex":{"l":173.43,"v":240584},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.45,"v":40666}},"tx":{"h":"bc547088ca02925e4fa37b23928f3868170c063e8cb9f9c429355c40fa87ea60","t":1593034688}},{"t":1593034740,"p":{"ppi":{"l":173.04,"v":696247},"bitfinex":{"l":173.43,"v":240584},"bittrex":{"l":172.77,"v":406741},"okcoin":{"l":173.5,"v":8255},"poloniex":{"l":173.32,"v":40667}},"tx":{"h":"1c847e708e3b2200ccec7bda2316b84bd705f2a1f2cc82a0579077c6baca67d1","t":1593034748}},{"t":1593034860,"p":{"ppi":{"l":172.72,"v":735185},"bitfinex":{"l":173.03,"v":260259},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.82,"v":10248},"poloniex":{"l":173.31,"v":40668}},"tx":{"h":"e0cb1a6f142ce33591c27faadf58f04765780a35e90938ef5a2409494d890eb9","t":1593034868}},{"t":1593034920,"p":{"ppi":{"l":172.72,"v":735185},"bitfinex":{"l":173.03,"v":260259},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.82,"v":10248},"poloniex":{"l":173.27,"v":40668}},"tx":{"h":"1a3dca5b075516ea07959728609112b10b1aae5c52eda8dad6b49bb4b7e70800","t":1593034929}},{"t":1593034980,"p":{"ppi":{"l":172.72,"v":735400},"bitfinex":{"l":173.04,"v":260473},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.82,"v":10248},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"ce5ce0f20a23c4a8198144d3eca59e3d180b0fb6d7f5af1b00579a851451bf3f","t":1593034988}},{"t":1593035040,"p":{"ppi":{"l":172.71,"v":743016},"bitfinex":{"l":173,"v":268089},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.82,"v":10248},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"81ad3b6ee1cab82bdc53e1c590172e4761c4c641dff0a019a9ac5b019671acf4","t":1593035048}},{"t":1593035160,"p":{"ppi":{"l":172.71,"v":743016},"bitfinex":{"l":173,"v":268089},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.82,"v":10248},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"e4e60bb7d1a5d51934e5d1ae06b294abc49cd69c73c28a417e4a8a58c13cf035","t":1593035168}},{"t":1593035220,"p":{"ppi":{"l":172.71,"v":747983},"bitfinex":{"l":173,"v":268089},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.58,"v":15215},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"f3a82936a901eccd00946584ef7ae429f92c8c803ab3f733cd8a059e770c7a40","t":1593035228}},{"t":1593035280,"p":{"ppi":{"l":172.71,"v":749033},"bitfinex":{"l":172.99,"v":268899},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.77,"v":15455},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"f30c354b7685c2337a7177f6aa1ff9b03f6c13482bc6bfdf6374766ce54f200b","t":1593035288}},{"t":1593035340,"p":{"ppi":{"l":172.71,"v":749385},"bitfinex":{"l":173,"v":268915},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.75,"v":15791},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"330eada58c1dd54f36bb05bac5408c5fc56a2c7d4a67426e73b2dfc7e3d07128","t":1593035349}},{"t":1593035460,"p":{"ppi":{"l":172.71,"v":756069},"bitfinex":{"l":173,"v":275599},"bittrex":{"l":172.47,"v":424010},"okcoin":{"l":172.75,"v":15791},"poloniex":{"l":173.27,"v":40669}},"tx":{"h":"bb5484f75eaebb58f22acc4eefd7aa8d53a020cc9f7c45c721b400eb3acf4a77","t":1593035469}},{"t":1593035520,"p":{"ppi":{"l":172.75,"v":760461},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":172.41,"v":427165},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.3,"v":40670}},"tx":{"h":"5978d69bcefeb44ecff750c3aa6d09b29855a2f3903ed4cd46344dbe1647f0a0","t":1593035528}},{"t":1593035580,"p":{"ppi":{"l":172.75,"v":760401},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":172.41,"v":427105},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.3,"v":40670}},"tx":{"h":"a95a0960b583855e3ce4a950cea212bcdd1e73a983b03b99afff4778f7ef01a4","t":1593035614}},{"t":1593035640,"p":{"ppi":{"l":172.75,"v":760401},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":172.41,"v":427105},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.3,"v":40670}},"tx":{"h":"0d8023f26511951d1bbac99c73ec18323951dc71aeb77c44f04bd0d3d7e5482b","t":1593035648}},{"t":1593035760,"p":{"ppi":{"l":172.76,"v":760403},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":172.41,"v":427105},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40672}},"tx":{"h":"7f237e9c24161c3911a626745155dd29045a066c37b8e56c0281642437f9f2f5","t":1593035768}},{"t":1593035820,"p":{"ppi":{"l":172.75,"v":760404},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":172.41,"v":427105},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.34,"v":40673}},"tx":{"h":"4ad01228941028fc128e20601f8694092ae5dde69081df4072ad74c18ee42af3","t":1593035828}},{"t":1593035880,"p":{"ppi":{"l":173.11,"v":761383},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":173.04,"v":428084},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.34,"v":40673}},"tx":{"h":"c588a48db19d31cfffa97da8d277c99b91290cba5bb936db376a5cb45290e1e7","t":1593035888}},{"t":1593035940,"p":{"ppi":{"l":173.11,"v":761384},"bitfinex":{"l":173.2,"v":276440},"bittrex":{"l":173.04,"v":428084},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.39,"v":40674}},"tx":{"h":"612dd5c9128789ba6f72dd8372ef283e408ca8ad90433368553c192ececec898","t":1593035949}},{"t":1593036060,"p":{"ppi":{"l":173.26,"v":762044},"bitfinex":{"l":173.61,"v":277099},"bittrex":{"l":173.04,"v":428084},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40675}},"tx":{"h":"db51ba755544f1ced38253efdf9d2b9743a16740ef97b953b13f01f9dce429a7","t":1593036068}},{"t":1593036120,"p":{"ppi":{"l":173.13,"v":761475},"bitfinex":{"l":173.25,"v":276530},"bittrex":{"l":173.04,"v":428084},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40675}},"tx":{"h":"43e688fec1216af81cf33d929f5b8c8e1e0601d979680825d32edcc1f709c416","t":1593036128}},{"t":1593036180,"p":{"ppi":{"l":173.13,"v":761475},"bitfinex":{"l":173.25,"v":276530},"bittrex":{"l":173.04,"v":428084},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40675}},"tx":{"h":"73c8877206d105c150e3bf4a12407b376d98119d212e30f81ad95be972958f39","t":1593036188}},{"t":1593036240,"p":{"ppi":{"l":172.95,"v":766117},"bitfinex":{"l":173.25,"v":276530},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40675}},"tx":{"h":"1341432acd1a9327dd165c974e9501debc954efae7739177aa2f1b550360943f","t":1593036249}},{"t":1593036360,"p":{"ppi":{"l":172.95,"v":764601},"bitfinex":{"l":173.25,"v":275014},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40675}},"tx":{"h":"30d5409dd65685b2aa640d749d97bdd7bfc70f0fd7d7e46cc1ee22d3e7d32374","t":1593036368}},{"t":1593036420,"p":{"ppi":{"l":172.95,"v":764601},"bitfinex":{"l":173.25,"v":275014},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.36,"v":40675}},"tx":{"h":"87fd6bde5916b4d687e587ba28beca22675ce0e5c962bf04f71d4ca8872df631","t":1593036428}},{"t":1593036480,"p":{"ppi":{"l":172.93,"v":764601},"bitfinex":{"l":173.25,"v":275014},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.99,"v":40675}},"tx":{"h":"d0d2358dde137850425a13ff681ae60bd414e1f124c8e8ed2faefdc06d4a1d7e","t":1593036488}},{"t":1593036540,"p":{"ppi":{"l":172.93,"v":764602},"bitfinex":{"l":173.25,"v":275014},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.99,"v":40676}},"tx":{"h":"a4d8ae3280f04e3f3ed73e42f4c57cd2dab83c474af2426df9062ccdc4fa7837","t":1593036548}},{"t":1593036660,"p":{"ppi":{"l":172.93,"v":764603},"bitfinex":{"l":173.25,"v":275014},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.12,"v":40677}},"tx":{"h":"c8cabcfed6f3f72b650f3543d8df8553eba89a8c572385bc0580c7ade4aed22d","t":1593036669}},{"t":1593036720,"p":{"ppi":{"l":172.83,"v":764542},"bitfinex":{"l":172.97,"v":274953},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.12,"v":40677}},"tx":{"h":"6a5f483f6c46bf5ca3246e78aec961c7dedc3f50c94e27400f0d6985d723cc40","t":1593036728}},{"t":1593036780,"p":{"ppi":{"l":172.83,"v":764542},"bitfinex":{"l":172.97,"v":274953},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.12,"v":40677}},"tx":{"h":"6d7fd28c32c1b7c5acb77e5d76b2001ac5b5860ce48ae9f04f0a84d0d8193708","t":1593036789}},{"t":1593036840,"p":{"ppi":{"l":172.84,"v":764689},"bitfinex":{"l":172.98,"v":275100},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.12,"v":40677}},"tx":{"h":"36ecf7b6d4cd48abf2f461c35b26fb90fad9db255f35e3a76012d77cc3e16b71","t":1593036848}},{"t":1593036960,"p":{"ppi":{"l":172.84,"v":764689},"bitfinex":{"l":172.98,"v":275100},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.18,"v":40677}},"tx":{"h":"cf47c614c98b1b5b88b93fd9b256036c00c942c84cdccc29a71d5f272969cf17","t":1593036968}},{"t":1593037020,"p":{"ppi":{"l":172.84,"v":764691},"bitfinex":{"l":172.98,"v":275100},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.18,"v":40679}},"tx":{"h":"596086213698a7b23413c8240025950b245a9b462ca5c6d2c43237a1229a3f31","t":1593037029}},{"t":1593037080,"p":{"ppi":{"l":172.87,"v":768280},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.18,"v":40680}},"tx":{"h":"d27587fb5ef66c2e98a4e7a7da6aa7dcbccccfb37b150955f94f630c1e10636b","t":1593037088}},{"t":1593037140,"p":{"ppi":{"l":172.88,"v":768281},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":173.31,"v":40681}},"tx":{"h":"4c6c22beb4a597821df1c452552385fec5671e046aae80d53adac2da0e174860","t":1593037148}},{"t":1593037260,"p":{"ppi":{"l":172.84,"v":776401},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48801}},"tx":{"h":"2aa887ea6e84f056f7be232fdbec7024cc95e265a9e48e5228d9f9e37c68f15b","t":1593037268}},{"t":1593037320,"p":{"ppi":{"l":172.84,"v":776401},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48801}},"tx":{"h":"501079fb0eafe0f3bf7e29329882522e22f6a795ad7ed748f27637faf50330c3","t":1593037328}},{"t":1593037380,"p":{"ppi":{"l":172.84,"v":776401},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48801}},"tx":{"h":"7c373ceeb0aa1fe668dc4f3e38da1785c9835b4e6c97daa6deec5a7cf6805354","t":1593037415}},{"t":1593037440,"p":{"ppi":{"l":172.84,"v":776401},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48801}},"tx":{"h":"f42dd139a080be19b3f416aefb8dd53e737a17fb2e4f140671e7b68f384fcd2c","t":1593037448}},{"t":1593037560,"p":{"ppi":{"l":172.84,"v":776401},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":172.72,"v":432726},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48801}},"tx":{"h":"ec1481b5e01d31d63796dfd558e3c782c97f8f6391fc352f3126868b4ebdd425","t":1593037569}},{"t":1593037620,"p":{"ppi":{"l":173.02,"v":777006},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":433844},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"77f6b415a22858098c97c9164829a18ea10a1eac70facbd088bb8f61460a3ecc","t":1593037628}},{"t":1593037680,"p":{"ppi":{"l":173.02,"v":777006},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":433844},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"e3138b2a130150e7e109674f4b2f51a60185f99b311d703bd09e5c3494a337ac","t":1593037688}},{"t":1593037740,"p":{"ppi":{"l":173.02,"v":777006},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":433844},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"6e7d60b68bd6a15ed33d8d8508bc83d1d4eff2e6ca535d90c90c4b676620fb6d","t":1593037748}},{"t":1593037860,"p":{"ppi":{"l":173.02,"v":776096},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432934},"okcoin":{"l":172.78,"v":16186},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"d82990bf3f3dc16fae52baa68bf221c1059acb90bd4758f0595ba52ba5a2846d","t":1593037869}},{"t":1593037920,"p":{"ppi":{"l":173.02,"v":775648},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432934},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"41eaa64bd95fcae843342d6101c030d786fecf83126f403e9eb624213c15bb07","t":1593037928}},{"t":1593037980,"p":{"ppi":{"l":173.02,"v":775066},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"ae882adea425fd97e91c866b0b9326e9b8b7fe71965edcb45edb4fd58a9654e3","t":1593037988}},{"t":1593038040,"p":{"ppi":{"l":173.02,"v":775066},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.67,"v":48288}},"tx":{"h":"49ea6cb880d7db106312f34654c0142beb36bdc7c403b0b120f0330640dfdf0a","t":1593038048}},{"t":1593038160,"p":{"ppi":{"l":172.99,"v":775066},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.16,"v":48288}},"tx":{"h":"034c1e31cfd62f052e97ba55d99bdc258024325bff95ed736adeb98b0aefa476","t":1593038169}},{"t":1593038220,"p":{"ppi":{"l":172.97,"v":792284},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.16,"v":65506}},"tx":{"h":"49190d58ae984b43561241c575135bb7a8d72e220745b06cde67f6478663b370","t":1593038229}},{"t":1593038280,"p":{"ppi":{"l":172.88,"v":792284},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":171.03,"v":65506}},"tx":{"h":"4a8fbae316108f773b9b8c84100a73be51ddee9ba90a606a25e570bc27165cf4","t":1593038288}},{"t":1593038340,"p":{"ppi":{"l":172.79,"v":828778},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":171.03,"v":102000}},"tx":{"h":"caa298f8211bf02a0cf821a25e01cc8e38163290a3b277009969c0b7cafc2556","t":1593038348}},{"t":1593038460,"p":{"ppi":{"l":172.96,"v":828779},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":432352},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.39,"v":102001}},"tx":{"h":"76524fc7d0310c384ed101c6c0d3f0cae668f9699d8ae65bfd1675aa75f8bee9","t":1593038468}},{"t":1593038520,"p":{"ppi":{"l":172.96,"v":819358},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":422931},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.39,"v":102001}},"tx":{"h":"7ab9b31c36757b334b4b745243614df18e3f24a55253b5a020eb4a1d7b603a35","t":1593038528}},{"t":1593038580,"p":{"ppi":{"l":172.96,"v":819358},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":422931},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.39,"v":102001}},"tx":{"h":"af5d2d4d35d6c796f35315985073acc71b13c08f230bc6142347aec07b7b4ca4","t":1593038587}},{"t":1593038640,"p":{"ppi":{"l":172.96,"v":819358},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":422931},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.39,"v":102001}},"tx":{"h":"bc3b18b5e64534ce87746efde1b26d1a51b9801e208f72555616b3dac5dfbe01","t":1593038648}},{"t":1593038760,"p":{"ppi":{"l":172.97,"v":821592},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":422531},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.49,"v":104635}},"tx":{"h":"10a0fb3772890649f915d052db5ed8c58e6d4647aae752e48929f5720e0e4a1f","t":1593038769}},{"t":1593038820,"p":{"ppi":{"l":172.97,"v":821592},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":422531},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.49,"v":104635}},"tx":{"h":"7279438bfd94f528833115e6dae09615cce807368eef82f9f4964a0b3a633d5d","t":1593038828}},{"t":1593038880,"p":{"ppi":{"l":172.97,"v":820859},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":421798},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.49,"v":104635}},"tx":{"h":"9bf3ce06dfab58afed78189fc53aea3cc4093bc06c8c3f308dfe9a21bc5ba897","t":1593038889}},{"t":1593038940,"p":{"ppi":{"l":172.97,"v":820861},"bitfinex":{"l":173.06,"v":278688},"bittrex":{"l":173.04,"v":421798},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.49,"v":104637}},"tx":{"h":"de9840898654f2e6045bb7ac1651e542f344828ddfb66d6a3bfcfb8cc93bec2f","t":1593038948}},{"t":1593039060,"p":{"ppi":{"l":172.97,"v":815415},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":421798},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.52,"v":104638}},"tx":{"h":"e7e4290a82cb8a9767f406c2a33969a856e12081b9f17bdb558addabeaef00fd","t":1593039069}},{"t":1593039120,"p":{"ppi":{"l":172.97,"v":815415},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":421798},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.52,"v":104638}},"tx":{"h":"cda9310fe8021ebe11416b4d055dd2851261eb0ea7951128a4418f8c9f534d30","t":1593039129}},{"t":1593039180,"p":{"ppi":{"l":173,"v":815415},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":421798},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.72,"v":104638}},"tx":{"h":"291369e455f81c1e974dd9216622a0b243c7eef042cc60e253304a9455bdf64e","t":1593039215}},{"t":1593039240,"p":{"ppi":{"l":173,"v":815416},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":421798},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.72,"v":104639}},"tx":{"h":"6324dbd15c0ed1270e90a8503ca5b7c78f5445a1ac0f3170ae083c42d7be48b6","t":1593039248}},{"t":1593039360,"p":{"ppi":{"l":173.01,"v":814344},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":420725},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.83,"v":104640}},"tx":{"h":"bdf6ea7dd528488adc83660f01cfb145245a424edced976394fbc224a9ff62e3","t":1593039368}},{"t":1593039420,"p":{"ppi":{"l":173,"v":813652},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":420032},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.75,"v":104641}},"tx":{"h":"6cfc792e24abe95417349895602c0018eb750857e24fc65c90cf55706b745b5e","t":1593039429}},{"t":1593039480,"p":{"ppi":{"l":173,"v":813652},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":420032},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.75,"v":104641}},"tx":{"h":"9ebf3b0426fd992572c3d50216662203bcadd6d7b7cf4498cfb21d4ae9b2725c","t":1593039489}},{"t":1593039540,"p":{"ppi":{"l":173.03,"v":813653},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":420032},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.97,"v":104642}},"tx":{"h":"e16b5f579834d5799e429bb56dbd559226027170a47706d2971e98830cbc7e37","t":1593039548}},{"t":1593039660,"p":{"ppi":{"l":173,"v":808950},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":415329},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.71,"v":104642}},"tx":{"h":"6c9789662c8c736d1e73db5ae5308b7e2c3c4064861face0c563dd6a86e3a3d5","t":1593039668}},{"t":1593039720,"p":{"ppi":{"l":173.07,"v":802291},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.04,"v":408768},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":173.26,"v":104544}},"tx":{"h":"2fd74be4c407e6ee7e0e38f4a3d9f20f219f7f57ca9665e1301b326db9f94057","t":1593039728}},{"t":1593039780,"p":{"ppi":{"l":173.03,"v":805343},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.1,"v":409546},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.75,"v":106818}},"tx":{"h":"da935c0461195137311e4e3267b13f8e3f4bfb967764bb24ebd8772961224e41","t":1593039788}},{"t":1593039840,"p":{"ppi":{"l":173.03,"v":805343},"bitfinex":{"l":173.06,"v":273241},"bittrex":{"l":173.1,"v":409546},"okcoin":{"l":172.78,"v":15738},"poloniex":{"l":172.75,"v":106818}},"tx":{"h":"c0fca7fb579ebe3ec567e8045771285fbd68fb61f57e43a953c600244240cdf2","t":1593039848}},{"t":1593039960,"p":{"ppi":{"l":173.04,"v":803546},"bitfinex":{"l":173.09,"v":273061},"bittrex":{"l":173.1,"v":408501},"okcoin":{"l":172.78,"v":15166},"poloniex":{"l":172.75,"v":106818}},"tx":{"h":"7d3b12ccaa076ba44c5024e9c5466225dd4eeaa7202767258727715dfd2189d8","t":1593039968}},{"t":1593040020,"p":{"ppi":{"l":173.04,"v":804151},"bitfinex":{"l":173.09,"v":273666},"bittrex":{"l":173.1,"v":408501},"okcoin":{"l":172.78,"v":15166},"poloniex":{"l":172.75,"v":106818}},"tx":{"h":"d8cf74a80645b8129fedeba69baaaf5674eef9adf317b4475223f9fdbd19c8dc","t":1593040029}},{"t":1593040080,"p":{"ppi":{"l":173.04,"v":804151},"bitfinex":{"l":173.09,"v":273666},"bittrex":{"l":173.1,"v":408501},"okcoin":{"l":172.78,"v":15166},"poloniex":{"l":172.75,"v":106818}},"tx":{"h":"a6d03c982734848465997684ec6622bb9819394760e3296d6756b97999434873","t":1593040089}},{"t":1593040140,"p":{"ppi":{"l":173.04,"v":804151},"bitfinex":{"l":173.09,"v":273666},"bittrex":{"l":173.1,"v":408501},"okcoin":{"l":172.78,"v":15166},"poloniex":{"l":172.75,"v":106818}},"tx":{"h":"cfba1b9c18c1515f8d839d27d03fa57e40eb6d31bb1db96a4905bd34f8188a7b","t":1593040148}},{"t":1593040260,"p":{"ppi":{"l":173.03,"v":804152},"bitfinex":{"l":173.09,"v":273666},"bittrex":{"l":173.1,"v":408501},"okcoin":{"l":172.78,"v":15166},"poloniex":{"l":172.66,"v":106819}},"tx":{"h":"ca9b800a3734a39992560645badfeb4908fdb7d76212610d7c9e7c1a0f42bce8","t":1593040268}},{"t":1593040320,"p":{"ppi":{"l":173.07,"v":804639},"bitfinex":{"l":173.2,"v":274153},"bittrex":{"l":173.1,"v":408501},"okcoin":{"l":172.78,"v":15166},"poloniex":{"l":172.66,"v":106819}},"tx":{"h":"d5b037d738556619b9f4669df8c178b477e0e9109c7d27d3b91443e1b8a4a23c","t":1593040328}}]`)))
	}

	// Valid Historical (by id)
	if req.URL.String() == apiEndpoint+"/tickers/12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8/historical?end=1592953700&interval=1&start=1592940680" {
		resp.StatusCode = http.StatusOK
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`[{"t":1592953860,"p":{"ppi":{"l":177.88,"v":726628},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":528243},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"0b7a598dcaec0a0db217cf65efece1db5f5930e2a341f23d6847f22831e56359","t":1592953868}},{"t":1592953920,"p":{"ppi":{"l":177.88,"v":726628},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":528243},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"8823964986e4ccc623cdb3ce87aee220d04deac243449a5b0d016efda76207d2","t":1592953929}},{"t":1592953980,"p":{"ppi":{"l":177.88,"v":726628},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":528243},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"b5937d93fcac13ccb5ab10661c8379e44adf22cb2b811aa6659d07bd7432acd1","t":1592953988}},{"t":1592954040,"p":{"ppi":{"l":177.88,"v":726628},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":528243},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"e97bc212e1ea9d234d74b27b4360499d5745f73934f05ad49db1849d1db80e33","t":1592954048}},{"t":1592954160,"p":{"ppi":{"l":177.88,"v":725475},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"b65f55beb30cdc279a6eaf559f4ef87b53ab7bfa8bcf89ac4c2fa385905a02dd","t":1592954168}},{"t":1592954220,"p":{"ppi":{"l":177.88,"v":725475},"bitfinex":{"l":178.26,"v":154059},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"8fd25d6adfbd06e5fb3e63715d996c6fd5d2d7802263b0ee418bbb0ca74c5819","t":1592954228}},{"t":1592954280,"p":{"ppi":{"l":177.84,"v":725471},"bitfinex":{"l":178.06,"v":154055},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"406ebe7afdfbb368ce41d8fbc85ddeb4eb4543a59ec6f81db7d088b0bab40c0d","t":1592954288}},{"t":1592954340,"p":{"ppi":{"l":177.84,"v":725471},"bitfinex":{"l":178.06,"v":154055},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"f583a5fd2a1450c92f309a6efaaef43b2409b10f4ce79f20ab997c579a4671cf","t":1592954349}},{"t":1592954460,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"d1b6df4b058a2dc8eba340e446be98f79575967a5e83288fcc830517caa2fe0c","t":1592954468}},{"t":1592954520,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"c093f92db1ddb686077cd6b7c41385040b4f3248bd3cee640ca9344c45528edd","t":1592954579}},{"t":1592954580,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"09dd45cb6c1a9e250c89cdacfd9b1e8214954c5ab0a59bb0fc93065406d8e6a2","t":1592954588}},{"t":1592954640,"p":{"ppi":{"l":177.84,"v":723399},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527090},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39105}},"tx":{"h":"a2a13b082effb134699875603c16e7d96fb04367477ce372a1e6c87642bf42fa","t":1592954648}},{"t":1592954760,"p":{"ppi":{"l":177.84,"v":723266},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.49,"v":39061}},"tx":{"h":"31652bf92e619bb57c0e91997cd8e8acc7c8e3fd5b1329a8e3f0500920b4696c","t":1592954768}},{"t":1592954820,"p":{"ppi":{"l":177.84,"v":723266},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39061}},"tx":{"h":"0b8854e1b1e46856933861bd9314fcbd615c4c251335b4505a57687c6e976793","t":1592954828}},{"t":1592954880,"p":{"ppi":{"l":177.84,"v":723436},"bitfinex":{"l":178.06,"v":151983},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39231}},"tx":{"h":"afea091074a79fec89a7b5ca98f86f8f062a787dc5fd10c30643e0e34e1deb0d","t":1592954890}},{"t":1592954940,"p":{"ppi":{"l":177.73,"v":733181},"bitfinex":{"l":177.52,"v":161728},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39231}},"tx":{"h":"7e40a8b5e6d79dc9ab1e30d21fcea523cffd7c98d80e4da0e5322a1096fa825d","t":1592954948}},{"t":1592955060,"p":{"ppi":{"l":177.73,"v":733181},"bitfinex":{"l":177.52,"v":161728},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.6,"v":39231}},"tx":{"h":"0e2406abfd57845c1dda837cd23ebd02eefa18ebaef8c9add87096ad9d6c8fa4","t":1592955068}},{"t":1592955120,"p":{"ppi":{"l":177.71,"v":733358},"bitfinex":{"l":177.52,"v":161728},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.33,"v":39408}},"tx":{"h":"1ddfe95c1e10d0586558e4e809f9736665e5fbe409b22b1da4f09946d27fa099","t":1592955128}},{"t":1592955180,"p":{"ppi":{"l":177.75,"v":733743},"bitfinex":{"l":177.71,"v":161902},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.33,"v":39619}},"tx":{"h":"7be4e379f5dac56f440c32a99d6421ac3673393f8724a59938f688c4bc5ba244","t":1592955188}},{"t":1592955240,"p":{"ppi":{"l":177.77,"v":734065},"bitfinex":{"l":177.71,"v":162199},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"adeabaad79ae3392578d29f08146c915d1b658b27116f2ec8282b1721c29d29f","t":1592955248}},{"t":1592955360,"p":{"ppi":{"l":177.77,"v":733354},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.8,"v":527001},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"c0d8547afcc569c4aa625acc516fee033b51a674e092fd320fa1c361127d556e","t":1592955368}},{"t":1592955420,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"400b4a01c2dc45fd967bb769a5043ee9c2b2fa4bf37bd6a1691cf4b5e9d74eff","t":1592955428}},{"t":1592955480,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"e6358fbb820aa3261f94fc0ed9dcf58d157526a2b9ed56b4f342e2f5128d470d","t":1592955488}},{"t":1592955540,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"1c6ff3caad68f35e2ca91f8bf93b76b4d3aa3bc00e35601597490391f0e131b6","t":1592955549}},{"t":1592955660,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"3a72857bf36c5e3f59fb5d5aeb41e05677d50172d9333c237f6e058480423eea","t":1592955669}},{"t":1592955720,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"b3444fc2a35b31e60d2afef23f138d9b9dbe7a63fa9ae35da039fbbaa7174c3d","t":1592955729}},{"t":1592955780,"p":{"ppi":{"l":177.78,"v":733604},"bitfinex":{"l":177.71,"v":161488},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"01de6e491b7cd4800d9e256f8b3e92ef3fa9a770d6b7434d4586fe7d8deb1b69","t":1592955788}},{"t":1592955840,"p":{"ppi":{"l":177.78,"v":733710},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"305cefc4b5353177217650f7b9985f32a264849bd7588e1e9b6983d8b735c5c8","t":1592955848}},{"t":1592955960,"p":{"ppi":{"l":177.78,"v":733710},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"6293f09007d392b29b6fd35008838e10d492f5763af1f965f03cd3eef1090234","t":1592955968}},{"t":1592956020,"p":{"ppi":{"l":177.78,"v":733710},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":527251},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"61ccb98a68468522056b51471252ea1ae6b80d5db438c4bbfdc7796de8a33d08","t":1592956028}},{"t":1592956080,"p":{"ppi":{"l":177.78,"v":732973},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":526514},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"fc7ffc839331400f580bf4a1d8cf852244c06397d587dac8f72d69489e875a7e","t":1592956089}},{"t":1592956140,"p":{"ppi":{"l":177.78,"v":732973},"bitfinex":{"l":177.69,"v":161594},"bittrex":{"l":177.81,"v":526514},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"e25889fa4c2297fb96842129b56de9d94506e88acfec487ea366c65bdd4e7ee4","t":1592956148}},{"t":1592956260,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"5c9d03789ba7e4e6eef3a78577b4ae55d8130d5d37619fa50e678fe6a2b76223","t":1592956268}},{"t":1592956320,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"43c736e41697d58e0cb7bf5594ab910f42bdf3c460831e73e008e625b4bed8b6","t":1592956379}},{"t":1592956380,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"6724f15b426270560f45f50a8be555648e2f0ac0201b4602ead9bbcc7f31cdaa","t":1592956388}},{"t":1592956440,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"9dd889913f98cddf0c8625af7ef876a50900dde866c9bb1886d0d8fa20c3d56a","t":1592956449}},{"t":1592956560,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"ff09adc3cda69510656695bb9421f3660031c1cc5c9b576d224d40f0ebb744a3","t":1592956568}},{"t":1592956620,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"f82e0b70f47bd9d7beddd27fe83563445260d11bce381d83b590f964de582f3c","t":1592956628}},{"t":1592956680,"p":{"ppi":{"l":177.78,"v":731803},"bitfinex":{"l":177.69,"v":160565},"bittrex":{"l":177.81,"v":526373},"okcoin":{"l":177.52,"v":5221},"poloniex":{"l":177.7,"v":39644}},"tx":{"h":"bc8be2d952e53c594dedab36daf107fb8da94546d0713211abeb688cc87231e5","t":1592956688}}]`)))
	}

	// Invalid (by id) (api returns empty result)
	if req.URL.String() == apiEndpoint+"/tickers/bad-pair-id/historical" {
		resp.StatusCode = http.StatusOK
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`[]`)))
	}

	// Invalid (by id) actual error
	if req.URL.String() == apiEndpoint+"/tickers/error/historical" {
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(``)))
		return resp, fmt.Errorf(`unknown error`)
	}

	// Default is valid
	return resp, nil
}

// mockHTTPTickersInvalid for mocking requests
type mockHTTPTickersInvalid struct{}

// Do is a mock http request
func (m *mockHTTPTickersInvalid) Do(req *http.Request) (*http.Response, error) {
	resp := new(http.Response)
	resp.StatusCode = http.StatusBadRequest

	// No req found
	if req == nil {
		return resp, fmt.Errorf("missing request")
	}

	// Invalid
	if req.URL.String() == apiEndpoint+"/tickers" {
		resp.Body = ioutil.NopCloser(bytes.NewBuffer([]byte(`{"success": false,"message": "Not Found"}`)))
		return resp, fmt.Errorf(`{"success": false,"message": "Not Found"}`)
	}

	// Default is valid
	return resp, nil
}

// TestClient_GetTickers tests the GetTickers()
func TestClient_GetTickers(t *testing.T) {
	t.Parallel()

	// New mock client
	client := newMockClient(&mockHTTPTickersValid{})

	// Test the valid response
	tickers, err := client.GetTickers()
	if err != nil {
		t.Errorf("%s Failed: error [%s]", t.Name(), err.Error())
	} else if tickers == nil {
		t.Errorf("%s Failed: tickers was nil", t.Name())
	} else if tickers.BsvUsd.ID != "12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8" {
		t.Errorf("%s Failed: pair id was not as expected, pair id was %s", t.Name(), tickers.BsvUsd.ID)
	}

	// New invalid mock client
	client = newMockClient(&mockHTTPTickersInvalid{})

	// Test invalid response
	_, err = client.GetTickers()
	if err == nil {
		t.Errorf("%s Failed: error should have occurred", t.Name())
	}
}

// TestClient_GetTicker tests the GetTicker()
func TestClient_GetTicker(t *testing.T) {
	t.Parallel()

	// New mock client
	client := newMockClient(&mockHTTPTickersValid{})

	// Create the list of tests
	var tests = []struct {
		input         string
		expected      string
		expectedError bool
		statusCode    int
	}{
		{"12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8", "12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8", false, http.StatusOK},
		{"bad-pair-id", "bad-pair-id", false, http.StatusOK},
		{"error", "", true, http.StatusBadRequest},
	}

	// Test all
	for _, test := range tests {
		if output, err := client.GetTicker(test.input); err == nil && test.expectedError {
			t.Errorf("%s Failed: expected to throw an error, no error [%s] inputted", t.Name(), test.input)
		} else if err != nil && !test.expectedError {
			t.Errorf("%s Failed: [%s] inputted, received: [%v] error [%s]", t.Name(), test.input, output, err.Error())
		} else if output != nil && output.ID != test.expected && !test.expectedError {
			t.Errorf("%s Failed: [%s] inputted and [%s] expected, received: [%s]", t.Name(), test.input, test.expected, output.ID)
		} else if client.LastRequest.StatusCode != test.statusCode {
			t.Errorf("%s Expected status code to be %d, got %d, [%s] inputted", t.Name(), test.statusCode, client.LastRequest.StatusCode, test.input)
		}
	}

}

// TestClient_GetTickerHistory tests the GetTickerHistory()
func TestClient_GetTickerHistory(t *testing.T) {
	t.Parallel()

	// New mock client
	client := newMockClient(&mockHTTPTickersValid{})

	// Create the list of tests
	var tests = []struct {
		input         string
		start         int64
		end           int64
		interval      int64
		expected      string
		expectedError bool
		statusCode    int
	}{
		{"12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8", 0, 0, 0, "b5937d93fcac13ccb5ab10661c8379e44adf22cb2b811aa6659d07bd7432acd1", false, http.StatusOK},
		{"12eLTxv1vyUeJtp5zqWbqpdWvfLdZ7dGf8", 1592940680, 1592953700, 1, "0b7a598dcaec0a0db217cf65efece1db5f5930e2a341f23d6847f22831e56359", false, http.StatusOK},
		{"bad-pair-id", 0, 0, 0, "", false, http.StatusOK},
		{"error", 0, 0, 0, "", true, http.StatusBadRequest},
	}

	// Test all
	for _, test := range tests {
		if output, err := client.GetTickerHistory(test.input, test.start, test.end, test.interval); err == nil && test.expectedError {
			t.Errorf("%s Failed: expected to throw an error, no error [%s] inputted", t.Name(), test.input)
		} else if err != nil && !test.expectedError {
			t.Errorf("%s Failed: [%s] inputted, received: [%v] error [%s]", t.Name(), test.input, output, err.Error())
		} else if err == nil && len(output) > 0 && output[0].Tx.Hash != test.expected && !test.expectedError {
			t.Errorf("%s Failed: [%s] inputted and [%s] expected, received: [%v]", t.Name(), test.input, test.expected, output[0].Tx.Hash)
		} else if client.LastRequest.StatusCode != test.statusCode {
			t.Errorf("%s Expected status code to be %d, got %d, [%s] inputted", t.Name(), test.statusCode, client.LastRequest.StatusCode, test.input)
		}
	}
}
